#[repr(transparent)]pub struct CompositionEvent {
pub obj: JsValue,
}Expand description
The CompositionEvent class.
This API requires the following crate features to be activated: CompositionEvent
Fields
obj: JsValueImplementations
Sourceimpl CompositionEvent
impl CompositionEvent
Sourceimpl CompositionEvent
impl CompositionEvent
Sourceimpl CompositionEvent
impl CompositionEvent
Sourceimpl CompositionEvent
impl CompositionEvent
Sourcepub fn init_composition_event(&self, type_arg: &str)
pub fn init_composition_event(&self, type_arg: &str)
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent
Sourceimpl CompositionEvent
impl CompositionEvent
Sourcepub fn init_composition_event_with_can_bubble_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
)
pub fn init_composition_event_with_can_bubble_arg( &self, type_arg: &str, can_bubble_arg: bool, )
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent
Sourceimpl CompositionEvent
impl CompositionEvent
Sourcepub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool,
)
pub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, )
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent
Sourceimpl CompositionEvent
impl CompositionEvent
Sourcepub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool,
view_arg: Option<&Window>,
)
pub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, )
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent, Window
Sourceimpl CompositionEvent
impl CompositionEvent
Sourcepub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_data_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool,
view_arg: Option<&Window>,
data_arg: Option<&str>,
)
pub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_data_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, data_arg: Option<&str>, )
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent, Window
Sourceimpl CompositionEvent
impl CompositionEvent
Sourcepub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_data_arg_and_locale_arg(
&self,
type_arg: &str,
can_bubble_arg: bool,
cancelable_arg: bool,
view_arg: Option<&Window>,
data_arg: Option<&str>,
locale_arg: &str,
)
pub fn init_composition_event_with_can_bubble_arg_and_cancelable_arg_and_view_arg_and_data_arg_and_locale_arg( &self, type_arg: &str, can_bubble_arg: bool, cancelable_arg: bool, view_arg: Option<&Window>, data_arg: Option<&str>, locale_arg: &str, )
The initCompositionEvent() method.
This API requires the following crate features to be activated: CompositionEvent, Window
Methods from Deref<Target = UiEvent>
Sourcepub fn view(&self) -> Option<Window>
pub fn view(&self) -> Option<Window>
Getter for the view field of this object.
This API requires the following crate features to be activated: UiEvent, Window
Sourcepub fn detail(&self) -> i32
pub fn detail(&self) -> i32
Getter for the detail field of this object.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn layer_x(&self) -> i32
pub fn layer_x(&self) -> i32
Getter for the layerX field of this object.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn layer_y(&self) -> i32
pub fn layer_y(&self) -> i32
Getter for the layerY field of this object.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn page_x(&self) -> i32
pub fn page_x(&self) -> i32
Getter for the pageX field of this object.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn page_y(&self) -> i32
pub fn page_y(&self) -> i32
Getter for the pageY field of this object.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn which(&self) -> u32
pub fn which(&self) -> u32
Getter for the which field of this object.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn range_parent(&self) -> Option<Node>
pub fn range_parent(&self) -> Option<Node>
Getter for the rangeParent field of this object.
This API requires the following crate features to be activated: Node, UiEvent
Sourcepub fn range_offset(&self) -> i32
pub fn range_offset(&self) -> i32
Getter for the rangeOffset field of this object.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn init_ui_event(&self, a_type: &str)
pub fn init_ui_event(&self, a_type: &str)
The initUIEvent() method.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn init_ui_event_with_a_can_bubble(&self, a_type: &str, a_can_bubble: bool)
pub fn init_ui_event_with_a_can_bubble(&self, a_type: &str, a_can_bubble: bool)
The initUIEvent() method.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn init_ui_event_with_a_can_bubble_and_a_cancelable(
&self,
a_type: &str,
a_can_bubble: bool,
a_cancelable: bool,
)
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, )
The initUIEvent() method.
This API requires the following crate features to be activated: UiEvent
Sourcepub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view(
&self,
a_type: &str,
a_can_bubble: bool,
a_cancelable: bool,
a_view: Option<&Window>,
)
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, a_view: Option<&Window>, )
The initUIEvent() method.
This API requires the following crate features to be activated: UiEvent, Window
Sourcepub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view_and_a_detail(
&self,
a_type: &str,
a_can_bubble: bool,
a_cancelable: bool,
a_view: Option<&Window>,
a_detail: i32,
)
pub fn init_ui_event_with_a_can_bubble_and_a_cancelable_and_a_view_and_a_detail( &self, a_type: &str, a_can_bubble: bool, a_cancelable: bool, a_view: Option<&Window>, a_detail: i32, )
The initUIEvent() method.
This API requires the following crate features to be activated: UiEvent, Window
pub const SCROLL_PAGE_UP: i32 = -32_768i32
pub const SCROLL_PAGE_DOWN: i32 = 32_768i32
Methods from Deref<Target = Event>
Sourcepub fn type_(&self) -> String
pub fn type_(&self) -> String
Getter for the type field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn target(&self) -> Option<EventTarget>
pub fn target(&self) -> Option<EventTarget>
Getter for the target field of this object.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn current_target(&self) -> Option<EventTarget>
pub fn current_target(&self) -> Option<EventTarget>
Getter for the currentTarget field of this object.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn event_phase(&self) -> u16
pub fn event_phase(&self) -> u16
Getter for the eventPhase field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn bubbles(&self) -> bool
pub fn bubbles(&self) -> bool
Getter for the bubbles field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn cancelable(&self) -> bool
pub fn cancelable(&self) -> bool
Getter for the cancelable field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn default_prevented(&self) -> bool
pub fn default_prevented(&self) -> bool
Getter for the defaultPrevented field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn composed(&self) -> bool
pub fn composed(&self) -> bool
Getter for the composed field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn is_trusted(&self) -> bool
pub fn is_trusted(&self) -> bool
Getter for the isTrusted field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn time_stamp(&self) -> f64
pub fn time_stamp(&self) -> f64
Getter for the timeStamp field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn cancel_bubble(&self) -> bool
pub fn cancel_bubble(&self) -> bool
Getter for the cancelBubble field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn set_cancel_bubble(&self, value: bool)
pub fn set_cancel_bubble(&self, value: bool)
Setter for the cancelBubble field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn composed_path(&self) -> Array
pub fn composed_path(&self) -> Array
The composedPath() method.
This API requires the following crate features to be activated: Event
Sourcepub fn init_event(&self, type_: &str)
pub fn init_event(&self, type_: &str)
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourcepub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
pub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourcepub fn init_event_with_bubbles_and_cancelable(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
)
pub fn init_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourcepub fn prevent_default(&self)
pub fn prevent_default(&self)
The preventDefault() method.
This API requires the following crate features to be activated: Event
Sourcepub fn stop_immediate_propagation(&self)
pub fn stop_immediate_propagation(&self)
The stopImmediatePropagation() method.
This API requires the following crate features to be activated: Event
Sourcepub fn stop_propagation(&self)
pub fn stop_propagation(&self)
The stopPropagation() method.
This API requires the following crate features to be activated: Event
pub const NONE: u16 = 0u16
pub const CAPTURING_PHASE: u16 = 1u16
pub const AT_TARGET: u16 = 2u16
pub const BUBBLING_PHASE: u16 = 3u16
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.