#[repr(transparent)]pub struct DataTransfer {
pub obj: JsValue,
}Expand description
The DataTransfer class.
This API requires the following crate features to be activated: DataTransfer
Fields
obj: JsValueImplementations
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn drop_effect(&self) -> String
pub fn drop_effect(&self) -> String
Getter for the dropEffect field of this object.
This API requires the following crate features to be activated: DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn set_drop_effect(&self, value: &str)
pub fn set_drop_effect(&self, value: &str)
Setter for the dropEffect field of this object.
This API requires the following crate features to be activated: DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn effect_allowed(&self) -> String
pub fn effect_allowed(&self) -> String
Getter for the effectAllowed field of this object.
This API requires the following crate features to be activated: DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn set_effect_allowed(&self, value: &str)
pub fn set_effect_allowed(&self, value: &str)
Setter for the effectAllowed field of this object.
This API requires the following crate features to be activated: DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn items(&self) -> DataTransferItemList
pub fn items(&self) -> DataTransferItemList
Getter for the items field of this object.
This API requires the following crate features to be activated: DataTransfer, DataTransferItemList
Sourceimpl DataTransfer
impl DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn new() -> Result<DataTransfer, JsValue>
pub fn new() -> Result<DataTransfer, JsValue>
The new DataTransfer(..) constructor, creating a new instance of DataTransfer.
This API requires the following crate features to be activated: DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn clear_data(&self) -> Result<(), JsValue>
pub fn clear_data(&self) -> Result<(), JsValue>
The clearData() method.
This API requires the following crate features to be activated: DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn get_files_and_directories(&self) -> Result<Promise, JsValue>
pub fn get_files_and_directories(&self) -> Result<Promise, JsValue>
The getFilesAndDirectories() method.
This API requires the following crate features to be activated: DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourceimpl DataTransfer
impl DataTransfer
Sourcepub fn set_drag_image(&self, image: &Element, x: i32, y: i32)
pub fn set_drag_image(&self, image: &Element, x: i32, y: i32)
The setDragImage() method.
This API requires the following crate features to be activated: DataTransfer, Element
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.