#[repr(transparent)]pub struct DomException {
pub obj: JsValue,
}Expand description
The DomException class.
This API requires the following crate features to be activated: DomException
Fields
obj: JsValueImplementations
Sourceimpl DomException
impl DomException
Sourceimpl DomException
impl DomException
Sourceimpl DomException
impl DomException
Sourceimpl DomException
impl DomException
Sourceimpl DomException
impl DomException
Sourceimpl DomException
impl DomException
Sourcepub fn line_number(&self) -> u32
pub fn line_number(&self) -> u32
Getter for the lineNumber field of this object.
This API requires the following crate features to be activated: DomException
Sourceimpl DomException
impl DomException
Sourcepub fn column_number(&self) -> u32
pub fn column_number(&self) -> u32
Getter for the columnNumber field of this object.
This API requires the following crate features to be activated: DomException
Sourceimpl DomException
impl DomException
Sourceimpl DomException
impl DomException
Sourceimpl DomException
impl DomException
Sourcepub fn new() -> Result<DomException, JsValue>
pub fn new() -> Result<DomException, JsValue>
The new DomException(..) constructor, creating a new instance of DomException.
This API requires the following crate features to be activated: DomException
Sourceimpl DomException
impl DomException
Sourcepub fn new_with_message(message: &str) -> Result<DomException, JsValue>
pub fn new_with_message(message: &str) -> Result<DomException, JsValue>
The new DomException(..) constructor, creating a new instance of DomException.
This API requires the following crate features to be activated: DomException
Sourceimpl DomException
impl DomException
Sourcepub fn new_with_message_and_name(
message: &str,
name: &str,
) -> Result<DomException, JsValue>
pub fn new_with_message_and_name( message: &str, name: &str, ) -> Result<DomException, JsValue>
The new DomException(..) constructor, creating a new instance of DomException.
This API requires the following crate features to be activated: DomException
Sourceimpl DomException
impl DomException
Sourcepub const INDEX_SIZE_ERR: u16 = 1u16
pub const INDEX_SIZE_ERR: u16 = 1u16
The DOMException.INDEX_SIZE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const DOMSTRING_SIZE_ERR: u16 = 2u16
pub const DOMSTRING_SIZE_ERR: u16 = 2u16
The DOMException.DOMSTRING_SIZE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const HIERARCHY_REQUEST_ERR: u16 = 3u16
pub const HIERARCHY_REQUEST_ERR: u16 = 3u16
The DOMException.HIERARCHY_REQUEST_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const WRONG_DOCUMENT_ERR: u16 = 4u16
pub const WRONG_DOCUMENT_ERR: u16 = 4u16
The DOMException.WRONG_DOCUMENT_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_CHARACTER_ERR: u16 = 5u16
pub const INVALID_CHARACTER_ERR: u16 = 5u16
The DOMException.INVALID_CHARACTER_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NO_DATA_ALLOWED_ERR: u16 = 6u16
pub const NO_DATA_ALLOWED_ERR: u16 = 6u16
The DOMException.NO_DATA_ALLOWED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NO_MODIFICATION_ALLOWED_ERR: u16 = 7u16
pub const NO_MODIFICATION_ALLOWED_ERR: u16 = 7u16
The DOMException.NO_MODIFICATION_ALLOWED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NOT_FOUND_ERR: u16 = 8u16
pub const NOT_FOUND_ERR: u16 = 8u16
The DOMException.NOT_FOUND_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NOT_SUPPORTED_ERR: u16 = 9u16
pub const NOT_SUPPORTED_ERR: u16 = 9u16
The DOMException.NOT_SUPPORTED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INUSE_ATTRIBUTE_ERR: u16 = 10u16
pub const INUSE_ATTRIBUTE_ERR: u16 = 10u16
The DOMException.INUSE_ATTRIBUTE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_STATE_ERR: u16 = 11u16
pub const INVALID_STATE_ERR: u16 = 11u16
The DOMException.INVALID_STATE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const SYNTAX_ERR: u16 = 12u16
pub const SYNTAX_ERR: u16 = 12u16
The DOMException.SYNTAX_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_MODIFICATION_ERR: u16 = 13u16
pub const INVALID_MODIFICATION_ERR: u16 = 13u16
The DOMException.INVALID_MODIFICATION_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NAMESPACE_ERR: u16 = 14u16
pub const NAMESPACE_ERR: u16 = 14u16
The DOMException.NAMESPACE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_ACCESS_ERR: u16 = 15u16
pub const INVALID_ACCESS_ERR: u16 = 15u16
The DOMException.INVALID_ACCESS_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const VALIDATION_ERR: u16 = 16u16
pub const VALIDATION_ERR: u16 = 16u16
The DOMException.VALIDATION_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const TYPE_MISMATCH_ERR: u16 = 17u16
pub const TYPE_MISMATCH_ERR: u16 = 17u16
The DOMException.TYPE_MISMATCH_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const SECURITY_ERR: u16 = 18u16
pub const SECURITY_ERR: u16 = 18u16
The DOMException.SECURITY_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const NETWORK_ERR: u16 = 19u16
pub const NETWORK_ERR: u16 = 19u16
The DOMException.NETWORK_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const ABORT_ERR: u16 = 20u16
pub const ABORT_ERR: u16 = 20u16
The DOMException.ABORT_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const URL_MISMATCH_ERR: u16 = 21u16
pub const URL_MISMATCH_ERR: u16 = 21u16
The DOMException.URL_MISMATCH_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const QUOTA_EXCEEDED_ERR: u16 = 22u16
pub const QUOTA_EXCEEDED_ERR: u16 = 22u16
The DOMException.QUOTA_EXCEEDED_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const TIMEOUT_ERR: u16 = 23u16
pub const TIMEOUT_ERR: u16 = 23u16
The DOMException.TIMEOUT_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const INVALID_NODE_TYPE_ERR: u16 = 24u16
pub const INVALID_NODE_TYPE_ERR: u16 = 24u16
The DOMException.INVALID_NODE_TYPE_ERR const.
This API requires the following crate features to be activated: DomException
Sourcepub const DATA_CLONE_ERR: u16 = 25u16
pub const DATA_CLONE_ERR: u16 = 25u16
The DOMException.DATA_CLONE_ERR const.
This API requires the following crate features to be activated: DomException
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.