DomTokenList

Struct DomTokenList 

#[repr(transparent)]
pub struct DomTokenList { pub obj: JsValue, }
The DomTokenList class.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Fields

obj: JsValue

Implementations

Source

impl DomTokenList

pub fn length(&self) -> u32

Getter for the length field of this object.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn value(&self) -> String

Getter for the value field of this object.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn set_value(&self, value: &str)

Setter for the value field of this object.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add(&self, tokens: &Array) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_0(&self) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_1(&self, tokens_1: &str) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_2(&self, tokens_1: &str, tokens_2: &str) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_3( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, ) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_4( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, ) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_5( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, tokens_5: &str, ) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_6( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, tokens_5: &str, tokens_6: &str, ) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn add_7( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, tokens_5: &str, tokens_6: &str, tokens_7: &str, ) -> Result<(), JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn contains(&self, token: &str) -> bool

The contains() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn entries(&self) -> Iterator

The entries() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn for_each(&self, callback: &Function) -> Result<(), JsValue>

The forEach() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn item(&self, index: u32) -> Option<String>

The item() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn keys(&self) -> Iterator

The keys() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove(&self, tokens: &Array) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_0(&self) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_1(&self, tokens_1: &str) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_2(&self, tokens_1: &str, tokens_2: &str) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_3( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, ) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_4( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, ) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_5( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, tokens_5: &str, ) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_6( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, tokens_5: &str, tokens_6: &str, ) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn remove_7( &self, tokens_1: &str, tokens_2: &str, tokens_3: &str, tokens_4: &str, tokens_5: &str, tokens_6: &str, tokens_7: &str, ) -> Result<(), JsValue>

The remove() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn replace(&self, token: &str, new_token: &str) -> Result<bool, JsValue>

The replace() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn supports(&self, token: &str) -> Result<bool, JsValue>

The supports() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn toggle(&self, token: &str) -> Result<bool, JsValue>

The toggle() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn toggle_with_force( &self, token: &str, force: bool, ) -> Result<bool, JsValue>

The toggle() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn values(&self) -> Iterator

The values() method.

MDN Documentation

This API requires the following crate features to be activated: DomTokenList

Source

impl DomTokenList

pub fn get(&self, index: u32) -> Option<String>

Indexing getter. As in the literal Javascript this[key].

This API requires the following crate features to be activated: DomTokenList

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.