#[repr(transparent)]pub struct File {
pub obj: JsValue,
}Expand description
The File class.
This API requires the following crate features to be activated: File
Fields
obj: JsValueImplementations
Sourceimpl File
impl File
Sourceimpl File
impl File
Sourcepub fn last_modified(&self) -> f64
pub fn last_modified(&self) -> f64
Getter for the lastModified field of this object.
This API requires the following crate features to be activated: File
Sourceimpl File
impl File
Sourceimpl File
impl File
Sourceimpl File
impl File
Sourceimpl File
impl File
Sourceimpl File
impl File
Sourceimpl File
impl File
Sourcepub fn new_with_buffer_source_sequence_and_options(
file_bits: &JsValue,
file_name: &str,
options: &FilePropertyBag,
) -> Result<File, JsValue>
pub fn new_with_buffer_source_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
The new File(..) constructor, creating a new instance of File.
This API requires the following crate features to be activated: File, FilePropertyBag
Sourceimpl File
impl File
Sourcepub fn new_with_u8_slice_sequence_and_options(
file_bits: &JsValue,
file_name: &str,
options: &FilePropertyBag,
) -> Result<File, JsValue>
pub fn new_with_u8_slice_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
The new File(..) constructor, creating a new instance of File.
This API requires the following crate features to be activated: File, FilePropertyBag
Sourceimpl File
impl File
Sourcepub fn new_with_u8_array_sequence_and_options(
file_bits: &JsValue,
file_name: &str,
options: &FilePropertyBag,
) -> Result<File, JsValue>
pub fn new_with_u8_array_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
The new File(..) constructor, creating a new instance of File.
This API requires the following crate features to be activated: File, FilePropertyBag
Sourceimpl File
impl File
Sourcepub fn new_with_blob_sequence_and_options(
file_bits: &JsValue,
file_name: &str,
options: &FilePropertyBag,
) -> Result<File, JsValue>
pub fn new_with_blob_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
The new File(..) constructor, creating a new instance of File.
This API requires the following crate features to be activated: File, FilePropertyBag
Sourceimpl File
impl File
Sourcepub fn new_with_str_sequence_and_options(
file_bits: &JsValue,
file_name: &str,
options: &FilePropertyBag,
) -> Result<File, JsValue>
pub fn new_with_str_sequence_and_options( file_bits: &JsValue, file_name: &str, options: &FilePropertyBag, ) -> Result<File, JsValue>
The new File(..) constructor, creating a new instance of File.
This API requires the following crate features to be activated: File, FilePropertyBag
Methods from Deref<Target = Blob>
Sourcepub fn size(&self) -> f64
pub fn size(&self) -> f64
Getter for the size field of this object.
This API requires the following crate features to be activated: Blob
Sourcepub fn type_(&self) -> String
pub fn type_(&self) -> String
Getter for the type field of this object.
This API requires the following crate features to be activated: Blob
Sourcepub fn array_buffer(&self) -> Promise
pub fn array_buffer(&self) -> Promise
The arrayBuffer() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn bytes(&self) -> Promise
pub fn bytes(&self) -> Promise
The bytes() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice(&self) -> Result<Blob, JsValue>
pub fn slice(&self) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_i32(&self, start: i32) -> Result<Blob, JsValue>
pub fn slice_with_i32(&self, start: i32) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_f64(&self, start: f64) -> Result<Blob, JsValue>
pub fn slice_with_f64(&self, start: f64) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_i32_and_i32(
&self,
start: i32,
end: i32,
) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_i32( &self, start: i32, end: i32, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_f64_and_i32(
&self,
start: f64,
end: i32,
) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_i32( &self, start: f64, end: i32, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_i32_and_f64(
&self,
start: i32,
end: f64,
) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_f64( &self, start: i32, end: f64, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_f64_and_f64(
&self,
start: f64,
end: f64,
) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_f64( &self, start: f64, end: f64, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_i32_and_i32_and_content_type(
&self,
start: i32,
end: i32,
content_type: &str,
) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_i32_and_content_type( &self, start: i32, end: i32, content_type: &str, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_f64_and_i32_and_content_type(
&self,
start: f64,
end: i32,
content_type: &str,
) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_i32_and_content_type( &self, start: f64, end: i32, content_type: &str, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_i32_and_f64_and_content_type(
&self,
start: i32,
end: f64,
content_type: &str,
) -> Result<Blob, JsValue>
pub fn slice_with_i32_and_f64_and_content_type( &self, start: i32, end: f64, content_type: &str, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn slice_with_f64_and_f64_and_content_type(
&self,
start: f64,
end: f64,
content_type: &str,
) -> Result<Blob, JsValue>
pub fn slice_with_f64_and_f64_and_content_type( &self, start: f64, end: f64, content_type: &str, ) -> Result<Blob, JsValue>
The slice() method.
This API requires the following crate features to be activated: Blob
Sourcepub fn stream(&self) -> ReadableStream
pub fn stream(&self) -> ReadableStream
The stream() method.
This API requires the following crate features to be activated: Blob, ReadableStream
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.