#[repr(transparent)]pub struct HtmlOptionsCollection {
pub obj: JsValue,
}Expand description
The HtmlOptionsCollection class.
This API requires the following crate features to be activated: HtmlOptionsCollection
Fields
obj: JsValueImplementations
Sourceimpl HtmlOptionsCollection
impl HtmlOptionsCollection
Sourceimpl HtmlOptionsCollection
impl HtmlOptionsCollection
Sourcepub fn set_length(&self, value: u32)
pub fn set_length(&self, value: u32)
Setter for the length field of this object.
This API requires the following crate features to be activated: HtmlOptionsCollection
Sourceimpl HtmlOptionsCollection
impl HtmlOptionsCollection
Sourcepub fn selected_index(&self) -> Result<i32, JsValue>
pub fn selected_index(&self) -> Result<i32, JsValue>
Getter for the selectedIndex field of this object.
This API requires the following crate features to be activated: HtmlOptionsCollection
Sourceimpl HtmlOptionsCollection
impl HtmlOptionsCollection
Sourceimpl HtmlOptionsCollection
impl HtmlOptionsCollection
Sourcepub fn add_with_html_option_element(
&self,
element: &HtmlOptionElement,
) -> Result<(), JsValue>
pub fn add_with_html_option_element( &self, element: &HtmlOptionElement, ) -> Result<(), JsValue>
The add() method.
This API requires the following crate features to be activated: HtmlOptionElement, HtmlOptionsCollection
Sourceimpl HtmlOptionsCollection
impl HtmlOptionsCollection
Sourcepub fn add_with_html_option_element_and_opt_html_element(
&self,
element: &HtmlOptionElement,
before: Option<&HtmlElement>,
) -> Result<(), JsValue>
pub fn add_with_html_option_element_and_opt_html_element( &self, element: &HtmlOptionElement, before: Option<&HtmlElement>, ) -> Result<(), JsValue>
The add() method.
This API requires the following crate features to be activated: HtmlElement, HtmlOptionElement, HtmlOptionsCollection
Sourceimpl HtmlOptionsCollection
impl HtmlOptionsCollection
Sourcepub fn add_with_html_option_element_and_opt_i32(
&self,
element: &HtmlOptionElement,
before: Option<i32>,
) -> Result<(), JsValue>
pub fn add_with_html_option_element_and_opt_i32( &self, element: &HtmlOptionElement, before: Option<i32>, ) -> Result<(), JsValue>
The add() method.
This API requires the following crate features to be activated: HtmlOptionElement, HtmlOptionsCollection
Methods from Deref<Target = HtmlCollection>
Sourcepub fn length(&self) -> u32
pub fn length(&self) -> u32
Getter for the length field of this object.
This API requires the following crate features to be activated: HtmlCollection
Sourcepub fn item(&self, index: u32) -> Option<Element>
pub fn item(&self, index: u32) -> Option<Element>
The item() method.
This API requires the following crate features to be activated: Element, HtmlCollection
Sourcepub fn named_item(&self, name: &str) -> Option<Element>
pub fn named_item(&self, name: &str) -> Option<Element>
The namedItem() method.
This API requires the following crate features to be activated: Element, HtmlCollection
Sourcepub fn get_with_index(&self, index: u32) -> Option<Element>
pub fn get_with_index(&self, index: u32) -> Option<Element>
Indexing getter. As in the literal Javascript this[key].
This API requires the following crate features to be activated: Element, HtmlCollection
Sourcepub fn get_with_name(&self, name: &str) -> Option<Element>
pub fn get_with_name(&self, name: &str) -> Option<Element>
Indexing getter. As in the literal Javascript this[key].
This API requires the following crate features to be activated: Element, HtmlCollection
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.