IdbDatabase

Struct IdbDatabase 

#[repr(transparent)]
pub struct IdbDatabase { pub obj: JsValue, }
The IdbDatabase class.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Fields

obj: JsValue

Implementations

Source

impl IdbDatabase

pub fn name(&self) -> String

Getter for the name field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn version(&self) -> f64

Getter for the version field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn object_store_names(&self) -> DomStringList

Getter for the objectStoreNames field of this object.

MDN Documentation

This API requires the following crate features to be activated: DomStringList, IdbDatabase

Source

impl IdbDatabase

pub fn onabort(&self) -> Option<Function>

Getter for the onabort field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn set_onabort(&self, value: Option<&Function>)

Setter for the onabort field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn onclose(&self) -> Option<Function>

Getter for the onclose field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn set_onclose(&self, value: Option<&Function>)

Setter for the onclose field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn onerror(&self) -> Option<Function>

Getter for the onerror field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn set_onerror(&self, value: Option<&Function>)

Setter for the onerror field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn onversionchange(&self) -> Option<Function>

Getter for the onversionchange field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn set_onversionchange(&self, value: Option<&Function>)

Setter for the onversionchange field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn close(&self)

The close() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn create_mutable_file(&self, name: &str) -> Result<IdbRequest, JsValue>

👎Deprecated

The createMutableFile() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase, IdbRequest

Source

impl IdbDatabase

pub fn create_mutable_file_with_type( &self, name: &str, type_: &str, ) -> Result<IdbRequest, JsValue>

👎Deprecated

The createMutableFile() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase, IdbRequest

Source

impl IdbDatabase

pub fn create_object_store(&self, name: &str) -> Result<IdbObjectStore, JsValue>

The createObjectStore() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase, IdbObjectStore

Source

impl IdbDatabase

pub fn delete_object_store(&self, name: &str) -> Result<(), JsValue>

The deleteObjectStore() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase

Source

impl IdbDatabase

pub fn transaction_with_str( &self, store_names: &str, ) -> Result<IdbTransaction, JsValue>

The transaction() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase, IdbTransaction

Source

impl IdbDatabase

pub fn transaction_with_str_sequence( &self, store_names: &JsValue, ) -> Result<IdbTransaction, JsValue>

The transaction() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase, IdbTransaction

Source

impl IdbDatabase

pub fn transaction_with_str_and_mode( &self, store_names: &str, mode: IdbTransactionMode, ) -> Result<IdbTransaction, JsValue>

The transaction() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase, IdbTransaction, IdbTransactionMode

Source

impl IdbDatabase

pub fn transaction_with_str_sequence_and_mode( &self, store_names: &JsValue, mode: IdbTransactionMode, ) -> Result<IdbTransaction, JsValue>

The transaction() method.

MDN Documentation

This API requires the following crate features to be activated: IdbDatabase, IdbTransaction, IdbTransactionMode

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

The dispatchEvent() method.

MDN Documentation

This API requires the following crate features to be activated: Event, EventTarget

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListenerOptions, EventTarget

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.