IdbObjectStore

Struct IdbObjectStore 

#[repr(transparent)]
pub struct IdbObjectStore { pub obj: JsValue, }
The IdbObjectStore class.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore

Fields

obj: JsValue

Implementations

Source

impl IdbObjectStore

pub fn name(&self) -> String

Getter for the name field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore

Source

impl IdbObjectStore

pub fn set_name(&self, value: &str)

Setter for the name field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore

Source

impl IdbObjectStore

pub fn key_path(&self) -> Result<JsValue, JsValue>

Getter for the keyPath field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore

Source

impl IdbObjectStore

pub fn index_names(&self) -> DomStringList

Getter for the indexNames field of this object.

MDN Documentation

This API requires the following crate features to be activated: DomStringList, IdbObjectStore

Source

impl IdbObjectStore

pub fn transaction(&self) -> IdbTransaction

Getter for the transaction field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbTransaction

Source

impl IdbObjectStore

pub fn auto_increment(&self) -> bool

Getter for the autoIncrement field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore

Source

impl IdbObjectStore

pub fn add(&self, value: &JsValue) -> Result<IdbRequest, JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn add_with_key( &self, value: &JsValue, key: &JsValue, ) -> Result<IdbRequest, JsValue>

The add() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn clear(&self) -> Result<IdbRequest, JsValue>

The clear() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn count(&self) -> Result<IdbRequest, JsValue>

The count() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn count_with_key(&self, query: &JsValue) -> Result<IdbRequest, JsValue>

The count() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn create_index_with_str( &self, name: &str, key_path: &str, ) -> Result<IdbIndex, JsValue>

The createIndex() method.

MDN Documentation

This API requires the following crate features to be activated: IdbIndex, IdbObjectStore

Source

impl IdbObjectStore

pub fn create_index_with_str_sequence( &self, name: &str, key_path: &JsValue, ) -> Result<IdbIndex, JsValue>

The createIndex() method.

MDN Documentation

This API requires the following crate features to be activated: IdbIndex, IdbObjectStore

Source

impl IdbObjectStore

pub fn delete(&self, query: &JsValue) -> Result<IdbRequest, JsValue>

The delete() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn delete_index(&self, name: &str) -> Result<(), JsValue>

The deleteIndex() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore

Source

impl IdbObjectStore

pub fn get(&self, query: &JsValue) -> Result<IdbRequest, JsValue>

The get() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn get_all(&self) -> Result<IdbRequest, JsValue>

The getAll() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn get_all_with_key(&self, query: &JsValue) -> Result<IdbRequest, JsValue>

The getAll() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn get_all_with_key_and_limit( &self, query: &JsValue, count: u32, ) -> Result<IdbRequest, JsValue>

The getAll() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn get_all_keys(&self) -> Result<IdbRequest, JsValue>

The getAllKeys() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn get_all_keys_with_key( &self, query: &JsValue, ) -> Result<IdbRequest, JsValue>

The getAllKeys() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn get_all_keys_with_key_and_limit( &self, query: &JsValue, count: u32, ) -> Result<IdbRequest, JsValue>

The getAllKeys() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn get_key(&self, query: &JsValue) -> Result<IdbRequest, JsValue>

The getKey() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn index(&self, name: &str) -> Result<IdbIndex, JsValue>

The index() method.

MDN Documentation

This API requires the following crate features to be activated: IdbIndex, IdbObjectStore

Source

impl IdbObjectStore

pub fn open_cursor(&self) -> Result<IdbRequest, JsValue>

The openCursor() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn open_cursor_with_range( &self, query: &JsValue, ) -> Result<IdbRequest, JsValue>

The openCursor() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn open_cursor_with_range_and_direction( &self, query: &JsValue, direction: IdbCursorDirection, ) -> Result<IdbRequest, JsValue>

The openCursor() method.

MDN Documentation

This API requires the following crate features to be activated: IdbCursorDirection, IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn open_key_cursor(&self) -> Result<IdbRequest, JsValue>

The openKeyCursor() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn open_key_cursor_with_range( &self, query: &JsValue, ) -> Result<IdbRequest, JsValue>

The openKeyCursor() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn open_key_cursor_with_range_and_direction( &self, query: &JsValue, direction: IdbCursorDirection, ) -> Result<IdbRequest, JsValue>

The openKeyCursor() method.

MDN Documentation

This API requires the following crate features to be activated: IdbCursorDirection, IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn put(&self, value: &JsValue) -> Result<IdbRequest, JsValue>

The put() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Source

impl IdbObjectStore

pub fn put_with_key( &self, value: &JsValue, key: &JsValue, ) -> Result<IdbRequest, JsValue>

The put() method.

MDN Documentation

This API requires the following crate features to be activated: IdbObjectStore, IdbRequest

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.