#[repr(transparent)]pub struct IntersectionObserverInit {
pub obj: JsValue,
}Expand description
The IntersectionObserverInit dictionary.
This API requires the following crate features to be activated: IntersectionObserverInit
Fields
obj: JsValueImplementations
Sourceimpl IntersectionObserverInit
impl IntersectionObserverInit
Sourcepub fn get_root_margin(&self) -> Option<String>
pub fn get_root_margin(&self) -> Option<String>
Get the rootMargin field of this object.
This API requires the following crate features to be activated: IntersectionObserverInit
Sourceimpl IntersectionObserverInit
impl IntersectionObserverInit
Sourcepub fn set_root_margin(&self, val: &str)
pub fn set_root_margin(&self, val: &str)
Change the rootMargin field of this object.
This API requires the following crate features to be activated: IntersectionObserverInit
Sourceimpl IntersectionObserverInit
impl IntersectionObserverInit
Sourcepub fn get_threshold(&self) -> JsValue
pub fn get_threshold(&self) -> JsValue
Get the threshold field of this object.
This API requires the following crate features to be activated: IntersectionObserverInit
Sourceimpl IntersectionObserverInit
impl IntersectionObserverInit
Sourcepub fn set_threshold(&self, val: &JsValue)
pub fn set_threshold(&self, val: &JsValue)
Change the threshold field of this object.
This API requires the following crate features to be activated: IntersectionObserverInit
Sourceimpl IntersectionObserverInit
impl IntersectionObserverInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new IntersectionObserverInit.
This API requires the following crate features to be activated: IntersectionObserverInit
pub fn root(&mut self, val: Option<&Element>) -> &mut Self
set_root() instead.pub fn root_margin(&mut self, val: &str) -> &mut Self
set_root_margin() instead.pub fn threshold(&mut self, val: &JsValue) -> &mut Self
set_threshold() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.