#[repr(transparent)]pub struct MediaStream {
pub obj: JsValue,
}Expand description
The MediaStream class.
This API requires the following crate features to be activated: MediaStream
Fields
obj: JsValueImplementations
Sourceimpl MediaStream
impl MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn onaddtrack(&self) -> Option<Function>
pub fn onaddtrack(&self) -> Option<Function>
Getter for the onaddtrack field of this object.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn set_onaddtrack(&self, value: Option<&Function>)
pub fn set_onaddtrack(&self, value: Option<&Function>)
Setter for the onaddtrack field of this object.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn onremovetrack(&self) -> Option<Function>
pub fn onremovetrack(&self) -> Option<Function>
Getter for the onremovetrack field of this object.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn set_onremovetrack(&self, value: Option<&Function>)
pub fn set_onremovetrack(&self, value: Option<&Function>)
Setter for the onremovetrack field of this object.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn current_time(&self) -> f64
pub fn current_time(&self) -> f64
Getter for the currentTime field of this object.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn new() -> Result<MediaStream, JsValue>
pub fn new() -> Result<MediaStream, JsValue>
The new MediaStream(..) constructor, creating a new instance of MediaStream.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn new_with_stream(stream: &MediaStream) -> Result<MediaStream, JsValue>
pub fn new_with_stream(stream: &MediaStream) -> Result<MediaStream, JsValue>
The new MediaStream(..) constructor, creating a new instance of MediaStream.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn new_with_tracks(tracks: &JsValue) -> Result<MediaStream, JsValue>
pub fn new_with_tracks(tracks: &JsValue) -> Result<MediaStream, JsValue>
The new MediaStream(..) constructor, creating a new instance of MediaStream.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn add_track(&self, track: &MediaStreamTrack)
pub fn add_track(&self, track: &MediaStreamTrack)
The addTrack() method.
This API requires the following crate features to be activated: MediaStream, MediaStreamTrack
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn clone(&self) -> MediaStream
pub fn clone(&self) -> MediaStream
The clone() method.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn get_audio_tracks(&self) -> Array
pub fn get_audio_tracks(&self) -> Array
The getAudioTracks() method.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn get_track_by_id(&self, track_id: &str) -> Option<MediaStreamTrack>
pub fn get_track_by_id(&self, track_id: &str) -> Option<MediaStreamTrack>
The getTrackById() method.
This API requires the following crate features to be activated: MediaStream, MediaStreamTrack
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn get_tracks(&self) -> Array
pub fn get_tracks(&self) -> Array
The getTracks() method.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn get_video_tracks(&self) -> Array
pub fn get_video_tracks(&self) -> Array
The getVideoTracks() method.
This API requires the following crate features to be activated: MediaStream
Sourceimpl MediaStream
impl MediaStream
Sourcepub fn remove_track(&self, track: &MediaStreamTrack)
pub fn remove_track(&self, track: &MediaStreamTrack)
The removeTrack() method.
This API requires the following crate features to be activated: MediaStream, MediaStreamTrack
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn remove_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.