#[repr(transparent)]pub struct MessageEvent {
pub obj: JsValue,
}Expand description
The MessageEvent class.
This API requires the following crate features to be activated: MessageEvent
Fields
obj: JsValueImplementations
Sourceimpl MessageEvent
impl MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn last_event_id(&self) -> String
pub fn last_event_id(&self) -> String
Getter for the lastEventId field of this object.
This API requires the following crate features to be activated: MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn new_with_event_init_dict(
type_: &str,
event_init_dict: &MessageEventInit,
) -> Result<MessageEvent, JsValue>
pub fn new_with_event_init_dict( type_: &str, event_init_dict: &MessageEventInit, ) -> Result<MessageEvent, JsValue>
The new MessageEvent(..) constructor, creating a new instance of MessageEvent.
This API requires the following crate features to be activated: MessageEvent, MessageEventInit
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event(&self, type_: &str)
pub fn init_message_event(&self, type_: &str)
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles(&self, type_: &str, bubbles: bool)
pub fn init_message_event_with_bubbles(&self, type_: &str, bubbles: bool)
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
)
pub fn init_message_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
data: &JsValue,
origin: &str,
last_event_id: &str,
)
pub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id( &self, type_: &str, bubbles: bool, cancelable: bool, data: &JsValue, origin: &str, last_event_id: &str, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_window(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
data: &JsValue,
origin: &str,
last_event_id: &str,
source: Option<&Window>,
)
pub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_window( &self, type_: &str, bubbles: bool, cancelable: bool, data: &JsValue, origin: &str, last_event_id: &str, source: Option<&Window>, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, Window
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_message_port(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
data: &JsValue,
origin: &str,
last_event_id: &str,
source: Option<&MessagePort>,
)
pub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_message_port( &self, type_: &str, bubbles: bool, cancelable: bool, data: &JsValue, origin: &str, last_event_id: &str, source: Option<&MessagePort>, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, MessagePort
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_service_worker(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
data: &JsValue,
origin: &str,
last_event_id: &str,
source: Option<&ServiceWorker>,
)
pub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_service_worker( &self, type_: &str, bubbles: bool, cancelable: bool, data: &JsValue, origin: &str, last_event_id: &str, source: Option<&ServiceWorker>, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, ServiceWorker
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_window_and_ports(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
data: &JsValue,
origin: &str,
last_event_id: &str,
source: Option<&Window>,
ports: &JsValue,
)
pub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_window_and_ports( &self, type_: &str, bubbles: bool, cancelable: bool, data: &JsValue, origin: &str, last_event_id: &str, source: Option<&Window>, ports: &JsValue, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, Window
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_message_port_and_ports(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
data: &JsValue,
origin: &str,
last_event_id: &str,
source: Option<&MessagePort>,
ports: &JsValue,
)
pub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_message_port_and_ports( &self, type_: &str, bubbles: bool, cancelable: bool, data: &JsValue, origin: &str, last_event_id: &str, source: Option<&MessagePort>, ports: &JsValue, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, MessagePort
Sourceimpl MessageEvent
impl MessageEvent
Sourcepub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_service_worker_and_ports(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
data: &JsValue,
origin: &str,
last_event_id: &str,
source: Option<&ServiceWorker>,
ports: &JsValue,
)
pub fn init_message_event_with_bubbles_and_cancelable_and_data_and_origin_and_last_event_id_and_opt_service_worker_and_ports( &self, type_: &str, bubbles: bool, cancelable: bool, data: &JsValue, origin: &str, last_event_id: &str, source: Option<&ServiceWorker>, ports: &JsValue, )
The initMessageEvent() method.
This API requires the following crate features to be activated: MessageEvent, ServiceWorker
Methods from Deref<Target = Event>
Sourcepub fn type_(&self) -> String
pub fn type_(&self) -> String
Getter for the type field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn target(&self) -> Option<EventTarget>
pub fn target(&self) -> Option<EventTarget>
Getter for the target field of this object.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn current_target(&self) -> Option<EventTarget>
pub fn current_target(&self) -> Option<EventTarget>
Getter for the currentTarget field of this object.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn event_phase(&self) -> u16
pub fn event_phase(&self) -> u16
Getter for the eventPhase field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn bubbles(&self) -> bool
pub fn bubbles(&self) -> bool
Getter for the bubbles field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn cancelable(&self) -> bool
pub fn cancelable(&self) -> bool
Getter for the cancelable field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn default_prevented(&self) -> bool
pub fn default_prevented(&self) -> bool
Getter for the defaultPrevented field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn composed(&self) -> bool
pub fn composed(&self) -> bool
Getter for the composed field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn is_trusted(&self) -> bool
pub fn is_trusted(&self) -> bool
Getter for the isTrusted field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn time_stamp(&self) -> f64
pub fn time_stamp(&self) -> f64
Getter for the timeStamp field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn cancel_bubble(&self) -> bool
pub fn cancel_bubble(&self) -> bool
Getter for the cancelBubble field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn set_cancel_bubble(&self, value: bool)
pub fn set_cancel_bubble(&self, value: bool)
Setter for the cancelBubble field of this object.
This API requires the following crate features to be activated: Event
Sourcepub fn composed_path(&self) -> Array
pub fn composed_path(&self) -> Array
The composedPath() method.
This API requires the following crate features to be activated: Event
Sourcepub fn init_event(&self, type_: &str)
pub fn init_event(&self, type_: &str)
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourcepub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
pub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourcepub fn init_event_with_bubbles_and_cancelable(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
)
pub fn init_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourcepub fn prevent_default(&self)
pub fn prevent_default(&self)
The preventDefault() method.
This API requires the following crate features to be activated: Event
Sourcepub fn stop_immediate_propagation(&self)
pub fn stop_immediate_propagation(&self)
The stopImmediatePropagation() method.
This API requires the following crate features to be activated: Event
Sourcepub fn stop_propagation(&self)
pub fn stop_propagation(&self)
The stopPropagation() method.
This API requires the following crate features to be activated: Event
pub const NONE: u16 = 0u16
pub const CAPTURING_PHASE: u16 = 1u16
pub const AT_TARGET: u16 = 2u16
pub const BUBBLING_PHASE: u16 = 3u16
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.