#[repr(transparent)]pub struct MessageEventInit {
pub obj: JsValue,
}Expand description
The MessageEventInit dictionary.
This API requires the following crate features to be activated: MessageEventInit
Fields
obj: JsValueImplementations
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn get_bubbles(&self) -> Option<bool>
pub fn get_bubbles(&self) -> Option<bool>
Get the bubbles field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn set_bubbles(&self, val: bool)
pub fn set_bubbles(&self, val: bool)
Change the bubbles field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn get_cancelable(&self) -> Option<bool>
pub fn get_cancelable(&self) -> Option<bool>
Get the cancelable field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn set_cancelable(&self, val: bool)
pub fn set_cancelable(&self, val: bool)
Change the cancelable field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn get_composed(&self) -> Option<bool>
pub fn get_composed(&self) -> Option<bool>
Get the composed field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn set_composed(&self, val: bool)
pub fn set_composed(&self, val: bool)
Change the composed field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn get_last_event_id(&self) -> Option<String>
pub fn get_last_event_id(&self) -> Option<String>
Get the lastEventId field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn set_last_event_id(&self, val: &str)
pub fn set_last_event_id(&self, val: &str)
Change the lastEventId field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn get_origin(&self) -> Option<String>
pub fn get_origin(&self) -> Option<String>
Get the origin field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn set_origin(&self, val: &str)
pub fn set_origin(&self, val: &str)
Change the origin field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn get_source(&self) -> Option<Object>
pub fn get_source(&self) -> Option<Object>
Get the source field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn set_source(&self, val: Option<&Object>)
pub fn set_source(&self, val: Option<&Object>)
Change the source field of this object.
This API requires the following crate features to be activated: MessageEventInit
Sourceimpl MessageEventInit
impl MessageEventInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new MessageEventInit.
This API requires the following crate features to be activated: MessageEventInit
pub fn bubbles(&mut self, val: bool) -> &mut Self
set_bubbles() instead.pub fn cancelable(&mut self, val: bool) -> &mut Self
set_cancelable() instead.pub fn composed(&mut self, val: bool) -> &mut Self
set_composed() instead.pub fn data(&mut self, val: &JsValue) -> &mut Self
set_data() instead.pub fn last_event_id(&mut self, val: &str) -> &mut Self
set_last_event_id() instead.pub fn origin(&mut self, val: &str) -> &mut Self
set_origin() instead.pub fn ports(&mut self, val: &JsValue) -> &mut Self
set_ports() instead.pub fn source(&mut self, val: Option<&Object>) -> &mut Self
set_source() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.