MouseEventInit

Struct MouseEventInit 

#[repr(transparent)]
pub struct MouseEventInit { pub obj: JsValue, }
The MouseEventInit dictionary.

This API requires the following crate features to be activated: MouseEventInit

Fields

obj: JsValue

Implementations

Source

impl MouseEventInit

pub fn get_bubbles(&self) -> Option<bool>

Get the bubbles field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_bubbles(&self, val: bool)

Change the bubbles field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_cancelable(&self) -> Option<bool>

Get the cancelable field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_cancelable(&self, val: bool)

Change the cancelable field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_composed(&self) -> Option<bool>

Get the composed field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_composed(&self, val: bool)

Change the composed field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_detail(&self) -> Option<i32>

Get the detail field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_detail(&self, val: i32)

Change the detail field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_view(&self) -> Option<Window>

Get the view field of this object.

This API requires the following crate features to be activated: MouseEventInit, Window

Source

impl MouseEventInit

pub fn set_view(&self, val: Option<&Window>)

Change the view field of this object.

This API requires the following crate features to be activated: MouseEventInit, Window

Source

impl MouseEventInit

pub fn get_alt_key(&self) -> Option<bool>

Get the altKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_alt_key(&self, val: bool)

Change the altKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_ctrl_key(&self) -> Option<bool>

Get the ctrlKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_ctrl_key(&self, val: bool)

Change the ctrlKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_meta_key(&self) -> Option<bool>

Get the metaKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_meta_key(&self, val: bool)

Change the metaKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_alt_graph(&self) -> Option<bool>

Get the modifierAltGraph field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_alt_graph(&self, val: bool)

Change the modifierAltGraph field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_caps_lock(&self) -> Option<bool>

Get the modifierCapsLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_caps_lock(&self, val: bool)

Change the modifierCapsLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_fn(&self) -> Option<bool>

Get the modifierFn field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_fn(&self, val: bool)

Change the modifierFn field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_fn_lock(&self) -> Option<bool>

Get the modifierFnLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_fn_lock(&self, val: bool)

Change the modifierFnLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_num_lock(&self) -> Option<bool>

Get the modifierNumLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_num_lock(&self, val: bool)

Change the modifierNumLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_os(&self) -> Option<bool>

Get the modifierOS field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_os(&self, val: bool)

Change the modifierOS field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_scroll_lock(&self) -> Option<bool>

Get the modifierScrollLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_scroll_lock(&self, val: bool)

Change the modifierScrollLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_symbol(&self) -> Option<bool>

Get the modifierSymbol field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_symbol(&self, val: bool)

Change the modifierSymbol field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_modifier_symbol_lock(&self) -> Option<bool>

Get the modifierSymbolLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_modifier_symbol_lock(&self, val: bool)

Change the modifierSymbolLock field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_shift_key(&self) -> Option<bool>

Get the shiftKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_shift_key(&self, val: bool)

Change the shiftKey field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_button(&self) -> Option<i16>

Get the button field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_button(&self, val: i16)

Change the button field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_buttons(&self) -> Option<u16>

Get the buttons field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_buttons(&self, val: u16)

Change the buttons field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_client_x(&self) -> Option<i32>

Get the clientX field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_client_x(&self, val: i32)

Change the clientX field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_client_y(&self) -> Option<i32>

Get the clientY field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_client_y(&self, val: i32)

Change the clientY field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_movement_x(&self) -> Option<i32>

Get the movementX field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_movement_x(&self, val: i32)

Change the movementX field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_movement_y(&self) -> Option<i32>

Get the movementY field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_movement_y(&self, val: i32)

Change the movementY field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

Get the relatedTarget field of this object.

This API requires the following crate features to be activated: EventTarget, MouseEventInit

Source

impl MouseEventInit

Change the relatedTarget field of this object.

This API requires the following crate features to be activated: EventTarget, MouseEventInit

Source

impl MouseEventInit

pub fn get_screen_x(&self) -> Option<i32>

Get the screenX field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_screen_x(&self, val: i32)

Change the screenX field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn get_screen_y(&self) -> Option<i32>

Get the screenY field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn set_screen_y(&self, val: i32)

Change the screenY field of this object.

This API requires the following crate features to be activated: MouseEventInit

Source

impl MouseEventInit

pub fn new() -> Self

Construct a new MouseEventInit.

This API requires the following crate features to be activated: MouseEventInit

pub fn bubbles(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_bubbles() instead.
pub fn cancelable(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_cancelable() instead.
pub fn composed(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_composed() instead.
pub fn detail(&mut self, val: i32) -> &mut Self

👎Deprecated: Use set_detail() instead.
pub fn view(&mut self, val: Option<&Window>) -> &mut Self

👎Deprecated: Use set_view() instead.
pub fn alt_key(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_alt_key() instead.
pub fn ctrl_key(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_ctrl_key() instead.
pub fn meta_key(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_meta_key() instead.
pub fn modifier_alt_graph(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_alt_graph() instead.
pub fn modifier_caps_lock(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_caps_lock() instead.
pub fn modifier_fn(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_fn() instead.
pub fn modifier_fn_lock(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_fn_lock() instead.
pub fn modifier_num_lock(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_num_lock() instead.
pub fn modifier_os(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_os() instead.
pub fn modifier_scroll_lock(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_scroll_lock() instead.
pub fn modifier_symbol(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_symbol() instead.
pub fn modifier_symbol_lock(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_modifier_symbol_lock() instead.
pub fn shift_key(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_shift_key() instead.
pub fn button(&mut self, val: i16) -> &mut Self

👎Deprecated: Use set_button() instead.
pub fn buttons(&mut self, val: u16) -> &mut Self

👎Deprecated: Use set_buttons() instead.
pub fn client_x(&mut self, val: i32) -> &mut Self

👎Deprecated: Use set_client_x() instead.
pub fn client_y(&mut self, val: i32) -> &mut Self

👎Deprecated: Use set_client_y() instead.
pub fn movement_x(&mut self, val: i32) -> &mut Self

👎Deprecated: Use set_movement_x() instead.
pub fn movement_y(&mut self, val: i32) -> &mut Self

👎Deprecated: Use set_movement_y() instead.
pub fn related_target(&mut self, val: Option<&EventTarget>) -> &mut Self

👎Deprecated: Use set_related_target() instead.
pub fn screen_x(&mut self, val: i32) -> &mut Self

👎Deprecated: Use set_screen_x() instead.
pub fn screen_y(&mut self, val: i32) -> &mut Self

👎Deprecated: Use set_screen_y() instead.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.