#[repr(transparent)]pub struct MutationObserverInit {
pub obj: JsValue,
}Expand description
The MutationObserverInit dictionary.
This API requires the following crate features to be activated: MutationObserverInit
Fields
obj: JsValueImplementations
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_animations(&self) -> Option<bool>
pub fn get_animations(&self) -> Option<bool>
Get the animations field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_animations(&self, val: bool)
pub fn set_animations(&self, val: bool)
Change the animations field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_attribute_filter(&self) -> Option<Array>
pub fn get_attribute_filter(&self) -> Option<Array>
Get the attributeFilter field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_attribute_filter(&self, val: &JsValue)
pub fn set_attribute_filter(&self, val: &JsValue)
Change the attributeFilter field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_attribute_old_value(&self) -> Option<bool>
pub fn get_attribute_old_value(&self) -> Option<bool>
Get the attributeOldValue field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_attribute_old_value(&self, val: bool)
pub fn set_attribute_old_value(&self, val: bool)
Change the attributeOldValue field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_attributes(&self) -> Option<bool>
pub fn get_attributes(&self) -> Option<bool>
Get the attributes field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_attributes(&self, val: bool)
pub fn set_attributes(&self, val: bool)
Change the attributes field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_character_data(&self) -> Option<bool>
pub fn get_character_data(&self) -> Option<bool>
Get the characterData field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_character_data(&self, val: bool)
pub fn set_character_data(&self, val: bool)
Change the characterData field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_character_data_old_value(&self) -> Option<bool>
pub fn get_character_data_old_value(&self) -> Option<bool>
Get the characterDataOldValue field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_character_data_old_value(&self, val: bool)
pub fn set_character_data_old_value(&self, val: bool)
Change the characterDataOldValue field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_child_list(&self) -> Option<bool>
pub fn get_child_list(&self) -> Option<bool>
Get the childList field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_child_list(&self, val: bool)
pub fn set_child_list(&self, val: bool)
Change the childList field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_native_anonymous_child_list(&self) -> Option<bool>
pub fn get_native_anonymous_child_list(&self) -> Option<bool>
Get the nativeAnonymousChildList field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_native_anonymous_child_list(&self, val: bool)
pub fn set_native_anonymous_child_list(&self, val: bool)
Change the nativeAnonymousChildList field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn get_subtree(&self) -> Option<bool>
pub fn get_subtree(&self) -> Option<bool>
Get the subtree field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn set_subtree(&self, val: bool)
pub fn set_subtree(&self, val: bool)
Change the subtree field of this object.
This API requires the following crate features to be activated: MutationObserverInit
Sourceimpl MutationObserverInit
impl MutationObserverInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new MutationObserverInit.
This API requires the following crate features to be activated: MutationObserverInit
pub fn animations(&mut self, val: bool) -> &mut Self
set_animations() instead.pub fn attribute_filter(&mut self, val: &JsValue) -> &mut Self
set_attribute_filter() instead.pub fn attribute_old_value(&mut self, val: bool) -> &mut Self
set_attribute_old_value() instead.pub fn attributes(&mut self, val: bool) -> &mut Self
set_attributes() instead.pub fn character_data(&mut self, val: bool) -> &mut Self
set_character_data() instead.pub fn character_data_old_value(&mut self, val: bool) -> &mut Self
set_character_data_old_value() instead.pub fn child_list(&mut self, val: bool) -> &mut Self
set_child_list() instead.pub fn native_anonymous_child_list(&mut self, val: bool) -> &mut Self
set_native_anonymous_child_list() instead.pub fn subtree(&mut self, val: bool) -> &mut Self
set_subtree() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.