#[repr(transparent)]pub struct Navigator {
pub obj: JsValue,
}Expand description
The Navigator class.
This API requires the following crate features to be activated: Navigator
Fields
obj: JsValueImplementations
Sourcepub fn permissions(&self) -> Result<Permissions, JsValue>
pub fn permissions(&self) -> Result<Permissions, JsValue>
Getter for the permissions field of this object.
This API requires the following crate features to be activated: Navigator, Permissions
Sourcepub fn do_not_track(&self) -> String
pub fn do_not_track(&self) -> String
Getter for the doNotTrack field of this object.
This API requires the following crate features to be activated: Navigator
Sourcepub fn max_touch_points(&self) -> i32
pub fn max_touch_points(&self) -> i32
Getter for the maxTouchPoints field of this object.
This API requires the following crate features to be activated: Navigator
Sourcepub fn active_vr_displays(&self) -> Array
pub fn active_vr_displays(&self) -> Array
Getter for the activeVRDisplays field of this object.
This API requires the following crate features to be activated: Navigator
Sourcepub fn media_devices(&self) -> Result<MediaDevices, JsValue>
pub fn media_devices(&self) -> Result<MediaDevices, JsValue>
Getter for the mediaDevices field of this object.
This API requires the following crate features to be activated: MediaDevices, Navigator
Sourcepub fn service_worker(&self) -> ServiceWorkerContainer
pub fn service_worker(&self) -> ServiceWorkerContainer
Getter for the serviceWorker field of this object.
This API requires the following crate features to be activated: Navigator, ServiceWorkerContainer
Sourcepub fn user_activation(&self) -> UserActivation
pub fn user_activation(&self) -> UserActivation
Getter for the userActivation field of this object.
This API requires the following crate features to be activated: Navigator, UserActivation
Sourcepub fn wake_lock(&self) -> WakeLock
pub fn wake_lock(&self) -> WakeLock
Getter for the wakeLock field of this object.
This API requires the following crate features to be activated: Navigator, WakeLock
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourcepub fn hardware_concurrency(&self) -> f64
pub fn hardware_concurrency(&self) -> f64
Getter for the hardwareConcurrency field of this object.
This API requires the following crate features to be activated: Navigator
Sourcepub fn device_memory(&self) -> f64
pub fn device_memory(&self) -> f64
Getter for the deviceMemory field of this object.
This API requires the following crate features to be activated: Navigator
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourcepub fn geolocation(&self) -> Result<Geolocation, JsValue>
pub fn geolocation(&self) -> Result<Geolocation, JsValue>
Getter for the geolocation field of this object.
This API requires the following crate features to be activated: Geolocation, Navigator
Sourcepub fn app_code_name(&self) -> Result<String, JsValue>
pub fn app_code_name(&self) -> Result<String, JsValue>
Getter for the appCodeName field of this object.
This API requires the following crate features to be activated: Navigator
Sourcepub fn app_version(&self) -> Result<String, JsValue>
pub fn app_version(&self) -> Result<String, JsValue>
Getter for the appVersion field of this object.
This API requires the following crate features to be activated: Navigator
Sourcepub fn user_agent(&self) -> Result<String, JsValue>
pub fn user_agent(&self) -> Result<String, JsValue>
Getter for the userAgent field of this object.
This API requires the following crate features to be activated: Navigator
Sourcepub fn storage(&self) -> StorageManager
pub fn storage(&self) -> StorageManager
Getter for the storage field of this object.
This API requires the following crate features to be activated: Navigator, StorageManager
The canShare() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn get_gamepads(&self) -> Result<Array, JsValue>
pub fn get_gamepads(&self) -> Result<Array, JsValue>
The getGamepads() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn get_vr_displays(&self) -> Result<Promise, JsValue>
pub fn get_vr_displays(&self) -> Result<Promise, JsValue>
The getVRDisplays() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn request_midi_access(&self) -> Result<Promise, JsValue>
pub fn request_midi_access(&self) -> Result<Promise, JsValue>
The requestMIDIAccess() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn request_media_key_system_access(
&self,
key_system: &str,
supported_configurations: &JsValue,
) -> Promise
pub fn request_media_key_system_access( &self, key_system: &str, supported_configurations: &JsValue, ) -> Promise
The requestMediaKeySystemAccess() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn send_beacon_with_opt_js_u8_array(
&self,
url: &str,
data: Option<&Uint8Array>,
) -> Result<bool, JsValue>
pub fn send_beacon_with_opt_js_u8_array( &self, url: &str, data: Option<&Uint8Array>, ) -> Result<bool, JsValue>
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn send_beacon_with_opt_url_search_params(
&self,
url: &str,
data: Option<&UrlSearchParams>,
) -> Result<bool, JsValue>
pub fn send_beacon_with_opt_url_search_params( &self, url: &str, data: Option<&UrlSearchParams>, ) -> Result<bool, JsValue>
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator, UrlSearchParams
Sourcepub fn send_beacon_with_opt_readable_stream(
&self,
url: &str,
data: Option<&ReadableStream>,
) -> Result<bool, JsValue>
pub fn send_beacon_with_opt_readable_stream( &self, url: &str, data: Option<&ReadableStream>, ) -> Result<bool, JsValue>
The sendBeacon() method.
This API requires the following crate features to be activated: Navigator, ReadableStream
The share() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn vibrate_with_duration(&self, pattern: u32) -> bool
pub fn vibrate_with_duration(&self, pattern: u32) -> bool
The vibrate() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn vibrate_with_pattern(&self, pattern: &JsValue) -> bool
pub fn vibrate_with_pattern(&self, pattern: &JsValue) -> bool
The vibrate() method.
This API requires the following crate features to be activated: Navigator
Sourcepub fn taint_enabled(&self) -> bool
pub fn taint_enabled(&self) -> bool
The taintEnabled() method.
This API requires the following crate features to be activated: Navigator
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.