NotificationOptions

Struct NotificationOptions 

#[repr(transparent)]
pub struct NotificationOptions { pub obj: JsValue, }
The NotificationOptions dictionary.

This API requires the following crate features to be activated: NotificationOptions

Fields

obj: JsValue

Implementations

Source

impl NotificationOptions

pub fn get_actions(&self) -> Option<Array>

Get the actions field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_actions(&self, val: &JsValue)

Change the actions field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_badge(&self) -> Option<String>

Get the badge field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_badge(&self, val: &str)

Change the badge field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_body(&self) -> Option<String>

Get the body field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_body(&self, val: &str)

Change the body field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_data(&self) -> JsValue

Get the data field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_data(&self, val: &JsValue)

Change the data field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_icon(&self) -> Option<String>

Get the icon field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_icon(&self, val: &str)

Change the icon field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_image(&self) -> Option<String>

Get the image field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_image(&self, val: &str)

Change the image field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_lang(&self) -> Option<String>

Get the lang field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_lang(&self, val: &str)

Change the lang field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_renotify(&self) -> Option<bool>

Get the renotify field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_renotify(&self, val: bool)

Change the renotify field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_require_interaction(&self) -> Option<bool>

Get the requireInteraction field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_require_interaction(&self, val: bool)

Change the requireInteraction field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_silent(&self) -> Option<bool>

Get the silent field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_silent(&self, val: Option<bool>)

Change the silent field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_tag(&self) -> Option<String>

Get the tag field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_tag(&self, val: &str)

Change the tag field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_timestamp(&self) -> Option<f64>

Get the timestamp field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_timestamp(&self, val: f64)

Change the timestamp field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn get_vibrate(&self) -> JsValue

Get the vibrate field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn set_vibrate(&self, val: &JsValue)

Change the vibrate field of this object.

This API requires the following crate features to be activated: NotificationOptions

Source

impl NotificationOptions

pub fn new() -> Self

Construct a new NotificationOptions.

This API requires the following crate features to be activated: NotificationOptions

pub fn actions(&mut self, val: &JsValue) -> &mut Self

👎Deprecated: Use set_actions() instead.
pub fn badge(&mut self, val: &str) -> &mut Self

👎Deprecated: Use set_badge() instead.
pub fn body(&mut self, val: &str) -> &mut Self

👎Deprecated: Use set_body() instead.
pub fn data(&mut self, val: &JsValue) -> &mut Self

👎Deprecated: Use set_data() instead.
pub fn icon(&mut self, val: &str) -> &mut Self

👎Deprecated: Use set_icon() instead.
pub fn image(&mut self, val: &str) -> &mut Self

👎Deprecated: Use set_image() instead.
pub fn lang(&mut self, val: &str) -> &mut Self

👎Deprecated: Use set_lang() instead.
pub fn renotify(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_renotify() instead.
pub fn require_interaction(&mut self, val: bool) -> &mut Self

👎Deprecated: Use set_require_interaction() instead.
pub fn silent(&mut self, val: Option<bool>) -> &mut Self

👎Deprecated: Use set_silent() instead.
pub fn tag(&mut self, val: &str) -> &mut Self

👎Deprecated: Use set_tag() instead.
pub fn timestamp(&mut self, val: f64) -> &mut Self

👎Deprecated: Use set_timestamp() instead.
pub fn vibrate(&mut self, val: &JsValue) -> &mut Self

👎Deprecated: Use set_vibrate() instead.

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.