OffscreenCanvasRenderingContext2d

Struct OffscreenCanvasRenderingContext2d 

#[repr(transparent)]
pub struct OffscreenCanvasRenderingContext2d { pub obj: JsValue, }
The OffscreenCanvasRenderingContext2d class.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Fields

obj: JsValue

Implementations

Source

impl OffscreenCanvasRenderingContext2d

pub fn canvas(&self) -> OffscreenCanvas

Getter for the canvas field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn global_alpha(&self) -> f64

Getter for the globalAlpha field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_global_alpha(&self, value: f64)

Setter for the globalAlpha field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn global_composite_operation(&self) -> Result<String, JsValue>

Getter for the globalCompositeOperation field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_global_composite_operation(&self, value: &str) -> Result<(), JsValue>

Setter for the globalCompositeOperation field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn stroke_style(&self) -> JsValue

Getter for the strokeStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_stroke_style(&self, value: &JsValue)

👎Deprecated

Setter for the strokeStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_stroke_style_str(&self, value: &str)

Setter for the strokeStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_stroke_style_canvas_gradient(&self, value: &CanvasGradient)

Setter for the strokeStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: CanvasGradient, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_stroke_style_canvas_pattern(&self, value: &CanvasPattern)

Setter for the strokeStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: CanvasPattern, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill_style(&self) -> JsValue

Getter for the fillStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_fill_style(&self, value: &JsValue)

👎Deprecated

Setter for the fillStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_fill_style_str(&self, value: &str)

Setter for the fillStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_fill_style_canvas_gradient(&self, value: &CanvasGradient)

Setter for the fillStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: CanvasGradient, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_fill_style_canvas_pattern(&self, value: &CanvasPattern)

Setter for the fillStyle field of this object.

MDN Documentation

This API requires the following crate features to be activated: CanvasPattern, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn filter(&self) -> String

Getter for the filter field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_filter(&self, value: &str)

Setter for the filter field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn image_smoothing_enabled(&self) -> bool

Getter for the imageSmoothingEnabled field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_image_smoothing_enabled(&self, value: bool)

Setter for the imageSmoothingEnabled field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn line_width(&self) -> f64

Getter for the lineWidth field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_line_width(&self, value: f64)

Setter for the lineWidth field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn line_cap(&self) -> String

Getter for the lineCap field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_line_cap(&self, value: &str)

Setter for the lineCap field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn line_join(&self) -> String

Getter for the lineJoin field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_line_join(&self, value: &str)

Setter for the lineJoin field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn miter_limit(&self) -> f64

Getter for the miterLimit field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_miter_limit(&self, value: f64)

Setter for the miterLimit field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn line_dash_offset(&self) -> f64

Getter for the lineDashOffset field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_line_dash_offset(&self, value: f64)

Setter for the lineDashOffset field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn shadow_offset_x(&self) -> f64

Getter for the shadowOffsetX field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_shadow_offset_x(&self, value: f64)

Setter for the shadowOffsetX field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn shadow_offset_y(&self) -> f64

Getter for the shadowOffsetY field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_shadow_offset_y(&self, value: f64)

Setter for the shadowOffsetY field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn shadow_blur(&self) -> f64

Getter for the shadowBlur field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_shadow_blur(&self, value: f64)

Setter for the shadowBlur field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn shadow_color(&self) -> String

Getter for the shadowColor field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_shadow_color(&self, value: &str)

Setter for the shadowColor field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn font(&self) -> String

Getter for the font field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_font(&self, value: &str)

Setter for the font field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn text_align(&self) -> String

Getter for the textAlign field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_text_align(&self, value: &str)

Setter for the textAlign field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn text_baseline(&self) -> String

Getter for the textBaseline field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_text_baseline(&self, value: &str)

Setter for the textBaseline field of this object.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_image_element( &self, image: &HtmlImageElement, dx: f64, dy: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlImageElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_canvas_element( &self, image: &HtmlCanvasElement, dx: f64, dy: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCanvasElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_video_element( &self, image: &HtmlVideoElement, dx: f64, dy: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlVideoElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_image_bitmap( &self, image: &ImageBitmap, dx: f64, dy: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmap, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_offscreen_canvas( &self, image: &OffscreenCanvas, dx: f64, dy: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_image_element_and_dw_and_dh( &self, image: &HtmlImageElement, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlImageElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_canvas_element_and_dw_and_dh( &self, image: &HtmlCanvasElement, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCanvasElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_video_element_and_dw_and_dh( &self, image: &HtmlVideoElement, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlVideoElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_image_bitmap_and_dw_and_dh( &self, image: &ImageBitmap, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmap, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_offscreen_canvas_and_dw_and_dh( &self, image: &OffscreenCanvas, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_image_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &HtmlImageElement, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlImageElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_canvas_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &HtmlCanvasElement, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCanvasElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_html_video_element_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &HtmlVideoElement, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlVideoElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_image_bitmap_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &ImageBitmap, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmap, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn draw_image_with_offscreen_canvas_and_sw_and_sh_and_dx_and_dy_and_dw_and_dh( &self, image: &OffscreenCanvas, sx: f64, sy: f64, sw: f64, sh: f64, dx: f64, dy: f64, dw: f64, dh: f64, ) -> Result<(), JsValue>

The drawImage() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvas, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn begin_path(&self)

The beginPath() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn clip(&self)

The clip() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn clip_with_canvas_winding_rule(&self, winding: CanvasWindingRule)

The clip() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn clip_with_path_2d(&self, path: &Path2d)

The clip() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn clip_with_path_2d_and_winding( &self, path: &Path2d, winding: CanvasWindingRule, )

The clip() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill(&self)

The fill() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill_with_canvas_winding_rule(&self, winding: CanvasWindingRule)

The fill() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill_with_path_2d(&self, path: &Path2d)

The fill() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill_with_path_2d_and_winding( &self, path: &Path2d, winding: CanvasWindingRule, )

The fill() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn is_point_in_path_with_f64(&self, x: f64, y: f64) -> bool

The isPointInPath() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn is_point_in_path_with_f64_and_canvas_winding_rule( &self, x: f64, y: f64, winding: CanvasWindingRule, ) -> bool

The isPointInPath() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn is_point_in_path_with_path_2d_and_f64( &self, path: &Path2d, x: f64, y: f64, ) -> bool

The isPointInPath() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn is_point_in_path_with_path_2d_and_f64_and_winding( &self, path: &Path2d, x: f64, y: f64, winding: CanvasWindingRule, ) -> bool

The isPointInPath() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasWindingRule, OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn is_point_in_stroke_with_x_and_y(&self, x: f64, y: f64) -> bool

The isPointInStroke() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn is_point_in_stroke_with_path_and_x_and_y( &self, path: &Path2d, x: f64, y: f64, ) -> bool

The isPointInStroke() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn stroke(&self)

The stroke() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn stroke_with_path(&self, path: &Path2d)

The stroke() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, Path2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_linear_gradient( &self, x0: f64, y0: f64, x1: f64, y1: f64, ) -> CanvasGradient

The createLinearGradient() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasGradient, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_pattern_with_html_image_element( &self, image: &HtmlImageElement, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>

The createPattern() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasPattern, HtmlImageElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_pattern_with_html_canvas_element( &self, image: &HtmlCanvasElement, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>

The createPattern() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasPattern, HtmlCanvasElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_pattern_with_html_video_element( &self, image: &HtmlVideoElement, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>

The createPattern() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasPattern, HtmlVideoElement, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_pattern_with_image_bitmap( &self, image: &ImageBitmap, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>

The createPattern() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasPattern, ImageBitmap, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_pattern_with_offscreen_canvas( &self, image: &OffscreenCanvas, repetition: &str, ) -> Result<Option<CanvasPattern>, JsValue>

The createPattern() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasPattern, OffscreenCanvas, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_radial_gradient( &self, x0: f64, y0: f64, r0: f64, x1: f64, y1: f64, r1: f64, ) -> Result<CanvasGradient, JsValue>

The createRadialGradient() method.

MDN Documentation

This API requires the following crate features to be activated: CanvasGradient, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_image_data_with_sw_and_sh( &self, sw: f64, sh: f64, ) -> Result<ImageData, JsValue>

The createImageData() method.

MDN Documentation

This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn create_image_data_with_imagedata( &self, imagedata: &ImageData, ) -> Result<ImageData, JsValue>

The createImageData() method.

MDN Documentation

This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn get_image_data( &self, sx: f64, sy: f64, sw: f64, sh: f64, ) -> Result<ImageData, JsValue>

The getImageData() method.

MDN Documentation

This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn put_image_data( &self, imagedata: &ImageData, dx: f64, dy: f64, ) -> Result<(), JsValue>

The putImageData() method.

MDN Documentation

This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn put_image_data_with_dirty_x_and_dirty_y_and_dirty_width_and_dirty_height( &self, imagedata: &ImageData, dx: f64, dy: f64, dirty_x: f64, dirty_y: f64, dirty_width: f64, dirty_height: f64, ) -> Result<(), JsValue>

The putImageData() method.

MDN Documentation

This API requires the following crate features to be activated: ImageData, OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn arc( &self, x: f64, y: f64, radius: f64, start_angle: f64, end_angle: f64, ) -> Result<(), JsValue>

The arc() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn arc_with_anticlockwise( &self, x: f64, y: f64, radius: f64, start_angle: f64, end_angle: f64, anticlockwise: bool, ) -> Result<(), JsValue>

The arc() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn arc_to( &self, x1: f64, y1: f64, x2: f64, y2: f64, radius: f64, ) -> Result<(), JsValue>

The arcTo() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn bezier_curve_to( &self, cp1x: f64, cp1y: f64, cp2x: f64, cp2y: f64, x: f64, y: f64, )

The bezierCurveTo() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn close_path(&self)

The closePath() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn ellipse( &self, x: f64, y: f64, radius_x: f64, radius_y: f64, rotation: f64, start_angle: f64, end_angle: f64, ) -> Result<(), JsValue>

The ellipse() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn ellipse_with_anticlockwise( &self, x: f64, y: f64, radius_x: f64, radius_y: f64, rotation: f64, start_angle: f64, end_angle: f64, anticlockwise: bool, ) -> Result<(), JsValue>

The ellipse() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn line_to(&self, x: f64, y: f64)

The lineTo() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn move_to(&self, x: f64, y: f64)

The moveTo() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn quadratic_curve_to(&self, cpx: f64, cpy: f64, x: f64, y: f64)

The quadraticCurveTo() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn rect(&self, x: f64, y: f64, w: f64, h: f64)

The rect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn round_rect(&self, x: f64, y: f64, w: f64, h: f64) -> Result<(), JsValue>

The roundRect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn round_rect_with_f64( &self, x: f64, y: f64, w: f64, h: f64, radii: f64, ) -> Result<(), JsValue>

The roundRect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn round_rect_with_f64_sequence( &self, x: f64, y: f64, w: f64, h: f64, radii: &JsValue, ) -> Result<(), JsValue>

The roundRect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn round_rect_with_dom_point_init_sequence( &self, x: f64, y: f64, w: f64, h: f64, radii: &JsValue, ) -> Result<(), JsValue>

The roundRect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn get_line_dash(&self) -> Array

The getLineDash() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_line_dash(&self, segments: &JsValue) -> Result<(), JsValue>

The setLineDash() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn clear_rect(&self, x: f64, y: f64, w: f64, h: f64)

The clearRect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill_rect(&self, x: f64, y: f64, w: f64, h: f64)

The fillRect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn stroke_rect(&self, x: f64, y: f64, w: f64, h: f64)

The strokeRect() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn reset(&self)

The reset() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn restore(&self)

The restore() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn save(&self)

The save() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill_text(&self, text: &str, x: f64, y: f64) -> Result<(), JsValue>

The fillText() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn fill_text_with_max_width( &self, text: &str, x: f64, y: f64, max_width: f64, ) -> Result<(), JsValue>

The fillText() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn measure_text(&self, text: &str) -> Result<TextMetrics, JsValue>

The measureText() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d, TextMetrics

Source

impl OffscreenCanvasRenderingContext2d

pub fn stroke_text(&self, text: &str, x: f64, y: f64) -> Result<(), JsValue>

The strokeText() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn stroke_text_with_max_width( &self, text: &str, x: f64, y: f64, max_width: f64, ) -> Result<(), JsValue>

The strokeText() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn reset_transform(&self) -> Result<(), JsValue>

The resetTransform() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn rotate(&self, angle: f64) -> Result<(), JsValue>

The rotate() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn scale(&self, x: f64, y: f64) -> Result<(), JsValue>

The scale() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_transform( &self, a: f64, b: f64, c: f64, d: f64, e: f64, f: f64, ) -> Result<(), JsValue>

The setTransform() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn set_transform_with_default_dom_matrix_2d_init( &self, ) -> Result<(), JsValue>

The setTransform() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn transform( &self, a: f64, b: f64, c: f64, d: f64, e: f64, f: f64, ) -> Result<(), JsValue>

The transform() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Source

impl OffscreenCanvasRenderingContext2d

pub fn translate(&self, x: f64, y: f64) -> Result<(), JsValue>

The translate() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvasRenderingContext2d

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.