#[repr(transparent)]pub struct PerformanceTiming {
pub obj: JsValue,
}Expand description
The PerformanceTiming class.
This API requires the following crate features to be activated: PerformanceTiming
Fields
obj: JsValueImplementations
Sourceimpl PerformanceTiming
impl PerformanceTiming
Getter for the navigationStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn unload_event_start(&self) -> f64
pub fn unload_event_start(&self) -> f64
Getter for the unloadEventStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn unload_event_end(&self) -> f64
pub fn unload_event_end(&self) -> f64
Getter for the unloadEventEnd field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn redirect_start(&self) -> f64
pub fn redirect_start(&self) -> f64
Getter for the redirectStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn redirect_end(&self) -> f64
pub fn redirect_end(&self) -> f64
Getter for the redirectEnd field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn fetch_start(&self) -> f64
pub fn fetch_start(&self) -> f64
Getter for the fetchStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn domain_lookup_start(&self) -> f64
pub fn domain_lookup_start(&self) -> f64
Getter for the domainLookupStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn domain_lookup_end(&self) -> f64
pub fn domain_lookup_end(&self) -> f64
Getter for the domainLookupEnd field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn connect_start(&self) -> f64
pub fn connect_start(&self) -> f64
Getter for the connectStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn connect_end(&self) -> f64
pub fn connect_end(&self) -> f64
Getter for the connectEnd field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn secure_connection_start(&self) -> f64
pub fn secure_connection_start(&self) -> f64
Getter for the secureConnectionStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn request_start(&self) -> f64
pub fn request_start(&self) -> f64
Getter for the requestStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn response_start(&self) -> f64
pub fn response_start(&self) -> f64
Getter for the responseStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn response_end(&self) -> f64
pub fn response_end(&self) -> f64
Getter for the responseEnd field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn dom_loading(&self) -> f64
pub fn dom_loading(&self) -> f64
Getter for the domLoading field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn dom_interactive(&self) -> f64
pub fn dom_interactive(&self) -> f64
Getter for the domInteractive field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn dom_content_loaded_event_start(&self) -> f64
pub fn dom_content_loaded_event_start(&self) -> f64
Getter for the domContentLoadedEventStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn dom_content_loaded_event_end(&self) -> f64
pub fn dom_content_loaded_event_end(&self) -> f64
Getter for the domContentLoadedEventEnd field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn dom_complete(&self) -> f64
pub fn dom_complete(&self) -> f64
Getter for the domComplete field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn load_event_start(&self) -> f64
pub fn load_event_start(&self) -> f64
Getter for the loadEventStart field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn load_event_end(&self) -> f64
pub fn load_event_end(&self) -> f64
Getter for the loadEventEnd field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn time_to_non_blank_paint(&self) -> f64
pub fn time_to_non_blank_paint(&self) -> f64
Getter for the timeToNonBlankPaint field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Sourceimpl PerformanceTiming
impl PerformanceTiming
Sourcepub fn time_to_dom_content_flushed(&self) -> f64
pub fn time_to_dom_content_flushed(&self) -> f64
Getter for the timeToDOMContentFlushed field of this object.
This API requires the following crate features to be activated: PerformanceTiming
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.