#[repr(transparent)]pub struct PositionOptions {
pub obj: JsValue,
}Expand description
The PositionOptions dictionary.
This API requires the following crate features to be activated: PositionOptions
Fields
obj: JsValueImplementations
Sourceimpl PositionOptions
impl PositionOptions
Sourcepub fn get_enable_high_accuracy(&self) -> Option<bool>
pub fn get_enable_high_accuracy(&self) -> Option<bool>
Get the enableHighAccuracy field of this object.
This API requires the following crate features to be activated: PositionOptions
Sourceimpl PositionOptions
impl PositionOptions
Sourcepub fn set_enable_high_accuracy(&self, val: bool)
pub fn set_enable_high_accuracy(&self, val: bool)
Change the enableHighAccuracy field of this object.
This API requires the following crate features to be activated: PositionOptions
Sourceimpl PositionOptions
impl PositionOptions
Sourcepub fn get_maximum_age(&self) -> Option<u32>
pub fn get_maximum_age(&self) -> Option<u32>
Get the maximumAge field of this object.
This API requires the following crate features to be activated: PositionOptions
Sourceimpl PositionOptions
impl PositionOptions
Sourcepub fn set_maximum_age(&self, val: u32)
pub fn set_maximum_age(&self, val: u32)
Change the maximumAge field of this object.
This API requires the following crate features to be activated: PositionOptions
Sourceimpl PositionOptions
impl PositionOptions
Sourcepub fn get_timeout(&self) -> Option<u32>
pub fn get_timeout(&self) -> Option<u32>
Get the timeout field of this object.
This API requires the following crate features to be activated: PositionOptions
Sourceimpl PositionOptions
impl PositionOptions
Sourcepub fn set_timeout(&self, val: u32)
pub fn set_timeout(&self, val: u32)
Change the timeout field of this object.
This API requires the following crate features to be activated: PositionOptions
Sourceimpl PositionOptions
impl PositionOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new PositionOptions.
This API requires the following crate features to be activated: PositionOptions
pub fn enable_high_accuracy(&mut self, val: bool) -> &mut Self
set_enable_high_accuracy() instead.pub fn maximum_age(&mut self, val: u32) -> &mut Self
set_maximum_age() instead.pub fn timeout(&mut self, val: u32) -> &mut Self
set_timeout() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.