#[repr(transparent)]pub struct ReadableStream {
pub obj: JsValue,
}Expand description
The ReadableStream class.
This API requires the following crate features to be activated: ReadableStream
Fields
obj: JsValueImplementations
Sourceimpl ReadableStream
impl ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn new() -> Result<ReadableStream, JsValue>
pub fn new() -> Result<ReadableStream, JsValue>
The new ReadableStream(..) constructor, creating a new instance of ReadableStream.
This API requires the following crate features to be activated: ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn new_with_underlying_source(
underlying_source: &Object,
) -> Result<ReadableStream, JsValue>
pub fn new_with_underlying_source( underlying_source: &Object, ) -> Result<ReadableStream, JsValue>
The new ReadableStream(..) constructor, creating a new instance of ReadableStream.
This API requires the following crate features to be activated: ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn new_with_underlying_source_and_strategy(
underlying_source: &Object,
strategy: &QueuingStrategy,
) -> Result<ReadableStream, JsValue>
pub fn new_with_underlying_source_and_strategy( underlying_source: &Object, strategy: &QueuingStrategy, ) -> Result<ReadableStream, JsValue>
The new ReadableStream(..) constructor, creating a new instance of ReadableStream.
This API requires the following crate features to be activated: QueuingStrategy, ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn cancel_with_reason(&self, reason: &JsValue) -> Promise
pub fn cancel_with_reason(&self, reason: &JsValue) -> Promise
The cancel() method.
This API requires the following crate features to be activated: ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn entries(&self) -> AsyncIterator
pub fn entries(&self) -> AsyncIterator
The entries() method.
This API requires the following crate features to be activated: ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn get_reader(&self) -> Object
pub fn get_reader(&self) -> Object
The getReader() method.
This API requires the following crate features to be activated: ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn get_reader_with_options(
&self,
options: &ReadableStreamGetReaderOptions,
) -> Object
pub fn get_reader_with_options( &self, options: &ReadableStreamGetReaderOptions, ) -> Object
The getReader() method.
This API requires the following crate features to be activated: ReadableStream, ReadableStreamGetReaderOptions
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn keys(&self) -> AsyncIterator
pub fn keys(&self) -> AsyncIterator
The keys() method.
This API requires the following crate features to be activated: ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn pipe_through(&self, transform: &ReadableWritablePair) -> ReadableStream
pub fn pipe_through(&self, transform: &ReadableWritablePair) -> ReadableStream
The pipeThrough() method.
This API requires the following crate features to be activated: ReadableStream, ReadableWritablePair
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn pipe_through_with_options(
&self,
transform: &ReadableWritablePair,
options: &StreamPipeOptions,
) -> ReadableStream
pub fn pipe_through_with_options( &self, transform: &ReadableWritablePair, options: &StreamPipeOptions, ) -> ReadableStream
The pipeThrough() method.
This API requires the following crate features to be activated: ReadableStream, ReadableWritablePair, StreamPipeOptions
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn pipe_to(&self, destination: &WritableStream) -> Promise
pub fn pipe_to(&self, destination: &WritableStream) -> Promise
The pipeTo() method.
This API requires the following crate features to be activated: ReadableStream, WritableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn pipe_to_with_options(
&self,
destination: &WritableStream,
options: &StreamPipeOptions,
) -> Promise
pub fn pipe_to_with_options( &self, destination: &WritableStream, options: &StreamPipeOptions, ) -> Promise
The pipeTo() method.
This API requires the following crate features to be activated: ReadableStream, StreamPipeOptions, WritableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourceimpl ReadableStream
impl ReadableStream
Sourcepub fn values(&self) -> AsyncIterator
pub fn values(&self) -> AsyncIterator
The values() method.
This API requires the following crate features to be activated: ReadableStream
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.