Request

Struct Request 

#[repr(transparent)]
pub struct Request { pub obj: JsValue, }
The Request class.

MDN Documentation

This API requires the following crate features to be activated: Request

Fields

obj: JsValue

Implementations

Source

impl Request

pub fn method(&self) -> String

Getter for the method field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn url(&self) -> String

Getter for the url field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn headers(&self) -> Headers

Getter for the headers field of this object.

MDN Documentation

This API requires the following crate features to be activated: Headers, Request

Source

impl Request

pub fn referrer(&self) -> String

Getter for the referrer field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn referrer_policy(&self) -> ReferrerPolicy

Getter for the referrerPolicy field of this object.

MDN Documentation

This API requires the following crate features to be activated: ReferrerPolicy, Request

Source

impl Request

pub fn mode(&self) -> RequestMode

Getter for the mode field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request, RequestMode

Source

impl Request

pub fn credentials(&self) -> RequestCredentials

Getter for the credentials field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request, RequestCredentials

Source

impl Request

pub fn cache(&self) -> RequestCache

Getter for the cache field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request, RequestCache

Source

impl Request

pub fn redirect(&self) -> RequestRedirect

Getter for the redirect field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request, RequestRedirect

Source

impl Request

pub fn integrity(&self) -> String

Getter for the integrity field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn signal(&self) -> AbortSignal

Getter for the signal field of this object.

MDN Documentation

This API requires the following crate features to be activated: AbortSignal, Request

Source

impl Request

pub fn body_used(&self) -> bool

Getter for the bodyUsed field of this object.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn body(&self) -> Option<ReadableStream>

Getter for the body field of this object.

MDN Documentation

This API requires the following crate features to be activated: ReadableStream, Request

Source

impl Request

pub fn new_with_request(input: &Request) -> Result<Request, JsValue>

The new Request(..) constructor, creating a new instance of Request.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn new_with_str(input: &str) -> Result<Request, JsValue>

The new Request(..) constructor, creating a new instance of Request.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn new_with_request_and_init( input: &Request, init: &RequestInit, ) -> Result<Request, JsValue>

The new Request(..) constructor, creating a new instance of Request.

MDN Documentation

This API requires the following crate features to be activated: Request, RequestInit

Source

impl Request

pub fn new_with_str_and_init( input: &str, init: &RequestInit, ) -> Result<Request, JsValue>

The new Request(..) constructor, creating a new instance of Request.

MDN Documentation

This API requires the following crate features to be activated: Request, RequestInit

Source

impl Request

pub fn clone(&self) -> Result<Request, JsValue>

The clone() method.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn array_buffer(&self) -> Result<Promise, JsValue>

The arrayBuffer() method.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn blob(&self) -> Result<Promise, JsValue>

The blob() method.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn form_data(&self) -> Result<Promise, JsValue>

The formData() method.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn json(&self) -> Result<Promise, JsValue>

The json() method.

MDN Documentation

This API requires the following crate features to be activated: Request

Source

impl Request

pub fn text(&self) -> Result<Promise, JsValue>

The text() method.

MDN Documentation

This API requires the following crate features to be activated: Request

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.