#[repr(transparent)]pub struct RequestInit {
pub obj: JsValue,
}Expand description
The RequestInit dictionary.
This API requires the following crate features to be activated: RequestInit
Fields
obj: JsValueImplementations
Sourceimpl RequestInit
impl RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_cache(&self) -> Option<RequestCache>
pub fn get_cache(&self) -> Option<RequestCache>
Get the cache field of this object.
This API requires the following crate features to be activated: RequestCache, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_cache(&self, val: RequestCache)
pub fn set_cache(&self, val: RequestCache)
Change the cache field of this object.
This API requires the following crate features to be activated: RequestCache, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_credentials(&self) -> Option<RequestCredentials>
pub fn get_credentials(&self) -> Option<RequestCredentials>
Get the credentials field of this object.
This API requires the following crate features to be activated: RequestCredentials, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_credentials(&self, val: RequestCredentials)
pub fn set_credentials(&self, val: RequestCredentials)
Change the credentials field of this object.
This API requires the following crate features to be activated: RequestCredentials, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_headers(&self) -> JsValue
pub fn get_headers(&self) -> JsValue
Get the headers field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_headers(&self, val: &JsValue)
pub fn set_headers(&self, val: &JsValue)
Change the headers field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_integrity(&self) -> Option<String>
pub fn get_integrity(&self) -> Option<String>
Get the integrity field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_integrity(&self, val: &str)
pub fn set_integrity(&self, val: &str)
Change the integrity field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_method(&self) -> Option<String>
pub fn get_method(&self) -> Option<String>
Get the method field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_method(&self, val: &str)
pub fn set_method(&self, val: &str)
Change the method field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_mode(&self) -> Option<RequestMode>
pub fn get_mode(&self) -> Option<RequestMode>
Get the mode field of this object.
This API requires the following crate features to be activated: RequestInit, RequestMode
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_mode(&self, val: RequestMode)
pub fn set_mode(&self, val: RequestMode)
Change the mode field of this object.
This API requires the following crate features to be activated: RequestInit, RequestMode
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_observe(&self) -> Option<ObserverCallback>
pub fn get_observe(&self) -> Option<ObserverCallback>
Get the observe field of this object.
This API requires the following crate features to be activated: ObserverCallback, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_observe(&self, val: &ObserverCallback)
pub fn set_observe(&self, val: &ObserverCallback)
Change the observe field of this object.
This API requires the following crate features to be activated: ObserverCallback, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_redirect(&self) -> Option<RequestRedirect>
pub fn get_redirect(&self) -> Option<RequestRedirect>
Get the redirect field of this object.
This API requires the following crate features to be activated: RequestInit, RequestRedirect
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_redirect(&self, val: RequestRedirect)
pub fn set_redirect(&self, val: RequestRedirect)
Change the redirect field of this object.
This API requires the following crate features to be activated: RequestInit, RequestRedirect
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_referrer(&self) -> Option<String>
pub fn get_referrer(&self) -> Option<String>
Get the referrer field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_referrer(&self, val: &str)
pub fn set_referrer(&self, val: &str)
Change the referrer field of this object.
This API requires the following crate features to be activated: RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_referrer_policy(&self) -> Option<ReferrerPolicy>
pub fn get_referrer_policy(&self) -> Option<ReferrerPolicy>
Get the referrerPolicy field of this object.
This API requires the following crate features to be activated: ReferrerPolicy, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_referrer_policy(&self, val: ReferrerPolicy)
pub fn set_referrer_policy(&self, val: ReferrerPolicy)
Change the referrerPolicy field of this object.
This API requires the following crate features to be activated: ReferrerPolicy, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn get_signal(&self) -> Option<AbortSignal>
pub fn get_signal(&self) -> Option<AbortSignal>
Get the signal field of this object.
This API requires the following crate features to be activated: AbortSignal, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn set_signal(&self, val: Option<&AbortSignal>)
pub fn set_signal(&self, val: Option<&AbortSignal>)
Change the signal field of this object.
This API requires the following crate features to be activated: AbortSignal, RequestInit
Sourceimpl RequestInit
impl RequestInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new RequestInit.
This API requires the following crate features to be activated: RequestInit
pub fn body(&mut self, val: Option<&JsValue>) -> &mut Self
set_body() instead.pub fn cache(&mut self, val: RequestCache) -> &mut Self
set_cache() instead.pub fn credentials(&mut self, val: RequestCredentials) -> &mut Self
set_credentials() instead.pub fn headers(&mut self, val: &JsValue) -> &mut Self
set_headers() instead.pub fn integrity(&mut self, val: &str) -> &mut Self
set_integrity() instead.pub fn method(&mut self, val: &str) -> &mut Self
set_method() instead.pub fn mode(&mut self, val: RequestMode) -> &mut Self
set_mode() instead.pub fn observe(&mut self, val: &ObserverCallback) -> &mut Self
set_observe() instead.pub fn redirect(&mut self, val: RequestRedirect) -> &mut Self
set_redirect() instead.pub fn referrer(&mut self, val: &str) -> &mut Self
set_referrer() instead.pub fn referrer_policy(&mut self, val: ReferrerPolicy) -> &mut Self
set_referrer_policy() instead.pub fn signal(&mut self, val: Option<&AbortSignal>) -> &mut Self
set_signal() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.