ShadowRoot

Struct ShadowRoot 

#[repr(transparent)]
pub struct ShadowRoot { pub obj: JsValue, }
The ShadowRoot class.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot

Fields

obj: JsValue

Implementations

Source

impl ShadowRoot

pub fn mode(&self) -> ShadowRootMode

Getter for the mode field of this object.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot, ShadowRootMode

Source

impl ShadowRoot

pub fn host(&self) -> Element

Getter for the host field of this object.

MDN Documentation

This API requires the following crate features to be activated: Element, ShadowRoot

Source

impl ShadowRoot

pub fn inner_html(&self) -> String

Getter for the innerHTML field of this object.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot

Source

impl ShadowRoot

pub fn set_inner_html(&self, value: &str)

Setter for the innerHTML field of this object.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot

Source

impl ShadowRoot

pub fn active_element(&self) -> Option<Element>

Getter for the activeElement field of this object.

MDN Documentation

This API requires the following crate features to be activated: Element, ShadowRoot

Source

impl ShadowRoot

pub fn pointer_lock_element(&self) -> Option<Element>

Getter for the pointerLockElement field of this object.

MDN Documentation

This API requires the following crate features to be activated: Element, ShadowRoot

Source

impl ShadowRoot

pub fn fullscreen_element(&self) -> Option<Element>

Getter for the fullscreenElement field of this object.

MDN Documentation

This API requires the following crate features to be activated: Element, ShadowRoot

Source

impl ShadowRoot

pub fn style_sheets(&self) -> StyleSheetList

Getter for the styleSheets field of this object.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot, StyleSheetList

Source

impl ShadowRoot

pub fn adopted_style_sheets(&self) -> Array

Getter for the adoptedStyleSheets field of this object.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot

Source

impl ShadowRoot

pub fn set_adopted_style_sheets(&self, value: &JsValue)

Setter for the adoptedStyleSheets field of this object.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot

Source

impl ShadowRoot

pub fn picture_in_picture_element(&self) -> Option<Element>

Getter for the pictureInPictureElement field of this object.

MDN Documentation

This API requires the following crate features to be activated: Element, ShadowRoot

This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as described in the wasm-bindgen guide

Source

impl ShadowRoot

pub fn get_element_by_id(&self, element_id: &str) -> Option<Element>

The getElementById() method.

MDN Documentation

This API requires the following crate features to be activated: Element, ShadowRoot

Source

impl ShadowRoot

pub fn get_elements_by_class_name(&self, class_names: &str) -> HtmlCollection

The getElementsByClassName() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCollection, ShadowRoot

Source

impl ShadowRoot

pub fn get_elements_by_tag_name(&self, local_name: &str) -> HtmlCollection

The getElementsByTagName() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCollection, ShadowRoot

Source

impl ShadowRoot

pub fn get_elements_by_tag_name_ns( &self, namespace: Option<&str>, local_name: &str, ) -> HtmlCollection

The getElementsByTagNameNS() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCollection, ShadowRoot

Source

impl ShadowRoot

pub fn element_from_point(&self, x: f32, y: f32) -> Option<Element>

The elementFromPoint() method.

MDN Documentation

This API requires the following crate features to be activated: Element, ShadowRoot

Source

impl ShadowRoot

pub fn elements_from_point(&self, x: f32, y: f32) -> Array

The elementsFromPoint() method.

MDN Documentation

This API requires the following crate features to be activated: ShadowRoot

Methods from Deref<Target = DocumentFragment>

pub fn children(&self) -> HtmlCollection

Getter for the children field of this object.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, HtmlCollection

pub fn first_element_child(&self) -> Option<Element>

Getter for the firstElementChild field of this object.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, Element

pub fn last_element_child(&self) -> Option<Element>

Getter for the lastElementChild field of this object.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, Element

pub fn child_element_count(&self) -> u32

Getter for the childElementCount field of this object.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn get_element_by_id(&self, element_id: &str) -> Option<Element>

The getElementById() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, Element

pub fn query_selector( &self, selectors: &str, ) -> Result<Option<Element>, JsValue>

The querySelector() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, Element

pub fn query_selector_all(&self, selectors: &str) -> Result<NodeList, JsValue>

The querySelectorAll() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment, NodeList

pub fn append_with_node(&self, nodes: &Array) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_0(&self) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str(&self, nodes: &Array) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_0(&self) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn append_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

The append() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node(&self, nodes: &Array) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_0(&self) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str(&self, nodes: &Array) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_0(&self) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn prepend_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>

The prepend() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node(&self, nodes: &Array)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_0(&self)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_1(&self, nodes_1: &Node)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_2(&self, nodes_1: &Node, nodes_2: &Node)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str(&self, nodes: &Array)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_0(&self)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_1(&self, nodes_1: &str)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_2(&self, nodes_1: &str, nodes_2: &str)

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

pub fn replace_children_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, )

The replaceChildren() method.

MDN Documentation

This API requires the following crate features to be activated: DocumentFragment

Methods from Deref<Target = Node>

pub fn node_type(&self) -> u16

Getter for the nodeType field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn node_name(&self) -> String

Getter for the nodeName field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn base_uri(&self) -> Result<Option<String>, JsValue>

Getter for the baseURI field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn is_connected(&self) -> bool

Getter for the isConnected field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn owner_document(&self) -> Option<Document>

Getter for the ownerDocument field of this object.

MDN Documentation

This API requires the following crate features to be activated: Document, Node

pub fn parent_node(&self) -> Option<Node>

Getter for the parentNode field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn parent_element(&self) -> Option<Element>

Getter for the parentElement field of this object.

MDN Documentation

This API requires the following crate features to be activated: Element, Node

pub fn child_nodes(&self) -> NodeList

Getter for the childNodes field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node, NodeList

pub fn first_child(&self) -> Option<Node>

Getter for the firstChild field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn last_child(&self) -> Option<Node>

Getter for the lastChild field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn previous_sibling(&self) -> Option<Node>

Getter for the previousSibling field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn next_sibling(&self) -> Option<Node>

Getter for the nextSibling field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn node_value(&self) -> Option<String>

Getter for the nodeValue field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn set_node_value(&self, value: Option<&str>)

Setter for the nodeValue field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn text_content(&self) -> Option<String>

Getter for the textContent field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn set_text_content(&self, value: Option<&str>)

Setter for the textContent field of this object.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn append_child(&self, node: &Node) -> Result<Node, JsValue>

The appendChild() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn clone_node(&self) -> Result<Node, JsValue>

The cloneNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>

The cloneNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn compare_document_position(&self, other: &Node) -> u16

The compareDocumentPosition() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn contains(&self, other: Option<&Node>) -> bool

The contains() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn get_root_node(&self) -> Node

The getRootNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn has_child_nodes(&self) -> bool

The hasChildNodes() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn insert_before( &self, node: &Node, child: Option<&Node>, ) -> Result<Node, JsValue>

The insertBefore() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool

The isDefaultNamespace() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn is_equal_node(&self, node: Option<&Node>) -> bool

The isEqualNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn is_same_node(&self, node: Option<&Node>) -> bool

The isSameNode() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>

The lookupNamespaceURI() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>

The lookupPrefix() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn normalize(&self)

The normalize() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>

The removeChild() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>

The replaceChild() method.

MDN Documentation

This API requires the following crate features to be activated: Node

pub const ELEMENT_NODE: u16 = 1u16

pub const ATTRIBUTE_NODE: u16 = 2u16

pub const TEXT_NODE: u16 = 3u16

pub const CDATA_SECTION_NODE: u16 = 4u16

pub const ENTITY_REFERENCE_NODE: u16 = 5u16

pub const ENTITY_NODE: u16 = 6u16

pub const PROCESSING_INSTRUCTION_NODE: u16 = 7u16

pub const COMMENT_NODE: u16 = 8u16

pub const DOCUMENT_NODE: u16 = 9u16

pub const DOCUMENT_TYPE_NODE: u16 = 10u16

pub const DOCUMENT_FRAGMENT_NODE: u16 = 11u16

pub const NOTATION_NODE: u16 = 12u16

pub const DOCUMENT_POSITION_DISCONNECTED: u16 = 1u16

pub const DOCUMENT_POSITION_PRECEDING: u16 = 2u16

pub const DOCUMENT_POSITION_FOLLOWING: u16 = 4u16

pub const DOCUMENT_POSITION_CONTAINS: u16 = 8u16

pub const DOCUMENT_POSITION_CONTAINED_BY: u16 = 16u16

pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16 = 32u16

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

The dispatchEvent() method.

MDN Documentation

This API requires the following crate features to be activated: Event, EventTarget

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListenerOptions, EventTarget

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.