SharedWorkerGlobalScope

Struct SharedWorkerGlobalScope 

#[repr(transparent)]
pub struct SharedWorkerGlobalScope { pub obj: JsValue, }
The SharedWorkerGlobalScope class.

MDN Documentation

This API requires the following crate features to be activated: SharedWorkerGlobalScope

Fields

obj: JsValue

Implementations

Source

impl SharedWorkerGlobalScope

pub fn name(&self) -> String

Getter for the name field of this object.

MDN Documentation

This API requires the following crate features to be activated: SharedWorkerGlobalScope

Source

impl SharedWorkerGlobalScope

pub fn onconnect(&self) -> Option<Function>

Getter for the onconnect field of this object.

MDN Documentation

This API requires the following crate features to be activated: SharedWorkerGlobalScope

Source

impl SharedWorkerGlobalScope

pub fn set_onconnect(&self, value: Option<&Function>)

Setter for the onconnect field of this object.

MDN Documentation

This API requires the following crate features to be activated: SharedWorkerGlobalScope

Source

impl SharedWorkerGlobalScope

pub fn close(&self)

The close() method.

MDN Documentation

This API requires the following crate features to be activated: SharedWorkerGlobalScope

Methods from Deref<Target = WorkerGlobalScope>

pub fn self_(&self) -> WorkerGlobalScope

Getter for the self field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn location(&self) -> WorkerLocation

Getter for the location field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope, WorkerLocation

pub fn navigator(&self) -> WorkerNavigator

Getter for the navigator field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope, WorkerNavigator

pub fn onerror(&self) -> Option<Function>

Getter for the onerror field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_onerror(&self, value: Option<&Function>)

Setter for the onerror field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn onoffline(&self) -> Option<Function>

Getter for the onoffline field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_onoffline(&self, value: Option<&Function>)

Setter for the onoffline field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn ononline(&self) -> Option<Function>

Getter for the ononline field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_ononline(&self, value: Option<&Function>)

Setter for the ononline field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn crypto(&self) -> Result<Crypto, JsValue>

Getter for the crypto field of this object.

MDN Documentation

This API requires the following crate features to be activated: Crypto, WorkerGlobalScope

pub fn indexed_db(&self) -> Result<Option<IdbFactory>, JsValue>

Getter for the indexedDB field of this object.

MDN Documentation

This API requires the following crate features to be activated: IdbFactory, WorkerGlobalScope

pub fn performance(&self) -> Option<Performance>

Getter for the performance field of this object.

MDN Documentation

This API requires the following crate features to be activated: Performance, WorkerGlobalScope

pub fn origin(&self) -> String

Getter for the origin field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn is_secure_context(&self) -> bool

Getter for the isSecureContext field of this object.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn caches(&self) -> Result<CacheStorage, JsValue>

Getter for the caches field of this object.

MDN Documentation

This API requires the following crate features to be activated: CacheStorage, WorkerGlobalScope

pub fn import_scripts(&self, urls: &Array) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_0(&self) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_1(&self, urls_1: &str) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_2( &self, urls_1: &str, urls_2: &str, ) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_3( &self, urls_1: &str, urls_2: &str, urls_3: &str, ) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_4( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, ) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_5( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, ) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_6( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, urls_6: &str, ) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn import_scripts_7( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, urls_6: &str, urls_7: &str, ) -> Result<(), JsValue>

The importScripts() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn atob(&self, atob: &str) -> Result<String, JsValue>

The atob() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn btoa(&self, btoa: &str) -> Result<String, JsValue>

The btoa() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn clear_interval(&self)

The clearInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn clear_interval_with_handle(&self, handle: i32)

The clearInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn clear_timeout(&self)

The clearTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn clear_timeout_with_handle(&self, handle: i32)

The clearTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn create_image_bitmap_with_html_image_element( &self, a_image: &HtmlImageElement, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlImageElement, WorkerGlobalScope

pub fn create_image_bitmap_with_html_canvas_element( &self, a_image: &HtmlCanvasElement, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCanvasElement, WorkerGlobalScope

pub fn create_image_bitmap_with_html_video_element( &self, a_image: &HtmlVideoElement, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlVideoElement, WorkerGlobalScope

pub fn create_image_bitmap_with_image_bitmap( &self, a_image: &ImageBitmap, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmap, WorkerGlobalScope

pub fn create_image_bitmap_with_offscreen_canvas( &self, a_image: &OffscreenCanvas, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvas, WorkerGlobalScope

pub fn create_image_bitmap_with_blob( &self, a_image: &Blob, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: Blob, WorkerGlobalScope

pub fn create_image_bitmap_with_image_data( &self, a_image: &ImageData, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageData, WorkerGlobalScope

pub fn create_image_bitmap_with_html_image_element_and_image_bitmap_options( &self, a_image: &HtmlImageElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlImageElement, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_html_canvas_element_and_image_bitmap_options( &self, a_image: &HtmlCanvasElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCanvasElement, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_html_video_element_and_image_bitmap_options( &self, a_image: &HtmlVideoElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlVideoElement, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_image_bitmap_and_image_bitmap_options( &self, a_image: &ImageBitmap, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmap, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_offscreen_canvas_and_image_bitmap_options( &self, a_image: &OffscreenCanvas, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmapOptions, OffscreenCanvas, WorkerGlobalScope

pub fn create_image_bitmap_with_blob_and_image_bitmap_options( &self, a_image: &Blob, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: Blob, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_image_data_and_image_bitmap_options( &self, a_image: &ImageData, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmapOptions, ImageData, WorkerGlobalScope

pub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlImageElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlImageElement, WorkerGlobalScope

pub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlCanvasElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCanvasElement, WorkerGlobalScope

pub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlVideoElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlVideoElement, WorkerGlobalScope

pub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &ImageBitmap, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmap, WorkerGlobalScope

pub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &OffscreenCanvas, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: OffscreenCanvas, WorkerGlobalScope

pub fn create_image_bitmap_with_blob_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &Blob, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: Blob, WorkerGlobalScope

pub fn create_image_bitmap_with_image_data_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &ImageData, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageData, WorkerGlobalScope

pub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlImageElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlImageElement, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlCanvasElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlCanvasElement, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlVideoElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: HtmlVideoElement, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &ImageBitmap, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmap, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &OffscreenCanvas, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmapOptions, OffscreenCanvas, WorkerGlobalScope

pub fn create_image_bitmap_with_blob_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &Blob, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: Blob, ImageBitmapOptions, WorkerGlobalScope

pub fn create_image_bitmap_with_image_data_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &ImageData, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>

The createImageBitmap() method.

MDN Documentation

This API requires the following crate features to be activated: ImageBitmapOptions, ImageData, WorkerGlobalScope

pub fn fetch_with_request(&self, input: &Request) -> Promise

The fetch() method.

MDN Documentation

This API requires the following crate features to be activated: Request, WorkerGlobalScope

pub fn fetch_with_str(&self, input: &str) -> Promise

The fetch() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn fetch_with_request_and_init( &self, input: &Request, init: &RequestInit, ) -> Promise

The fetch() method.

MDN Documentation

This API requires the following crate features to be activated: Request, RequestInit, WorkerGlobalScope

pub fn fetch_with_str_and_init( &self, input: &str, init: &RequestInit, ) -> Promise

The fetch() method.

MDN Documentation

This API requires the following crate features to be activated: RequestInit, WorkerGlobalScope

pub fn queue_microtask(&self, callback: &Function)

The queueMicrotask() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback( &self, handler: &Function, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, arguments: &Array, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_0( &self, handler: &Function, timeout: i32, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str(&self, handler: &str) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_0( &self, handler: &str, timeout: i32, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_interval_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>

The setInterval() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback( &self, handler: &Function, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, arguments: &Array, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_0( &self, handler: &Function, timeout: i32, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str(&self, handler: &str) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_0( &self, handler: &str, timeout: i32, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

pub fn set_timeout_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>

The setTimeout() method.

MDN Documentation

This API requires the following crate features to be activated: WorkerGlobalScope

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

The dispatchEvent() method.

MDN Documentation

This API requires the following crate features to be activated: Event, EventTarget

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListenerOptions, EventTarget

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.