#[repr(transparent)]pub struct StreamPipeOptions {
pub obj: JsValue,
}Expand description
The StreamPipeOptions dictionary.
This API requires the following crate features to be activated: StreamPipeOptions
Fields
obj: JsValueImplementations
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn get_prevent_abort(&self) -> Option<bool>
pub fn get_prevent_abort(&self) -> Option<bool>
Get the preventAbort field of this object.
This API requires the following crate features to be activated: StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn set_prevent_abort(&self, val: bool)
pub fn set_prevent_abort(&self, val: bool)
Change the preventAbort field of this object.
This API requires the following crate features to be activated: StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn get_prevent_cancel(&self) -> Option<bool>
pub fn get_prevent_cancel(&self) -> Option<bool>
Get the preventCancel field of this object.
This API requires the following crate features to be activated: StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn set_prevent_cancel(&self, val: bool)
pub fn set_prevent_cancel(&self, val: bool)
Change the preventCancel field of this object.
This API requires the following crate features to be activated: StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn get_prevent_close(&self) -> Option<bool>
pub fn get_prevent_close(&self) -> Option<bool>
Get the preventClose field of this object.
This API requires the following crate features to be activated: StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn set_prevent_close(&self, val: bool)
pub fn set_prevent_close(&self, val: bool)
Change the preventClose field of this object.
This API requires the following crate features to be activated: StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn get_signal(&self) -> Option<AbortSignal>
pub fn get_signal(&self) -> Option<AbortSignal>
Get the signal field of this object.
This API requires the following crate features to be activated: AbortSignal, StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn set_signal(&self, val: &AbortSignal)
pub fn set_signal(&self, val: &AbortSignal)
Change the signal field of this object.
This API requires the following crate features to be activated: AbortSignal, StreamPipeOptions
Sourceimpl StreamPipeOptions
impl StreamPipeOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new StreamPipeOptions.
This API requires the following crate features to be activated: StreamPipeOptions
pub fn prevent_abort(&mut self, val: bool) -> &mut Self
set_prevent_abort() instead.pub fn prevent_cancel(&mut self, val: bool) -> &mut Self
set_prevent_cancel() instead.pub fn prevent_close(&mut self, val: bool) -> &mut Self
set_prevent_close() instead.pub fn signal(&mut self, val: &AbortSignal) -> &mut Self
set_signal() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.