#[repr(transparent)]pub struct SubtleCrypto {
pub obj: JsValue,
}Expand description
The SubtleCrypto class.
This API requires the following crate features to be activated: SubtleCrypto
Fields
obj: JsValueImplementations
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn decrypt_with_object_and_js_u8_array(
&self,
algorithm: &Object,
key: &CryptoKey,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn decrypt_with_object_and_js_u8_array( &self, algorithm: &Object, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>
The decrypt() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn decrypt_with_str_and_js_u8_array(
&self,
algorithm: &str,
key: &CryptoKey,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn decrypt_with_str_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>
The decrypt() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn derive_key_with_object_and_object(
&self,
algorithm: &Object,
base_key: &CryptoKey,
derived_key_type: &Object,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn derive_key_with_object_and_object( &self, algorithm: &Object, base_key: &CryptoKey, derived_key_type: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The deriveKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn digest_with_object_and_js_u8_array(
&self,
algorithm: &Object,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn digest_with_object_and_js_u8_array( &self, algorithm: &Object, data: &Uint8Array, ) -> Result<Promise, JsValue>
The digest() method.
This API requires the following crate features to be activated: SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn digest_with_str_and_js_u8_array(
&self,
algorithm: &str,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn digest_with_str_and_js_u8_array( &self, algorithm: &str, data: &Uint8Array, ) -> Result<Promise, JsValue>
The digest() method.
This API requires the following crate features to be activated: SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn encrypt_with_object_and_js_u8_array(
&self,
algorithm: &Object,
key: &CryptoKey,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn encrypt_with_object_and_js_u8_array( &self, algorithm: &Object, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>
The encrypt() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn encrypt_with_str_and_js_u8_array(
&self,
algorithm: &str,
key: &CryptoKey,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn encrypt_with_str_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>
The encrypt() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn sign_with_object_and_js_u8_array(
&self,
algorithm: &Object,
key: &CryptoKey,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn sign_with_object_and_js_u8_array( &self, algorithm: &Object, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>
The sign() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn sign_with_str_and_js_u8_array(
&self,
algorithm: &str,
key: &CryptoKey,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn sign_with_str_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, data: &Uint8Array, ) -> Result<Promise, JsValue>
The sign() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_buffer_source_and_object_and_object(
&self,
format: &str,
wrapped_key: &Object,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &Object,
unwrapped_key_algorithm: &Object,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_buffer_source_and_object_and_object( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_u8_array_and_object_and_object(
&self,
format: &str,
wrapped_key: &[u8],
unwrapping_key: &CryptoKey,
unwrap_algorithm: &Object,
unwrapped_key_algorithm: &Object,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_u8_array_and_object_and_object( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_js_u8_array_and_object_and_object(
&self,
format: &str,
wrapped_key: &Uint8Array,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &Object,
unwrapped_key_algorithm: &Object,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_js_u8_array_and_object_and_object( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_buffer_source_and_str_and_object(
&self,
format: &str,
wrapped_key: &Object,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &str,
unwrapped_key_algorithm: &Object,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_buffer_source_and_str_and_object( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_u8_array_and_str_and_object(
&self,
format: &str,
wrapped_key: &[u8],
unwrapping_key: &CryptoKey,
unwrap_algorithm: &str,
unwrapped_key_algorithm: &Object,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_u8_array_and_str_and_object( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_js_u8_array_and_str_and_object(
&self,
format: &str,
wrapped_key: &Uint8Array,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &str,
unwrapped_key_algorithm: &Object,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_js_u8_array_and_str_and_object( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &Object, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_buffer_source_and_object_and_str(
&self,
format: &str,
wrapped_key: &Object,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &Object,
unwrapped_key_algorithm: &str,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_buffer_source_and_object_and_str( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_u8_array_and_object_and_str(
&self,
format: &str,
wrapped_key: &[u8],
unwrapping_key: &CryptoKey,
unwrap_algorithm: &Object,
unwrapped_key_algorithm: &str,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_u8_array_and_object_and_str( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_js_u8_array_and_object_and_str(
&self,
format: &str,
wrapped_key: &Uint8Array,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &Object,
unwrapped_key_algorithm: &str,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_js_u8_array_and_object_and_str( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &Object, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_buffer_source_and_str_and_str(
&self,
format: &str,
wrapped_key: &Object,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &str,
unwrapped_key_algorithm: &str,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_buffer_source_and_str_and_str( &self, format: &str, wrapped_key: &Object, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_u8_array_and_str_and_str(
&self,
format: &str,
wrapped_key: &[u8],
unwrapping_key: &CryptoKey,
unwrap_algorithm: &str,
unwrapped_key_algorithm: &str,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_u8_array_and_str_and_str( &self, format: &str, wrapped_key: &[u8], unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn unwrap_key_with_js_u8_array_and_str_and_str(
&self,
format: &str,
wrapped_key: &Uint8Array,
unwrapping_key: &CryptoKey,
unwrap_algorithm: &str,
unwrapped_key_algorithm: &str,
extractable: bool,
key_usages: &JsValue,
) -> Result<Promise, JsValue>
pub fn unwrap_key_with_js_u8_array_and_str_and_str( &self, format: &str, wrapped_key: &Uint8Array, unwrapping_key: &CryptoKey, unwrap_algorithm: &str, unwrapped_key_algorithm: &str, extractable: bool, key_usages: &JsValue, ) -> Result<Promise, JsValue>
The unwrapKey() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_object_and_js_u8_array_and_buffer_source(
&self,
algorithm: &Object,
key: &CryptoKey,
signature: &Uint8Array,
data: &Object,
) -> Result<Promise, JsValue>
pub fn verify_with_object_and_js_u8_array_and_buffer_source( &self, algorithm: &Object, key: &CryptoKey, signature: &Uint8Array, data: &Object, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_str_and_js_u8_array_and_buffer_source(
&self,
algorithm: &str,
key: &CryptoKey,
signature: &Uint8Array,
data: &Object,
) -> Result<Promise, JsValue>
pub fn verify_with_str_and_js_u8_array_and_buffer_source( &self, algorithm: &str, key: &CryptoKey, signature: &Uint8Array, data: &Object, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_object_and_u8_array_and_u8_slice(
&self,
algorithm: &Object,
key: &CryptoKey,
signature: &Uint8Array,
data: &[u8],
) -> Result<Promise, JsValue>
pub fn verify_with_object_and_u8_array_and_u8_slice( &self, algorithm: &Object, key: &CryptoKey, signature: &Uint8Array, data: &[u8], ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_str_and_u8_array_and_u8_slice(
&self,
algorithm: &str,
key: &CryptoKey,
signature: &Uint8Array,
data: &[u8],
) -> Result<Promise, JsValue>
pub fn verify_with_str_and_u8_array_and_u8_slice( &self, algorithm: &str, key: &CryptoKey, signature: &Uint8Array, data: &[u8], ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_object_and_buffer_source_and_js_u8_array(
&self,
algorithm: &Object,
key: &CryptoKey,
signature: &Object,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn verify_with_object_and_buffer_source_and_js_u8_array( &self, algorithm: &Object, key: &CryptoKey, signature: &Object, data: &Uint8Array, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_str_and_buffer_source_and_js_u8_array(
&self,
algorithm: &str,
key: &CryptoKey,
signature: &Object,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn verify_with_str_and_buffer_source_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &Object, data: &Uint8Array, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_object_and_u8_slice_and_u8_array(
&self,
algorithm: &Object,
key: &CryptoKey,
signature: &[u8],
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn verify_with_object_and_u8_slice_and_u8_array( &self, algorithm: &Object, key: &CryptoKey, signature: &[u8], data: &Uint8Array, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_str_and_u8_slice_and_u8_array(
&self,
algorithm: &str,
key: &CryptoKey,
signature: &[u8],
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn verify_with_str_and_u8_slice_and_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &[u8], data: &Uint8Array, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_object_and_js_u8_array_and_js_u8_array(
&self,
algorithm: &Object,
key: &CryptoKey,
signature: &Uint8Array,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn verify_with_object_and_js_u8_array_and_js_u8_array( &self, algorithm: &Object, key: &CryptoKey, signature: &Uint8Array, data: &Uint8Array, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Sourcepub fn verify_with_str_and_js_u8_array_and_js_u8_array(
&self,
algorithm: &str,
key: &CryptoKey,
signature: &Uint8Array,
data: &Uint8Array,
) -> Result<Promise, JsValue>
pub fn verify_with_str_and_js_u8_array_and_js_u8_array( &self, algorithm: &str, key: &CryptoKey, signature: &Uint8Array, data: &Uint8Array, ) -> Result<Promise, JsValue>
The verify() method.
This API requires the following crate features to be activated: CryptoKey, SubtleCrypto
Sourceimpl SubtleCrypto
impl SubtleCrypto
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.