#[repr(transparent)]pub struct Transformer {
pub obj: JsValue,
}Expand description
The Transformer dictionary.
This API requires the following crate features to be activated: Transformer
Fields
obj: JsValueImplementations
Sourceimpl Transformer
impl Transformer
Sourceimpl Transformer
impl Transformer
Sourceimpl Transformer
impl Transformer
Sourcepub fn get_readable_type(&self) -> JsValue
pub fn get_readable_type(&self) -> JsValue
Get the readableType field of this object.
This API requires the following crate features to be activated: Transformer
Sourceimpl Transformer
impl Transformer
Sourcepub fn set_readable_type(&self, val: &JsValue)
pub fn set_readable_type(&self, val: &JsValue)
Change the readableType field of this object.
This API requires the following crate features to be activated: Transformer
Sourceimpl Transformer
impl Transformer
Sourceimpl Transformer
impl Transformer
Sourceimpl Transformer
impl Transformer
Sourcepub fn get_transform(&self) -> Option<Function>
pub fn get_transform(&self) -> Option<Function>
Get the transform field of this object.
This API requires the following crate features to be activated: Transformer
Sourceimpl Transformer
impl Transformer
Sourcepub fn set_transform(&self, val: &Function)
pub fn set_transform(&self, val: &Function)
Change the transform field of this object.
This API requires the following crate features to be activated: Transformer
Sourceimpl Transformer
impl Transformer
Sourcepub fn get_writable_type(&self) -> JsValue
pub fn get_writable_type(&self) -> JsValue
Get the writableType field of this object.
This API requires the following crate features to be activated: Transformer
Sourceimpl Transformer
impl Transformer
Sourcepub fn set_writable_type(&self, val: &JsValue)
pub fn set_writable_type(&self, val: &JsValue)
Change the writableType field of this object.
This API requires the following crate features to be activated: Transformer
Sourceimpl Transformer
impl Transformer
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new Transformer.
This API requires the following crate features to be activated: Transformer
pub fn flush(&mut self, val: &Function) -> &mut Self
set_flush() instead.pub fn readable_type(&mut self, val: &JsValue) -> &mut Self
set_readable_type() instead.pub fn start(&mut self, val: &Function) -> &mut Self
set_start() instead.pub fn transform(&mut self, val: &Function) -> &mut Self
set_transform() instead.pub fn writable_type(&mut self, val: &JsValue) -> &mut Self
set_writable_type() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.