#[repr(transparent)]pub struct WakeLockSentinel {
pub obj: JsValue,
}Expand description
The WakeLockSentinel class.
This API requires the following crate features to be activated: WakeLockSentinel
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Fields
obj: JsValueImplementations
Sourceimpl WakeLockSentinel
impl WakeLockSentinel
Sourcepub fn released(&self) -> bool
pub fn released(&self) -> bool
Getter for the released field of this object.
This API requires the following crate features to be activated: WakeLockSentinel
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourceimpl WakeLockSentinel
impl WakeLockSentinel
Sourcepub fn onrelease(&self) -> Option<Function>
pub fn onrelease(&self) -> Option<Function>
Getter for the onrelease field of this object.
This API requires the following crate features to be activated: WakeLockSentinel
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourceimpl WakeLockSentinel
impl WakeLockSentinel
Sourcepub fn set_onrelease(&self, value: Option<&Function>)
pub fn set_onrelease(&self, value: Option<&Function>)
Setter for the onrelease field of this object.
This API requires the following crate features to be activated: WakeLockSentinel
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Sourceimpl WakeLockSentinel
impl WakeLockSentinel
Sourcepub fn release(&self) -> Promise
pub fn release(&self) -> Promise
The release() method.
This API requires the following crate features to be activated: WakeLockSentinel
This API is unstable and requires --cfg=web_sys_unstable_apis to be activated, as
described in the wasm-bindgen guide
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn remove_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.