XmlHttpRequest

Struct XmlHttpRequest 

#[repr(transparent)]
pub struct XmlHttpRequest { pub obj: JsValue, }
The XmlHttpRequest class.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Fields

obj: JsValue

Implementations

Source

impl XmlHttpRequest

pub fn onreadystatechange(&self) -> Option<Function>

Getter for the onreadystatechange field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn set_onreadystatechange(&self, value: Option<&Function>)

Setter for the onreadystatechange field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn ready_state(&self) -> u16

Getter for the readyState field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn timeout(&self) -> u32

Getter for the timeout field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn set_timeout(&self, value: u32)

Setter for the timeout field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn with_credentials(&self) -> bool

Getter for the withCredentials field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn set_with_credentials(&self, value: bool)

Setter for the withCredentials field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn response_url(&self) -> String

Getter for the responseURL field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn status(&self) -> Result<u16, JsValue>

Getter for the status field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn status_text(&self) -> Result<String, JsValue>

Getter for the statusText field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn response_type(&self) -> XmlHttpRequestResponseType

Getter for the responseType field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest, XmlHttpRequestResponseType

Source

impl XmlHttpRequest

pub fn set_response_type(&self, value: XmlHttpRequestResponseType)

Setter for the responseType field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest, XmlHttpRequestResponseType

Source

impl XmlHttpRequest

pub fn response(&self) -> Result<JsValue, JsValue>

Getter for the response field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn response_text(&self) -> Result<Option<String>, JsValue>

Getter for the responseText field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn response_xml(&self) -> Result<Option<Document>, JsValue>

Getter for the responseXML field of this object.

MDN Documentation

This API requires the following crate features to be activated: Document, XmlHttpRequest

Source

impl XmlHttpRequest

pub fn new() -> Result<XmlHttpRequest, JsValue>

The new XmlHttpRequest(..) constructor, creating a new instance of XmlHttpRequest.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn new_with_ignored(ignored: &str) -> Result<XmlHttpRequest, JsValue>

The new XmlHttpRequest(..) constructor, creating a new instance of XmlHttpRequest.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn abort(&self) -> Result<(), JsValue>

The abort() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn get_all_response_headers(&self) -> Result<String, JsValue>

The getAllResponseHeaders() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn get_response_header( &self, header: &str, ) -> Result<Option<String>, JsValue>

The getResponseHeader() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn open(&self, method: &str, url: &str) -> Result<(), JsValue>

The open() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn open_with_async( &self, method: &str, url: &str, async: bool, ) -> Result<(), JsValue>

The open() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn open_with_async_and_user( &self, method: &str, url: &str, async: bool, user: Option<&str>, ) -> Result<(), JsValue>

The open() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn open_with_async_and_user_and_password( &self, method: &str, url: &str, async: bool, user: Option<&str>, password: Option<&str>, ) -> Result<(), JsValue>

The open() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn override_mime_type(&self, mime: &str) -> Result<(), JsValue>

The overrideMimeType() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send(&self) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_document( &self, body: Option<&Document>, ) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: Document, XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_blob(&self, body: Option<&Blob>) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: Blob, XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_buffer_source( &self, body: Option<&Object>, ) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_u8_array(&self, body: Option<&[u8]>) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_js_u8_array( &self, body: Option<&Uint8Array>, ) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_form_data( &self, body: Option<&FormData>, ) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: FormData, XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_url_search_params( &self, body: Option<&UrlSearchParams>, ) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: UrlSearchParams, XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_str(&self, body: Option<&str>) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub fn send_with_opt_readable_stream( &self, body: Option<&ReadableStream>, ) -> Result<(), JsValue>

The send() method.

MDN Documentation

This API requires the following crate features to be activated: ReadableStream, XmlHttpRequest

Source

impl XmlHttpRequest

pub fn set_request_header( &self, header: &str, value: &str, ) -> Result<(), JsValue>

The setRequestHeader() method.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequest

Source

impl XmlHttpRequest

pub const UNSENT: u16 = 0u16

The XMLHttpRequest.UNSENT const.

This API requires the following crate features to be activated: XmlHttpRequest

pub const OPENED: u16 = 1u16

The XMLHttpRequest.OPENED const.

This API requires the following crate features to be activated: XmlHttpRequest

pub const HEADERS_RECEIVED: u16 = 2u16

The XMLHttpRequest.HEADERS_RECEIVED const.

This API requires the following crate features to be activated: XmlHttpRequest

pub const LOADING: u16 = 3u16

The XMLHttpRequest.LOADING const.

This API requires the following crate features to be activated: XmlHttpRequest

pub const DONE: u16 = 4u16

The XMLHttpRequest.DONE const.

This API requires the following crate features to be activated: XmlHttpRequest

Methods from Deref<Target = XmlHttpRequestEventTarget>

pub fn onloadstart(&self) -> Option<Function>

Getter for the onloadstart field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn set_onloadstart(&self, value: Option<&Function>)

Setter for the onloadstart field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn onprogress(&self) -> Option<Function>

Getter for the onprogress field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn set_onprogress(&self, value: Option<&Function>)

Setter for the onprogress field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn onabort(&self) -> Option<Function>

Getter for the onabort field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn set_onabort(&self, value: Option<&Function>)

Setter for the onabort field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn onerror(&self) -> Option<Function>

Getter for the onerror field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn set_onerror(&self, value: Option<&Function>)

Setter for the onerror field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn onload(&self) -> Option<Function>

Getter for the onload field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn set_onload(&self, value: Option<&Function>)

Setter for the onload field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn ontimeout(&self) -> Option<Function>

Getter for the ontimeout field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn set_ontimeout(&self, value: Option<&Function>)

Setter for the ontimeout field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn onloadend(&self) -> Option<Function>

Getter for the onloadend field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

pub fn set_onloadend(&self, value: Option<&Function>)

Setter for the onloadend field of this object.

MDN Documentation

This API requires the following crate features to be activated: XmlHttpRequestEventTarget

Methods from Deref<Target = EventTarget>

pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget

pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget

pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>

The addEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>

The dispatchEvent() method.

MDN Documentation

This API requires the following crate features to be activated: Event, EventTarget

pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListenerOptions, EventTarget

pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget

pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventTarget

pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>

The removeEventListener() method.

MDN Documentation

This API requires the following crate features to be activated: EventListener, EventTarget

Methods from Deref<Target = Object>

pub fn constructor(&self) -> Function

The constructor property returns a reference to the Object constructor function that created the instance object.

MDN documentation

pub fn has_own_property(&self, property: &JsValue) -> bool

The hasOwnProperty() method returns a boolean indicating whether the object has the specified property as its own property (as opposed to inheriting it).

MDN documentation

pub fn is_prototype_of(&self, value: &JsValue) -> bool

The isPrototypeOf() method checks if an object exists in another object’s prototype chain.

MDN documentation

pub fn property_is_enumerable(&self, property: &JsValue) -> bool

The propertyIsEnumerable() method returns a Boolean indicating whether the specified property is enumerable.

MDN documentation

pub fn to_locale_string(&self) -> JsString

The toLocaleString() method returns a string representing the object. This method is meant to be overridden by derived objects for locale-specific purposes.

MDN documentation

pub fn to_string(&self) -> JsString

The toString() method returns a string representing the object.

MDN documentation

pub fn value_of(&self) -> Object

The valueOf() method returns the primitive value of the specified object.

MDN documentation

Methods from Deref<Target = JsValue>

pub const NULL: JsValue

pub const UNDEFINED: JsValue

pub const TRUE: JsValue

pub const FALSE: JsValue

pub fn id(&self) -> u64

Get the heap ID for this value.

This is used internally for encoding values to send to JS.

pub fn unchecked_into_f64(&self) -> f64

Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.

pub fn has_type<T>(&self) -> bool
where T: JsCast,

Check if this value is an instance of a specific JS type.

pub fn checked_div(&self, rhs: &JsValue) -> JsValue

Checked division.

pub fn pow(&self, rhs: &JsValue) -> JsValue

Power operation.

pub fn bit_and(&self, rhs: &JsValue) -> JsValue

Bitwise AND.

pub fn bit_or(&self, rhs: &JsValue) -> JsValue

Bitwise OR.

pub fn bit_xor(&self, rhs: &JsValue) -> JsValue

Bitwise XOR.

pub fn bit_not(&self) -> JsValue

Bitwise NOT.

pub fn shl(&self, rhs: &JsValue) -> JsValue

Left shift.

pub fn shr(&self, rhs: &JsValue) -> JsValue

Signed right shift.

pub fn unsigned_shr(&self, rhs: &JsValue) -> u32

Unsigned right shift.

pub fn add(&self, rhs: &JsValue) -> JsValue

Add.

pub fn sub(&self, rhs: &JsValue) -> JsValue

Subtract.

pub fn mul(&self, rhs: &JsValue) -> JsValue

Multiply.

pub fn div(&self, rhs: &JsValue) -> JsValue

Divide.

pub fn rem(&self, rhs: &JsValue) -> JsValue

Remainder.

pub fn neg(&self) -> JsValue

Negate.

pub fn lt(&self, rhs: &JsValue) -> bool

Less than comparison.

pub fn le(&self, rhs: &JsValue) -> bool

Less than or equal comparison.

pub fn gt(&self, rhs: &JsValue) -> bool

Greater than comparison.

pub fn ge(&self, rhs: &JsValue) -> bool

Greater than or equal comparison.

pub fn loose_eq(&self, rhs: &JsValue) -> bool

Loose equality (==).

pub fn is_falsy(&self) -> bool

Check if this value is a falsy value in JavaScript.

pub fn is_truthy(&self) -> bool

Check if this value is a truthy value in JavaScript.

pub fn is_object(&self) -> bool

Check if this value is an object.

pub fn is_function(&self) -> bool

Check if this value is a function.

pub fn is_string(&self) -> bool

Check if this value is a string.

pub fn is_symbol(&self) -> bool

Check if this value is a symbol.

pub fn is_bigint(&self) -> bool

Check if this value is a bigint.

pub fn is_undefined(&self) -> bool

Check if this value is undefined.

pub fn is_null(&self) -> bool

Check if this value is null.

pub fn js_typeof(&self) -> JsValue

Get the typeof this value as a string.

pub fn js_in(&self, obj: &JsValue) -> bool

Check if this value has a property with the given name.

pub fn as_bool(&self) -> Option<bool>

Get the value as a bool.

pub fn as_f64(&self) -> Option<f64>

Get the value as an f64.

pub fn as_string(&self) -> Option<String>

Get the value as a string.

pub fn as_debug_string(&self) -> String

Get a debug string representation of the value.