#[repr(transparent)]pub struct Event {
pub obj: JsValue,
}Expand description
The Event class.
This API requires the following crate features to be activated: Event
Fields
obj: JsValueImplementations
Sourceimpl Event
impl Event
Sourceimpl Event
impl Event
Sourcepub fn target(&self) -> Option<EventTarget>
pub fn target(&self) -> Option<EventTarget>
Getter for the target field of this object.
This API requires the following crate features to be activated: Event, EventTarget
Sourceimpl Event
impl Event
Sourcepub fn current_target(&self) -> Option<EventTarget>
pub fn current_target(&self) -> Option<EventTarget>
Getter for the currentTarget field of this object.
This API requires the following crate features to be activated: Event, EventTarget
Sourceimpl Event
impl Event
Sourcepub fn event_phase(&self) -> u16
pub fn event_phase(&self) -> u16
Getter for the eventPhase field of this object.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourceimpl Event
impl Event
Sourcepub fn cancelable(&self) -> bool
pub fn cancelable(&self) -> bool
Getter for the cancelable field of this object.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn default_prevented(&self) -> bool
pub fn default_prevented(&self) -> bool
Getter for the defaultPrevented field of this object.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourceimpl Event
impl Event
Sourcepub fn is_trusted(&self) -> bool
pub fn is_trusted(&self) -> bool
Getter for the isTrusted field of this object.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn time_stamp(&self) -> f64
pub fn time_stamp(&self) -> f64
Getter for the timeStamp field of this object.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn cancel_bubble(&self) -> bool
pub fn cancel_bubble(&self) -> bool
Getter for the cancelBubble field of this object.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn set_cancel_bubble(&self, value: bool)
pub fn set_cancel_bubble(&self, value: bool)
Setter for the cancelBubble field of this object.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourceimpl Event
impl Event
Sourcepub fn composed_path(&self) -> Array
pub fn composed_path(&self) -> Array
The composedPath() method.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn init_event(&self, type_: &str)
pub fn init_event(&self, type_: &str)
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
pub fn init_event_with_bubbles(&self, type_: &str, bubbles: bool)
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn init_event_with_bubbles_and_cancelable(
&self,
type_: &str,
bubbles: bool,
cancelable: bool,
)
pub fn init_event_with_bubbles_and_cancelable( &self, type_: &str, bubbles: bool, cancelable: bool, )
The initEvent() method.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn prevent_default(&self)
pub fn prevent_default(&self)
The preventDefault() method.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn stop_immediate_propagation(&self)
pub fn stop_immediate_propagation(&self)
The stopImmediatePropagation() method.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub fn stop_propagation(&self)
pub fn stop_propagation(&self)
The stopPropagation() method.
This API requires the following crate features to be activated: Event
Sourceimpl Event
impl Event
Sourcepub const NONE: u16 = 0u16
pub const NONE: u16 = 0u16
The Event.NONE const.
This API requires the following crate features to be activated: Event
Sourcepub const CAPTURING_PHASE: u16 = 1u16
pub const CAPTURING_PHASE: u16 = 1u16
The Event.CAPTURING_PHASE const.
This API requires the following crate features to be activated: Event
Sourcepub const AT_TARGET: u16 = 2u16
pub const AT_TARGET: u16 = 2u16
The Event.AT_TARGET const.
This API requires the following crate features to be activated: Event
Sourcepub const BUBBLING_PHASE: u16 = 3u16
pub const BUBBLING_PHASE: u16 = 3u16
The Event.BUBBLING_PHASE const.
This API requires the following crate features to be activated: Event
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.