#[repr(transparent)]pub struct IdbObjectStore {
pub obj: JsValue,
}Expand description
The IdbObjectStore class.
This API requires the following crate features to be activated: IdbObjectStore
Fields
obj: JsValueImplementations
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn index_names(&self) -> DomStringList
pub fn index_names(&self) -> DomStringList
Getter for the indexNames field of this object.
This API requires the following crate features to be activated: DomStringList, IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn transaction(&self) -> IdbTransaction
pub fn transaction(&self) -> IdbTransaction
Getter for the transaction field of this object.
This API requires the following crate features to be activated: IdbObjectStore, IdbTransaction
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn auto_increment(&self) -> bool
pub fn auto_increment(&self) -> bool
Getter for the autoIncrement field of this object.
This API requires the following crate features to be activated: IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn add_with_key(
&self,
value: &JsValue,
key: &JsValue,
) -> Result<IdbRequest, JsValue>
pub fn add_with_key( &self, value: &JsValue, key: &JsValue, ) -> Result<IdbRequest, JsValue>
The add() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn clear(&self) -> Result<IdbRequest, JsValue>
pub fn clear(&self) -> Result<IdbRequest, JsValue>
The clear() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn count(&self) -> Result<IdbRequest, JsValue>
pub fn count(&self) -> Result<IdbRequest, JsValue>
The count() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn count_with_key(&self, query: &JsValue) -> Result<IdbRequest, JsValue>
pub fn count_with_key(&self, query: &JsValue) -> Result<IdbRequest, JsValue>
The count() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn get_all(&self) -> Result<IdbRequest, JsValue>
pub fn get_all(&self) -> Result<IdbRequest, JsValue>
The getAll() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn get_all_with_key(&self, query: &JsValue) -> Result<IdbRequest, JsValue>
pub fn get_all_with_key(&self, query: &JsValue) -> Result<IdbRequest, JsValue>
The getAll() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn get_all_with_key_and_limit(
&self,
query: &JsValue,
count: u32,
) -> Result<IdbRequest, JsValue>
pub fn get_all_with_key_and_limit( &self, query: &JsValue, count: u32, ) -> Result<IdbRequest, JsValue>
The getAll() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn get_all_keys(&self) -> Result<IdbRequest, JsValue>
pub fn get_all_keys(&self) -> Result<IdbRequest, JsValue>
The getAllKeys() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn get_all_keys_with_key(
&self,
query: &JsValue,
) -> Result<IdbRequest, JsValue>
pub fn get_all_keys_with_key( &self, query: &JsValue, ) -> Result<IdbRequest, JsValue>
The getAllKeys() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn get_all_keys_with_key_and_limit(
&self,
query: &JsValue,
count: u32,
) -> Result<IdbRequest, JsValue>
pub fn get_all_keys_with_key_and_limit( &self, query: &JsValue, count: u32, ) -> Result<IdbRequest, JsValue>
The getAllKeys() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn open_cursor(&self) -> Result<IdbRequest, JsValue>
pub fn open_cursor(&self) -> Result<IdbRequest, JsValue>
The openCursor() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn open_cursor_with_range(
&self,
query: &JsValue,
) -> Result<IdbRequest, JsValue>
pub fn open_cursor_with_range( &self, query: &JsValue, ) -> Result<IdbRequest, JsValue>
The openCursor() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn open_cursor_with_range_and_direction(
&self,
query: &JsValue,
direction: IdbCursorDirection,
) -> Result<IdbRequest, JsValue>
pub fn open_cursor_with_range_and_direction( &self, query: &JsValue, direction: IdbCursorDirection, ) -> Result<IdbRequest, JsValue>
The openCursor() method.
This API requires the following crate features to be activated: IdbCursorDirection, IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn open_key_cursor(&self) -> Result<IdbRequest, JsValue>
pub fn open_key_cursor(&self) -> Result<IdbRequest, JsValue>
The openKeyCursor() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn open_key_cursor_with_range(
&self,
query: &JsValue,
) -> Result<IdbRequest, JsValue>
pub fn open_key_cursor_with_range( &self, query: &JsValue, ) -> Result<IdbRequest, JsValue>
The openKeyCursor() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn open_key_cursor_with_range_and_direction(
&self,
query: &JsValue,
direction: IdbCursorDirection,
) -> Result<IdbRequest, JsValue>
pub fn open_key_cursor_with_range_and_direction( &self, query: &JsValue, direction: IdbCursorDirection, ) -> Result<IdbRequest, JsValue>
The openKeyCursor() method.
This API requires the following crate features to be activated: IdbCursorDirection, IdbObjectStore, IdbRequest
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourceimpl IdbObjectStore
impl IdbObjectStore
Sourcepub fn put_with_key(
&self,
value: &JsValue,
key: &JsValue,
) -> Result<IdbRequest, JsValue>
pub fn put_with_key( &self, value: &JsValue, key: &JsValue, ) -> Result<IdbRequest, JsValue>
The put() method.
This API requires the following crate features to be activated: IdbObjectStore, IdbRequest
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.