#[repr(transparent)]pub struct Node {
pub obj: JsValue,
}Expand description
The Node class.
This API requires the following crate features to be activated: Node
Fields
obj: JsValueImplementations
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Getter for the isConnected field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn owner_document(&self) -> Option<Document>
pub fn owner_document(&self) -> Option<Document>
Getter for the ownerDocument field of this object.
This API requires the following crate features to be activated: Document, Node
Sourceimpl Node
impl Node
Sourcepub fn parent_node(&self) -> Option<Node>
pub fn parent_node(&self) -> Option<Node>
Getter for the parentNode field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn parent_element(&self) -> Option<Element>
pub fn parent_element(&self) -> Option<Element>
Getter for the parentElement field of this object.
This API requires the following crate features to be activated: Element, Node
Sourceimpl Node
impl Node
Sourcepub fn child_nodes(&self) -> NodeList
pub fn child_nodes(&self) -> NodeList
Getter for the childNodes field of this object.
This API requires the following crate features to be activated: Node, NodeList
Sourceimpl Node
impl Node
Sourcepub fn first_child(&self) -> Option<Node>
pub fn first_child(&self) -> Option<Node>
Getter for the firstChild field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn last_child(&self) -> Option<Node>
pub fn last_child(&self) -> Option<Node>
Getter for the lastChild field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn previous_sibling(&self) -> Option<Node>
pub fn previous_sibling(&self) -> Option<Node>
Getter for the previousSibling field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn next_sibling(&self) -> Option<Node>
pub fn next_sibling(&self) -> Option<Node>
Getter for the nextSibling field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn node_value(&self) -> Option<String>
pub fn node_value(&self) -> Option<String>
Getter for the nodeValue field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn set_node_value(&self, value: Option<&str>)
pub fn set_node_value(&self, value: Option<&str>)
Setter for the nodeValue field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn text_content(&self) -> Option<String>
pub fn text_content(&self) -> Option<String>
Getter for the textContent field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn set_text_content(&self, value: Option<&str>)
pub fn set_text_content(&self, value: Option<&str>)
Setter for the textContent field of this object.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourcepub fn clone_node(&self) -> Result<Node, JsValue>
pub fn clone_node(&self) -> Result<Node, JsValue>
The cloneNode() method.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourcepub fn compare_document_position(&self, other: &Node) -> u16
pub fn compare_document_position(&self, other: &Node) -> u16
The compareDocumentPosition() method.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn get_root_node(&self) -> Node
pub fn get_root_node(&self) -> Node
The getRootNode() method.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn has_child_nodes(&self) -> bool
pub fn has_child_nodes(&self) -> bool
The hasChildNodes() method.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourcepub fn is_default_namespace(&self, namespace: Option<&str>) -> bool
pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool
The isDefaultNamespace() method.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn is_equal_node(&self, node: Option<&Node>) -> bool
pub fn is_equal_node(&self, node: Option<&Node>) -> bool
The isEqualNode() method.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourcepub fn is_same_node(&self, node: Option<&Node>) -> bool
pub fn is_same_node(&self, node: Option<&Node>) -> bool
The isSameNode() method.
This API requires the following crate features to be activated: Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourceimpl Node
impl Node
Sourcepub const ELEMENT_NODE: u16 = 1u16
pub const ELEMENT_NODE: u16 = 1u16
The Node.ELEMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const ATTRIBUTE_NODE: u16 = 2u16
pub const ATTRIBUTE_NODE: u16 = 2u16
The Node.ATTRIBUTE_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const TEXT_NODE: u16 = 3u16
pub const TEXT_NODE: u16 = 3u16
The Node.TEXT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const CDATA_SECTION_NODE: u16 = 4u16
pub const CDATA_SECTION_NODE: u16 = 4u16
The Node.CDATA_SECTION_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const ENTITY_REFERENCE_NODE: u16 = 5u16
pub const ENTITY_REFERENCE_NODE: u16 = 5u16
The Node.ENTITY_REFERENCE_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const ENTITY_NODE: u16 = 6u16
pub const ENTITY_NODE: u16 = 6u16
The Node.ENTITY_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const PROCESSING_INSTRUCTION_NODE: u16 = 7u16
pub const PROCESSING_INSTRUCTION_NODE: u16 = 7u16
The Node.PROCESSING_INSTRUCTION_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const COMMENT_NODE: u16 = 8u16
pub const COMMENT_NODE: u16 = 8u16
The Node.COMMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_NODE: u16 = 9u16
pub const DOCUMENT_NODE: u16 = 9u16
The Node.DOCUMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_TYPE_NODE: u16 = 10u16
pub const DOCUMENT_TYPE_NODE: u16 = 10u16
The Node.DOCUMENT_TYPE_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_FRAGMENT_NODE: u16 = 11u16
pub const DOCUMENT_FRAGMENT_NODE: u16 = 11u16
The Node.DOCUMENT_FRAGMENT_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const NOTATION_NODE: u16 = 12u16
pub const NOTATION_NODE: u16 = 12u16
The Node.NOTATION_NODE const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_DISCONNECTED: u16 = 1u16
pub const DOCUMENT_POSITION_DISCONNECTED: u16 = 1u16
The Node.DOCUMENT_POSITION_DISCONNECTED const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_PRECEDING: u16 = 2u16
pub const DOCUMENT_POSITION_PRECEDING: u16 = 2u16
The Node.DOCUMENT_POSITION_PRECEDING const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_FOLLOWING: u16 = 4u16
pub const DOCUMENT_POSITION_FOLLOWING: u16 = 4u16
The Node.DOCUMENT_POSITION_FOLLOWING const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_CONTAINS: u16 = 8u16
pub const DOCUMENT_POSITION_CONTAINS: u16 = 8u16
The Node.DOCUMENT_POSITION_CONTAINS const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_CONTAINED_BY: u16 = 16u16
pub const DOCUMENT_POSITION_CONTAINED_BY: u16 = 16u16
The Node.DOCUMENT_POSITION_CONTAINED_BY const.
This API requires the following crate features to be activated: Node
Sourcepub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16 = 32u16
pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16 = 32u16
The Node.DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC const.
This API requires the following crate features to be activated: Node
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn remove_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.