#[repr(transparent)]pub struct NotificationOptions {
pub obj: JsValue,
}Expand description
The NotificationOptions dictionary.
This API requires the following crate features to be activated: NotificationOptions
Fields
obj: JsValueImplementations
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn get_actions(&self) -> Option<Array>
pub fn get_actions(&self) -> Option<Array>
Get the actions field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn set_actions(&self, val: &JsValue)
pub fn set_actions(&self, val: &JsValue)
Change the actions field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn get_renotify(&self) -> Option<bool>
pub fn get_renotify(&self) -> Option<bool>
Get the renotify field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn set_renotify(&self, val: bool)
pub fn set_renotify(&self, val: bool)
Change the renotify field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn get_require_interaction(&self) -> Option<bool>
pub fn get_require_interaction(&self) -> Option<bool>
Get the requireInteraction field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn set_require_interaction(&self, val: bool)
pub fn set_require_interaction(&self, val: bool)
Change the requireInteraction field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn get_silent(&self) -> Option<bool>
pub fn get_silent(&self) -> Option<bool>
Get the silent field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn set_silent(&self, val: Option<bool>)
pub fn set_silent(&self, val: Option<bool>)
Change the silent field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn get_timestamp(&self) -> Option<f64>
pub fn get_timestamp(&self) -> Option<f64>
Get the timestamp field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn set_timestamp(&self, val: f64)
pub fn set_timestamp(&self, val: f64)
Change the timestamp field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn get_vibrate(&self) -> JsValue
pub fn get_vibrate(&self) -> JsValue
Get the vibrate field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn set_vibrate(&self, val: &JsValue)
pub fn set_vibrate(&self, val: &JsValue)
Change the vibrate field of this object.
This API requires the following crate features to be activated: NotificationOptions
Sourceimpl NotificationOptions
impl NotificationOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new NotificationOptions.
This API requires the following crate features to be activated: NotificationOptions
pub fn actions(&mut self, val: &JsValue) -> &mut Self
set_actions() instead.pub fn badge(&mut self, val: &str) -> &mut Self
set_badge() instead.pub fn body(&mut self, val: &str) -> &mut Self
set_body() instead.pub fn data(&mut self, val: &JsValue) -> &mut Self
set_data() instead.pub fn icon(&mut self, val: &str) -> &mut Self
set_icon() instead.pub fn image(&mut self, val: &str) -> &mut Self
set_image() instead.pub fn lang(&mut self, val: &str) -> &mut Self
set_lang() instead.pub fn renotify(&mut self, val: bool) -> &mut Self
set_renotify() instead.pub fn require_interaction(&mut self, val: bool) -> &mut Self
set_require_interaction() instead.pub fn silent(&mut self, val: Option<bool>) -> &mut Self
set_silent() instead.pub fn tag(&mut self, val: &str) -> &mut Self
set_tag() instead.pub fn timestamp(&mut self, val: f64) -> &mut Self
set_timestamp() instead.pub fn vibrate(&mut self, val: &JsValue) -> &mut Self
set_vibrate() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.