#[repr(transparent)]pub struct PointerEventInit {
pub obj: JsValue,
}Expand description
The PointerEventInit dictionary.
This API requires the following crate features to be activated: PointerEventInit
Fields
obj: JsValueImplementations
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_bubbles(&self) -> Option<bool>
pub fn get_bubbles(&self) -> Option<bool>
Get the bubbles field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_bubbles(&self, val: bool)
pub fn set_bubbles(&self, val: bool)
Change the bubbles field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_cancelable(&self) -> Option<bool>
pub fn get_cancelable(&self) -> Option<bool>
Get the cancelable field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_cancelable(&self, val: bool)
pub fn set_cancelable(&self, val: bool)
Change the cancelable field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_composed(&self) -> Option<bool>
pub fn get_composed(&self) -> Option<bool>
Get the composed field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_composed(&self, val: bool)
pub fn set_composed(&self, val: bool)
Change the composed field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_detail(&self) -> Option<i32>
pub fn get_detail(&self) -> Option<i32>
Get the detail field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_detail(&self, val: i32)
pub fn set_detail(&self, val: i32)
Change the detail field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_alt_key(&self) -> Option<bool>
pub fn get_alt_key(&self) -> Option<bool>
Get the altKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_alt_key(&self, val: bool)
pub fn set_alt_key(&self, val: bool)
Change the altKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_ctrl_key(&self) -> Option<bool>
pub fn get_ctrl_key(&self) -> Option<bool>
Get the ctrlKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_ctrl_key(&self, val: bool)
pub fn set_ctrl_key(&self, val: bool)
Change the ctrlKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_meta_key(&self) -> Option<bool>
pub fn get_meta_key(&self) -> Option<bool>
Get the metaKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_meta_key(&self, val: bool)
pub fn set_meta_key(&self, val: bool)
Change the metaKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_alt_graph(&self) -> Option<bool>
pub fn get_modifier_alt_graph(&self) -> Option<bool>
Get the modifierAltGraph field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_alt_graph(&self, val: bool)
pub fn set_modifier_alt_graph(&self, val: bool)
Change the modifierAltGraph field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_caps_lock(&self) -> Option<bool>
pub fn get_modifier_caps_lock(&self) -> Option<bool>
Get the modifierCapsLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_caps_lock(&self, val: bool)
pub fn set_modifier_caps_lock(&self, val: bool)
Change the modifierCapsLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_fn(&self) -> Option<bool>
pub fn get_modifier_fn(&self) -> Option<bool>
Get the modifierFn field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_fn(&self, val: bool)
pub fn set_modifier_fn(&self, val: bool)
Change the modifierFn field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_fn_lock(&self) -> Option<bool>
pub fn get_modifier_fn_lock(&self) -> Option<bool>
Get the modifierFnLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_fn_lock(&self, val: bool)
pub fn set_modifier_fn_lock(&self, val: bool)
Change the modifierFnLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_num_lock(&self) -> Option<bool>
pub fn get_modifier_num_lock(&self) -> Option<bool>
Get the modifierNumLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_num_lock(&self, val: bool)
pub fn set_modifier_num_lock(&self, val: bool)
Change the modifierNumLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_os(&self) -> Option<bool>
pub fn get_modifier_os(&self) -> Option<bool>
Get the modifierOS field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_os(&self, val: bool)
pub fn set_modifier_os(&self, val: bool)
Change the modifierOS field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_scroll_lock(&self) -> Option<bool>
pub fn get_modifier_scroll_lock(&self) -> Option<bool>
Get the modifierScrollLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_scroll_lock(&self, val: bool)
pub fn set_modifier_scroll_lock(&self, val: bool)
Change the modifierScrollLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_symbol(&self) -> Option<bool>
pub fn get_modifier_symbol(&self) -> Option<bool>
Get the modifierSymbol field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_symbol(&self, val: bool)
pub fn set_modifier_symbol(&self, val: bool)
Change the modifierSymbol field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_modifier_symbol_lock(&self) -> Option<bool>
pub fn get_modifier_symbol_lock(&self) -> Option<bool>
Get the modifierSymbolLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_modifier_symbol_lock(&self, val: bool)
pub fn set_modifier_symbol_lock(&self, val: bool)
Change the modifierSymbolLock field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_shift_key(&self) -> Option<bool>
pub fn get_shift_key(&self) -> Option<bool>
Get the shiftKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_shift_key(&self, val: bool)
pub fn set_shift_key(&self, val: bool)
Change the shiftKey field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Get the button field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Change the button field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Get the buttons field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Change the buttons field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_client_x(&self) -> Option<i32>
pub fn get_client_x(&self) -> Option<i32>
Get the clientX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_client_x(&self, val: i32)
pub fn set_client_x(&self, val: i32)
Change the clientX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_client_y(&self) -> Option<i32>
pub fn get_client_y(&self) -> Option<i32>
Get the clientY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_client_y(&self, val: i32)
pub fn set_client_y(&self, val: i32)
Change the clientY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_movement_x(&self) -> Option<i32>
pub fn get_movement_x(&self) -> Option<i32>
Get the movementX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_movement_x(&self, val: i32)
pub fn set_movement_x(&self, val: i32)
Change the movementX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_movement_y(&self) -> Option<i32>
pub fn get_movement_y(&self) -> Option<i32>
Get the movementY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_movement_y(&self, val: i32)
pub fn set_movement_y(&self, val: i32)
Change the movementY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Get the relatedTarget field of this object.
This API requires the following crate features to be activated: EventTarget, PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Change the relatedTarget field of this object.
This API requires the following crate features to be activated: EventTarget, PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_screen_x(&self) -> Option<i32>
pub fn get_screen_x(&self) -> Option<i32>
Get the screenX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_screen_x(&self, val: i32)
pub fn set_screen_x(&self, val: i32)
Change the screenX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_screen_y(&self) -> Option<i32>
pub fn get_screen_y(&self) -> Option<i32>
Get the screenY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_screen_y(&self, val: i32)
pub fn set_screen_y(&self, val: i32)
Change the screenY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_coalesced_events(&self) -> Option<Array>
pub fn get_coalesced_events(&self) -> Option<Array>
Get the coalescedEvents field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_coalesced_events(&self, val: &JsValue)
pub fn set_coalesced_events(&self, val: &JsValue)
Change the coalescedEvents field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_height(&self) -> Option<i32>
pub fn get_height(&self) -> Option<i32>
Get the height field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_height(&self, val: i32)
pub fn set_height(&self, val: i32)
Change the height field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_is_primary(&self) -> Option<bool>
pub fn get_is_primary(&self) -> Option<bool>
Get the isPrimary field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_is_primary(&self, val: bool)
pub fn set_is_primary(&self, val: bool)
Change the isPrimary field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_pointer_id(&self) -> Option<i32>
pub fn get_pointer_id(&self) -> Option<i32>
Get the pointerId field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_pointer_id(&self, val: i32)
pub fn set_pointer_id(&self, val: i32)
Change the pointerId field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_pointer_type(&self) -> Option<String>
pub fn get_pointer_type(&self) -> Option<String>
Get the pointerType field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_pointer_type(&self, val: &str)
pub fn set_pointer_type(&self, val: &str)
Change the pointerType field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_pressure(&self) -> Option<f32>
pub fn get_pressure(&self) -> Option<f32>
Get the pressure field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_pressure(&self, val: f32)
pub fn set_pressure(&self, val: f32)
Change the pressure field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_tangential_pressure(&self) -> Option<f32>
pub fn get_tangential_pressure(&self) -> Option<f32>
Get the tangentialPressure field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_tangential_pressure(&self, val: f32)
pub fn set_tangential_pressure(&self, val: f32)
Change the tangentialPressure field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_tilt_x(&self) -> Option<i32>
pub fn get_tilt_x(&self) -> Option<i32>
Get the tiltX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_tilt_x(&self, val: i32)
pub fn set_tilt_x(&self, val: i32)
Change the tiltX field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn get_tilt_y(&self) -> Option<i32>
pub fn get_tilt_y(&self) -> Option<i32>
Get the tiltY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn set_tilt_y(&self, val: i32)
pub fn set_tilt_y(&self, val: i32)
Change the tiltY field of this object.
This API requires the following crate features to be activated: PointerEventInit
Sourceimpl PointerEventInit
impl PointerEventInit
Sourcepub fn new() -> Self
pub fn new() -> Self
Construct a new PointerEventInit.
This API requires the following crate features to be activated: PointerEventInit
pub fn bubbles(&mut self, val: bool) -> &mut Self
set_bubbles() instead.pub fn cancelable(&mut self, val: bool) -> &mut Self
set_cancelable() instead.pub fn composed(&mut self, val: bool) -> &mut Self
set_composed() instead.pub fn detail(&mut self, val: i32) -> &mut Self
set_detail() instead.pub fn view(&mut self, val: Option<&Window>) -> &mut Self
set_view() instead.pub fn alt_key(&mut self, val: bool) -> &mut Self
set_alt_key() instead.pub fn ctrl_key(&mut self, val: bool) -> &mut Self
set_ctrl_key() instead.pub fn meta_key(&mut self, val: bool) -> &mut Self
set_meta_key() instead.pub fn modifier_alt_graph(&mut self, val: bool) -> &mut Self
set_modifier_alt_graph() instead.pub fn modifier_caps_lock(&mut self, val: bool) -> &mut Self
set_modifier_caps_lock() instead.pub fn modifier_fn(&mut self, val: bool) -> &mut Self
set_modifier_fn() instead.pub fn modifier_fn_lock(&mut self, val: bool) -> &mut Self
set_modifier_fn_lock() instead.pub fn modifier_num_lock(&mut self, val: bool) -> &mut Self
set_modifier_num_lock() instead.pub fn modifier_os(&mut self, val: bool) -> &mut Self
set_modifier_os() instead.pub fn modifier_scroll_lock(&mut self, val: bool) -> &mut Self
set_modifier_scroll_lock() instead.pub fn modifier_symbol(&mut self, val: bool) -> &mut Self
set_modifier_symbol() instead.pub fn modifier_symbol_lock(&mut self, val: bool) -> &mut Self
set_modifier_symbol_lock() instead.pub fn shift_key(&mut self, val: bool) -> &mut Self
set_shift_key() instead.set_button() instead.set_buttons() instead.pub fn client_x(&mut self, val: i32) -> &mut Self
set_client_x() instead.pub fn client_y(&mut self, val: i32) -> &mut Self
set_client_y() instead.pub fn movement_x(&mut self, val: i32) -> &mut Self
set_movement_x() instead.pub fn movement_y(&mut self, val: i32) -> &mut Self
set_movement_y() instead.set_related_target() instead.pub fn screen_x(&mut self, val: i32) -> &mut Self
set_screen_x() instead.pub fn screen_y(&mut self, val: i32) -> &mut Self
set_screen_y() instead.pub fn coalesced_events(&mut self, val: &JsValue) -> &mut Self
set_coalesced_events() instead.pub fn height(&mut self, val: i32) -> &mut Self
set_height() instead.pub fn is_primary(&mut self, val: bool) -> &mut Self
set_is_primary() instead.pub fn pointer_id(&mut self, val: i32) -> &mut Self
set_pointer_id() instead.pub fn pointer_type(&mut self, val: &str) -> &mut Self
set_pointer_type() instead.pub fn pressure(&mut self, val: f32) -> &mut Self
set_pressure() instead.pub fn tangential_pressure(&mut self, val: f32) -> &mut Self
set_tangential_pressure() instead.pub fn tilt_x(&mut self, val: i32) -> &mut Self
set_tilt_x() instead.pub fn tilt_y(&mut self, val: i32) -> &mut Self
set_tilt_y() instead.pub fn twist(&mut self, val: i32) -> &mut Self
set_twist() instead.pub fn width(&mut self, val: i32) -> &mut Self
set_width() instead.Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.