#[repr(transparent)]pub struct ProcessingInstruction {
pub obj: JsValue,
}Expand description
The ProcessingInstruction class.
This API requires the following crate features to be activated: ProcessingInstruction
Fields
obj: JsValueImplementations
Sourceimpl ProcessingInstruction
impl ProcessingInstruction
Sourceimpl ProcessingInstruction
impl ProcessingInstruction
Sourcepub fn sheet(&self) -> Option<StyleSheet>
pub fn sheet(&self) -> Option<StyleSheet>
Getter for the sheet field of this object.
This API requires the following crate features to be activated: ProcessingInstruction, StyleSheet
Methods from Deref<Target = CharacterData>
Sourcepub fn data(&self) -> String
pub fn data(&self) -> String
Getter for the data field of this object.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn set_data(&self, value: &str)
pub fn set_data(&self, value: &str)
Setter for the data field of this object.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn length(&self) -> u32
pub fn length(&self) -> u32
Getter for the length field of this object.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn previous_element_sibling(&self) -> Option<Element>
pub fn previous_element_sibling(&self) -> Option<Element>
Getter for the previousElementSibling field of this object.
This API requires the following crate features to be activated: CharacterData, Element
Sourcepub fn next_element_sibling(&self) -> Option<Element>
pub fn next_element_sibling(&self) -> Option<Element>
Getter for the nextElementSibling field of this object.
This API requires the following crate features to be activated: CharacterData, Element
Sourcepub fn append_data(&self, data: &str) -> Result<(), JsValue>
pub fn append_data(&self, data: &str) -> Result<(), JsValue>
The appendData() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn delete_data(&self, offset: u32, count: u32) -> Result<(), JsValue>
pub fn delete_data(&self, offset: u32, count: u32) -> Result<(), JsValue>
The deleteData() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn insert_data(&self, offset: u32, data: &str) -> Result<(), JsValue>
pub fn insert_data(&self, offset: u32, data: &str) -> Result<(), JsValue>
The insertData() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_data(
&self,
offset: u32,
count: u32,
data: &str,
) -> Result<(), JsValue>
pub fn replace_data( &self, offset: u32, count: u32, data: &str, ) -> Result<(), JsValue>
The replaceData() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn substring_data(&self, offset: u32, count: u32) -> Result<String, JsValue>
pub fn substring_data(&self, offset: u32, count: u32) -> Result<String, JsValue>
The substringData() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node(&self, nodes: &Array) -> Result<(), JsValue>
pub fn after_with_node(&self, nodes: &Array) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_0(&self) -> Result<(), JsValue>
pub fn after_with_node_0(&self) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>
pub fn after_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_2(
&self,
nodes_1: &Node,
nodes_2: &Node,
) -> Result<(), JsValue>
pub fn after_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_3(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
) -> Result<(), JsValue>
pub fn after_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_4(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
) -> Result<(), JsValue>
pub fn after_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_5(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
) -> Result<(), JsValue>
pub fn after_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_6(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
nodes_6: &Node,
) -> Result<(), JsValue>
pub fn after_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_node_7(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
nodes_6: &Node,
nodes_7: &Node,
) -> Result<(), JsValue>
pub fn after_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str(&self, nodes: &Array) -> Result<(), JsValue>
pub fn after_with_str(&self, nodes: &Array) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_0(&self) -> Result<(), JsValue>
pub fn after_with_str_0(&self) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>
pub fn after_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_2(
&self,
nodes_1: &str,
nodes_2: &str,
) -> Result<(), JsValue>
pub fn after_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_3(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
) -> Result<(), JsValue>
pub fn after_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_4(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
) -> Result<(), JsValue>
pub fn after_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_5(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
nodes_5: &str,
) -> Result<(), JsValue>
pub fn after_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_6(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
nodes_5: &str,
nodes_6: &str,
) -> Result<(), JsValue>
pub fn after_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn after_with_str_7(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
nodes_5: &str,
nodes_6: &str,
nodes_7: &str,
) -> Result<(), JsValue>
pub fn after_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>
The after() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node(&self, nodes: &Array) -> Result<(), JsValue>
pub fn before_with_node(&self, nodes: &Array) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_0(&self) -> Result<(), JsValue>
pub fn before_with_node_0(&self) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>
pub fn before_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_2(
&self,
nodes_1: &Node,
nodes_2: &Node,
) -> Result<(), JsValue>
pub fn before_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_3(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
) -> Result<(), JsValue>
pub fn before_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_4(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
) -> Result<(), JsValue>
pub fn before_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_5(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
) -> Result<(), JsValue>
pub fn before_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_6(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
nodes_6: &Node,
) -> Result<(), JsValue>
pub fn before_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_node_7(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
nodes_6: &Node,
nodes_7: &Node,
) -> Result<(), JsValue>
pub fn before_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str(&self, nodes: &Array) -> Result<(), JsValue>
pub fn before_with_str(&self, nodes: &Array) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_0(&self) -> Result<(), JsValue>
pub fn before_with_str_0(&self) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>
pub fn before_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_2(
&self,
nodes_1: &str,
nodes_2: &str,
) -> Result<(), JsValue>
pub fn before_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_3(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
) -> Result<(), JsValue>
pub fn before_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_4(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
) -> Result<(), JsValue>
pub fn before_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_5(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
nodes_5: &str,
) -> Result<(), JsValue>
pub fn before_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_6(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
nodes_5: &str,
nodes_6: &str,
) -> Result<(), JsValue>
pub fn before_with_str_6( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn before_with_str_7(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
nodes_5: &str,
nodes_6: &str,
nodes_7: &str,
) -> Result<(), JsValue>
pub fn before_with_str_7( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, nodes_6: &str, nodes_7: &str, ) -> Result<(), JsValue>
The before() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn remove(&self)
pub fn remove(&self)
The remove() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node(&self, nodes: &Array) -> Result<(), JsValue>
pub fn replace_with_with_node(&self, nodes: &Array) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_0(&self) -> Result<(), JsValue>
pub fn replace_with_with_node_0(&self) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>
pub fn replace_with_with_node_1(&self, nodes_1: &Node) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_2(
&self,
nodes_1: &Node,
nodes_2: &Node,
) -> Result<(), JsValue>
pub fn replace_with_with_node_2( &self, nodes_1: &Node, nodes_2: &Node, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_3(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
) -> Result<(), JsValue>
pub fn replace_with_with_node_3( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_4(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
) -> Result<(), JsValue>
pub fn replace_with_with_node_4( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_5(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
) -> Result<(), JsValue>
pub fn replace_with_with_node_5( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_6(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
nodes_6: &Node,
) -> Result<(), JsValue>
pub fn replace_with_with_node_6( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_node_7(
&self,
nodes_1: &Node,
nodes_2: &Node,
nodes_3: &Node,
nodes_4: &Node,
nodes_5: &Node,
nodes_6: &Node,
nodes_7: &Node,
) -> Result<(), JsValue>
pub fn replace_with_with_node_7( &self, nodes_1: &Node, nodes_2: &Node, nodes_3: &Node, nodes_4: &Node, nodes_5: &Node, nodes_6: &Node, nodes_7: &Node, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_str(&self, nodes: &Array) -> Result<(), JsValue>
pub fn replace_with_with_str(&self, nodes: &Array) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_str_0(&self) -> Result<(), JsValue>
pub fn replace_with_with_str_0(&self) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>
pub fn replace_with_with_str_1(&self, nodes_1: &str) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_str_2(
&self,
nodes_1: &str,
nodes_2: &str,
) -> Result<(), JsValue>
pub fn replace_with_with_str_2( &self, nodes_1: &str, nodes_2: &str, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_str_3(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
) -> Result<(), JsValue>
pub fn replace_with_with_str_3( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_str_4(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
) -> Result<(), JsValue>
pub fn replace_with_with_str_4( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Sourcepub fn replace_with_with_str_5(
&self,
nodes_1: &str,
nodes_2: &str,
nodes_3: &str,
nodes_4: &str,
nodes_5: &str,
) -> Result<(), JsValue>
pub fn replace_with_with_str_5( &self, nodes_1: &str, nodes_2: &str, nodes_3: &str, nodes_4: &str, nodes_5: &str, ) -> Result<(), JsValue>
The replaceWith() method.
This API requires the following crate features to be activated: CharacterData
Methods from Deref<Target = Node>
Sourcepub fn node_type(&self) -> u16
pub fn node_type(&self) -> u16
Getter for the nodeType field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn node_name(&self) -> String
pub fn node_name(&self) -> String
Getter for the nodeName field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn base_uri(&self) -> Result<Option<String>, JsValue>
pub fn base_uri(&self) -> Result<Option<String>, JsValue>
Getter for the baseURI field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn is_connected(&self) -> bool
pub fn is_connected(&self) -> bool
Getter for the isConnected field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn owner_document(&self) -> Option<Document>
pub fn owner_document(&self) -> Option<Document>
Getter for the ownerDocument field of this object.
This API requires the following crate features to be activated: Document, Node
Sourcepub fn parent_node(&self) -> Option<Node>
pub fn parent_node(&self) -> Option<Node>
Getter for the parentNode field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn parent_element(&self) -> Option<Element>
pub fn parent_element(&self) -> Option<Element>
Getter for the parentElement field of this object.
This API requires the following crate features to be activated: Element, Node
Sourcepub fn child_nodes(&self) -> NodeList
pub fn child_nodes(&self) -> NodeList
Getter for the childNodes field of this object.
This API requires the following crate features to be activated: Node, NodeList
Sourcepub fn first_child(&self) -> Option<Node>
pub fn first_child(&self) -> Option<Node>
Getter for the firstChild field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn last_child(&self) -> Option<Node>
pub fn last_child(&self) -> Option<Node>
Getter for the lastChild field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn previous_sibling(&self) -> Option<Node>
pub fn previous_sibling(&self) -> Option<Node>
Getter for the previousSibling field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn next_sibling(&self) -> Option<Node>
pub fn next_sibling(&self) -> Option<Node>
Getter for the nextSibling field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn node_value(&self) -> Option<String>
pub fn node_value(&self) -> Option<String>
Getter for the nodeValue field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn set_node_value(&self, value: Option<&str>)
pub fn set_node_value(&self, value: Option<&str>)
Setter for the nodeValue field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn text_content(&self) -> Option<String>
pub fn text_content(&self) -> Option<String>
Getter for the textContent field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn set_text_content(&self, value: Option<&str>)
pub fn set_text_content(&self, value: Option<&str>)
Setter for the textContent field of this object.
This API requires the following crate features to be activated: Node
Sourcepub fn append_child(&self, node: &Node) -> Result<Node, JsValue>
pub fn append_child(&self, node: &Node) -> Result<Node, JsValue>
The appendChild() method.
This API requires the following crate features to be activated: Node
Sourcepub fn clone_node(&self) -> Result<Node, JsValue>
pub fn clone_node(&self) -> Result<Node, JsValue>
The cloneNode() method.
This API requires the following crate features to be activated: Node
Sourcepub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>
pub fn clone_node_with_deep(&self, deep: bool) -> Result<Node, JsValue>
The cloneNode() method.
This API requires the following crate features to be activated: Node
Sourcepub fn compare_document_position(&self, other: &Node) -> u16
pub fn compare_document_position(&self, other: &Node) -> u16
The compareDocumentPosition() method.
This API requires the following crate features to be activated: Node
Sourcepub fn contains(&self, other: Option<&Node>) -> bool
pub fn contains(&self, other: Option<&Node>) -> bool
The contains() method.
This API requires the following crate features to be activated: Node
Sourcepub fn get_root_node(&self) -> Node
pub fn get_root_node(&self) -> Node
The getRootNode() method.
This API requires the following crate features to be activated: Node
Sourcepub fn has_child_nodes(&self) -> bool
pub fn has_child_nodes(&self) -> bool
The hasChildNodes() method.
This API requires the following crate features to be activated: Node
Sourcepub fn insert_before(
&self,
node: &Node,
child: Option<&Node>,
) -> Result<Node, JsValue>
pub fn insert_before( &self, node: &Node, child: Option<&Node>, ) -> Result<Node, JsValue>
The insertBefore() method.
This API requires the following crate features to be activated: Node
Sourcepub fn is_default_namespace(&self, namespace: Option<&str>) -> bool
pub fn is_default_namespace(&self, namespace: Option<&str>) -> bool
The isDefaultNamespace() method.
This API requires the following crate features to be activated: Node
Sourcepub fn is_equal_node(&self, node: Option<&Node>) -> bool
pub fn is_equal_node(&self, node: Option<&Node>) -> bool
The isEqualNode() method.
This API requires the following crate features to be activated: Node
Sourcepub fn is_same_node(&self, node: Option<&Node>) -> bool
pub fn is_same_node(&self, node: Option<&Node>) -> bool
The isSameNode() method.
This API requires the following crate features to be activated: Node
Sourcepub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>
pub fn lookup_namespace_uri(&self, prefix: Option<&str>) -> Option<String>
The lookupNamespaceURI() method.
This API requires the following crate features to be activated: Node
Sourcepub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>
pub fn lookup_prefix(&self, namespace: Option<&str>) -> Option<String>
The lookupPrefix() method.
This API requires the following crate features to be activated: Node
Sourcepub fn normalize(&self)
pub fn normalize(&self)
The normalize() method.
This API requires the following crate features to be activated: Node
Sourcepub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>
pub fn remove_child(&self, child: &Node) -> Result<Node, JsValue>
The removeChild() method.
This API requires the following crate features to be activated: Node
Sourcepub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>
pub fn replace_child(&self, node: &Node, child: &Node) -> Result<Node, JsValue>
The replaceChild() method.
This API requires the following crate features to be activated: Node
pub const ELEMENT_NODE: u16 = 1u16
pub const ATTRIBUTE_NODE: u16 = 2u16
pub const TEXT_NODE: u16 = 3u16
pub const CDATA_SECTION_NODE: u16 = 4u16
pub const ENTITY_REFERENCE_NODE: u16 = 5u16
pub const ENTITY_NODE: u16 = 6u16
pub const PROCESSING_INSTRUCTION_NODE: u16 = 7u16
pub const COMMENT_NODE: u16 = 8u16
pub const DOCUMENT_NODE: u16 = 9u16
pub const DOCUMENT_TYPE_NODE: u16 = 10u16
pub const DOCUMENT_FRAGMENT_NODE: u16 = 11u16
pub const NOTATION_NODE: u16 = 12u16
pub const DOCUMENT_POSITION_DISCONNECTED: u16 = 1u16
pub const DOCUMENT_POSITION_PRECEDING: u16 = 2u16
pub const DOCUMENT_POSITION_FOLLOWING: u16 = 4u16
pub const DOCUMENT_POSITION_CONTAINS: u16 = 8u16
pub const DOCUMENT_POSITION_CONTAINED_BY: u16 = 16u16
pub const DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC: u16 = 32u16
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn remove_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.