#[repr(transparent)]pub struct Request {
pub obj: JsValue,
}Expand description
The Request class.
This API requires the following crate features to be activated: Request
Fields
obj: JsValueImplementations
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourcepub fn referrer_policy(&self) -> ReferrerPolicy
pub fn referrer_policy(&self) -> ReferrerPolicy
Getter for the referrerPolicy field of this object.
This API requires the following crate features to be activated: ReferrerPolicy, Request
Sourceimpl Request
impl Request
Sourcepub fn mode(&self) -> RequestMode
pub fn mode(&self) -> RequestMode
Getter for the mode field of this object.
This API requires the following crate features to be activated: Request, RequestMode
Sourceimpl Request
impl Request
Sourcepub fn credentials(&self) -> RequestCredentials
pub fn credentials(&self) -> RequestCredentials
Getter for the credentials field of this object.
This API requires the following crate features to be activated: Request, RequestCredentials
Sourceimpl Request
impl Request
Sourcepub fn cache(&self) -> RequestCache
pub fn cache(&self) -> RequestCache
Getter for the cache field of this object.
This API requires the following crate features to be activated: Request, RequestCache
Sourceimpl Request
impl Request
Sourcepub fn redirect(&self) -> RequestRedirect
pub fn redirect(&self) -> RequestRedirect
Getter for the redirect field of this object.
This API requires the following crate features to be activated: Request, RequestRedirect
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourcepub fn signal(&self) -> AbortSignal
pub fn signal(&self) -> AbortSignal
Getter for the signal field of this object.
This API requires the following crate features to be activated: AbortSignal, Request
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourcepub fn body(&self) -> Option<ReadableStream>
pub fn body(&self) -> Option<ReadableStream>
Getter for the body field of this object.
This API requires the following crate features to be activated: ReadableStream, Request
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourceimpl Request
impl Request
Sourcepub fn new_with_request_and_init(
input: &Request,
init: &RequestInit,
) -> Result<Request, JsValue>
pub fn new_with_request_and_init( input: &Request, init: &RequestInit, ) -> Result<Request, JsValue>
The new Request(..) constructor, creating a new instance of Request.
This API requires the following crate features to be activated: Request, RequestInit
Sourceimpl Request
impl Request
Sourcepub fn new_with_str_and_init(
input: &str,
init: &RequestInit,
) -> Result<Request, JsValue>
pub fn new_with_str_and_init( input: &str, init: &RequestInit, ) -> Result<Request, JsValue>
The new Request(..) constructor, creating a new instance of Request.
This API requires the following crate features to be activated: Request, RequestInit
Sourceimpl Request
impl Request
Sourcepub fn array_buffer(&self) -> Result<Promise, JsValue>
pub fn array_buffer(&self) -> Result<Promise, JsValue>
The arrayBuffer() method.
This API requires the following crate features to be activated: Request
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.