#[repr(transparent)]pub struct SharedWorkerGlobalScope {
pub obj: JsValue,
}Expand description
The SharedWorkerGlobalScope class.
This API requires the following crate features to be activated: SharedWorkerGlobalScope
Fields
obj: JsValueImplementations
Sourcepub fn set_onconnect(&self, value: Option<&Function>)
pub fn set_onconnect(&self, value: Option<&Function>)
Setter for the onconnect field of this object.
This API requires the following crate features to be activated: SharedWorkerGlobalScope
Methods from Deref<Target = WorkerGlobalScope>
Sourcepub fn self_(&self) -> WorkerGlobalScope
pub fn self_(&self) -> WorkerGlobalScope
Getter for the self field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn location(&self) -> WorkerLocation
pub fn location(&self) -> WorkerLocation
Getter for the location field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope, WorkerLocation
Getter for the navigator field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope, WorkerNavigator
Sourcepub fn onerror(&self) -> Option<Function>
pub fn onerror(&self) -> Option<Function>
Getter for the onerror field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_onerror(&self, value: Option<&Function>)
pub fn set_onerror(&self, value: Option<&Function>)
Setter for the onerror field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn onoffline(&self) -> Option<Function>
pub fn onoffline(&self) -> Option<Function>
Getter for the onoffline field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_onoffline(&self, value: Option<&Function>)
pub fn set_onoffline(&self, value: Option<&Function>)
Setter for the onoffline field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn ononline(&self) -> Option<Function>
pub fn ononline(&self) -> Option<Function>
Getter for the ononline field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_ononline(&self, value: Option<&Function>)
pub fn set_ononline(&self, value: Option<&Function>)
Setter for the ononline field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn crypto(&self) -> Result<Crypto, JsValue>
pub fn crypto(&self) -> Result<Crypto, JsValue>
Getter for the crypto field of this object.
This API requires the following crate features to be activated: Crypto, WorkerGlobalScope
Sourcepub fn indexed_db(&self) -> Result<Option<IdbFactory>, JsValue>
pub fn indexed_db(&self) -> Result<Option<IdbFactory>, JsValue>
Getter for the indexedDB field of this object.
This API requires the following crate features to be activated: IdbFactory, WorkerGlobalScope
Sourcepub fn performance(&self) -> Option<Performance>
pub fn performance(&self) -> Option<Performance>
Getter for the performance field of this object.
This API requires the following crate features to be activated: Performance, WorkerGlobalScope
Sourcepub fn origin(&self) -> String
pub fn origin(&self) -> String
Getter for the origin field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn is_secure_context(&self) -> bool
pub fn is_secure_context(&self) -> bool
Getter for the isSecureContext field of this object.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn caches(&self) -> Result<CacheStorage, JsValue>
pub fn caches(&self) -> Result<CacheStorage, JsValue>
Getter for the caches field of this object.
This API requires the following crate features to be activated: CacheStorage, WorkerGlobalScope
Sourcepub fn import_scripts(&self, urls: &Array) -> Result<(), JsValue>
pub fn import_scripts(&self, urls: &Array) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_0(&self) -> Result<(), JsValue>
pub fn import_scripts_0(&self) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_1(&self, urls_1: &str) -> Result<(), JsValue>
pub fn import_scripts_1(&self, urls_1: &str) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_2(
&self,
urls_1: &str,
urls_2: &str,
) -> Result<(), JsValue>
pub fn import_scripts_2( &self, urls_1: &str, urls_2: &str, ) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_3(
&self,
urls_1: &str,
urls_2: &str,
urls_3: &str,
) -> Result<(), JsValue>
pub fn import_scripts_3( &self, urls_1: &str, urls_2: &str, urls_3: &str, ) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_4(
&self,
urls_1: &str,
urls_2: &str,
urls_3: &str,
urls_4: &str,
) -> Result<(), JsValue>
pub fn import_scripts_4( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, ) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_5(
&self,
urls_1: &str,
urls_2: &str,
urls_3: &str,
urls_4: &str,
urls_5: &str,
) -> Result<(), JsValue>
pub fn import_scripts_5( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, ) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_6(
&self,
urls_1: &str,
urls_2: &str,
urls_3: &str,
urls_4: &str,
urls_5: &str,
urls_6: &str,
) -> Result<(), JsValue>
pub fn import_scripts_6( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, urls_6: &str, ) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn import_scripts_7(
&self,
urls_1: &str,
urls_2: &str,
urls_3: &str,
urls_4: &str,
urls_5: &str,
urls_6: &str,
urls_7: &str,
) -> Result<(), JsValue>
pub fn import_scripts_7( &self, urls_1: &str, urls_2: &str, urls_3: &str, urls_4: &str, urls_5: &str, urls_6: &str, urls_7: &str, ) -> Result<(), JsValue>
The importScripts() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn atob(&self, atob: &str) -> Result<String, JsValue>
pub fn atob(&self, atob: &str) -> Result<String, JsValue>
The atob() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn btoa(&self, btoa: &str) -> Result<String, JsValue>
pub fn btoa(&self, btoa: &str) -> Result<String, JsValue>
The btoa() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn clear_interval(&self)
pub fn clear_interval(&self)
The clearInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn clear_interval_with_handle(&self, handle: i32)
pub fn clear_interval_with_handle(&self, handle: i32)
The clearInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn clear_timeout(&self)
pub fn clear_timeout(&self)
The clearTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn clear_timeout_with_handle(&self, handle: i32)
pub fn clear_timeout_with_handle(&self, handle: i32)
The clearTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_image_element(
&self,
a_image: &HtmlImageElement,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_image_element( &self, a_image: &HtmlImageElement, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlImageElement, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_canvas_element(
&self,
a_image: &HtmlCanvasElement,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_canvas_element( &self, a_image: &HtmlCanvasElement, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlCanvasElement, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_video_element(
&self,
a_image: &HtmlVideoElement,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_video_element( &self, a_image: &HtmlVideoElement, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlVideoElement, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_bitmap(
&self,
a_image: &ImageBitmap,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_bitmap( &self, a_image: &ImageBitmap, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmap, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_offscreen_canvas(
&self,
a_image: &OffscreenCanvas,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_offscreen_canvas( &self, a_image: &OffscreenCanvas, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: OffscreenCanvas, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_blob(
&self,
a_image: &Blob,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_blob( &self, a_image: &Blob, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: Blob, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_data(
&self,
a_image: &ImageData,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_data( &self, a_image: &ImageData, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageData, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_image_element_and_image_bitmap_options(
&self,
a_image: &HtmlImageElement,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_image_element_and_image_bitmap_options( &self, a_image: &HtmlImageElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlImageElement, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_canvas_element_and_image_bitmap_options(
&self,
a_image: &HtmlCanvasElement,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_canvas_element_and_image_bitmap_options( &self, a_image: &HtmlCanvasElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlCanvasElement, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_video_element_and_image_bitmap_options(
&self,
a_image: &HtmlVideoElement,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_video_element_and_image_bitmap_options( &self, a_image: &HtmlVideoElement, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlVideoElement, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_bitmap_and_image_bitmap_options(
&self,
a_image: &ImageBitmap,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_bitmap_and_image_bitmap_options( &self, a_image: &ImageBitmap, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmap, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_offscreen_canvas_and_image_bitmap_options(
&self,
a_image: &OffscreenCanvas,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_offscreen_canvas_and_image_bitmap_options( &self, a_image: &OffscreenCanvas, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmapOptions, OffscreenCanvas, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_blob_and_image_bitmap_options(
&self,
a_image: &Blob,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_blob_and_image_bitmap_options( &self, a_image: &Blob, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: Blob, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_data_and_image_bitmap_options(
&self,
a_image: &ImageData,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_data_and_image_bitmap_options( &self, a_image: &ImageData, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmapOptions, ImageData, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh(
&self,
a_image: &HtmlImageElement,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlImageElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlImageElement, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh(
&self,
a_image: &HtmlCanvasElement,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlCanvasElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlCanvasElement, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh(
&self,
a_image: &HtmlVideoElement,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &HtmlVideoElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlVideoElement, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh(
&self,
a_image: &ImageBitmap,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &ImageBitmap, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmap, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh(
&self,
a_image: &OffscreenCanvas,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &OffscreenCanvas, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: OffscreenCanvas, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_blob_and_a_sx_and_a_sy_and_a_sw_and_a_sh(
&self,
a_image: &Blob,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_blob_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &Blob, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: Blob, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_data_and_a_sx_and_a_sy_and_a_sw_and_a_sh(
&self,
a_image: &ImageData,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_data_and_a_sx_and_a_sy_and_a_sw_and_a_sh( &self, a_image: &ImageData, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageData, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options(
&self,
a_image: &HtmlImageElement,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_image_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlImageElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlImageElement, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options(
&self,
a_image: &HtmlCanvasElement,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_canvas_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlCanvasElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlCanvasElement, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options(
&self,
a_image: &HtmlVideoElement,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_html_video_element_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &HtmlVideoElement, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: HtmlVideoElement, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options(
&self,
a_image: &ImageBitmap,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_bitmap_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &ImageBitmap, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmap, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options(
&self,
a_image: &OffscreenCanvas,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_offscreen_canvas_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &OffscreenCanvas, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmapOptions, OffscreenCanvas, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_blob_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options(
&self,
a_image: &Blob,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_blob_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &Blob, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: Blob, ImageBitmapOptions, WorkerGlobalScope
Sourcepub fn create_image_bitmap_with_image_data_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options(
&self,
a_image: &ImageData,
a_sx: i32,
a_sy: i32,
a_sw: i32,
a_sh: i32,
a_options: &ImageBitmapOptions,
) -> Result<Promise, JsValue>
pub fn create_image_bitmap_with_image_data_and_a_sx_and_a_sy_and_a_sw_and_a_sh_and_a_options( &self, a_image: &ImageData, a_sx: i32, a_sy: i32, a_sw: i32, a_sh: i32, a_options: &ImageBitmapOptions, ) -> Result<Promise, JsValue>
The createImageBitmap() method.
This API requires the following crate features to be activated: ImageBitmapOptions, ImageData, WorkerGlobalScope
Sourcepub fn fetch_with_request(&self, input: &Request) -> Promise
pub fn fetch_with_request(&self, input: &Request) -> Promise
The fetch() method.
This API requires the following crate features to be activated: Request, WorkerGlobalScope
Sourcepub fn fetch_with_str(&self, input: &str) -> Promise
pub fn fetch_with_str(&self, input: &str) -> Promise
The fetch() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn fetch_with_request_and_init(
&self,
input: &Request,
init: &RequestInit,
) -> Promise
pub fn fetch_with_request_and_init( &self, input: &Request, init: &RequestInit, ) -> Promise
The fetch() method.
This API requires the following crate features to be activated: Request, RequestInit, WorkerGlobalScope
Sourcepub fn fetch_with_str_and_init(
&self,
input: &str,
init: &RequestInit,
) -> Promise
pub fn fetch_with_str_and_init( &self, input: &str, init: &RequestInit, ) -> Promise
The fetch() method.
This API requires the following crate features to be activated: RequestInit, WorkerGlobalScope
Sourcepub fn queue_microtask(&self, callback: &Function)
pub fn queue_microtask(&self, callback: &Function)
The queueMicrotask() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback(
&self,
handler: &Function,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback( &self, handler: &Function, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments(
&self,
handler: &Function,
timeout: i32,
arguments: &Array,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, arguments: &Array, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_0(
&self,
handler: &Function,
timeout: i32,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_0( &self, handler: &Function, timeout: i32, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_1(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_2(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_3(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_4(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_5(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
arguments_5: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_6(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
arguments_5: &JsValue,
arguments_6: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_callback_and_timeout_and_arguments_7(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
arguments_5: &JsValue,
arguments_6: &JsValue,
arguments_7: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str(&self, handler: &str) -> Result<i32, JsValue>
pub fn set_interval_with_str(&self, handler: &str) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused(
&self,
handler: &str,
timeout: i32,
unused: &Array,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_0(
&self,
handler: &str,
timeout: i32,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_0( &self, handler: &str, timeout: i32, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_1(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_2(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_3(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_4(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_5(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
unused_5: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_6(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
unused_5: &JsValue,
unused_6: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_interval_with_str_and_timeout_and_unused_7(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
unused_5: &JsValue,
unused_6: &JsValue,
unused_7: &JsValue,
) -> Result<i32, JsValue>
pub fn set_interval_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>
The setInterval() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback(
&self,
handler: &Function,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback( &self, handler: &Function, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments(
&self,
handler: &Function,
timeout: i32,
arguments: &Array,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments( &self, handler: &Function, timeout: i32, arguments: &Array, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_0(
&self,
handler: &Function,
timeout: i32,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_0( &self, handler: &Function, timeout: i32, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_1(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_1( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_2(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_2( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_3(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_3( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_4(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_4( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_5(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
arguments_5: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_5( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_6(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
arguments_5: &JsValue,
arguments_6: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_6( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_callback_and_timeout_and_arguments_7(
&self,
handler: &Function,
timeout: i32,
arguments_1: &JsValue,
arguments_2: &JsValue,
arguments_3: &JsValue,
arguments_4: &JsValue,
arguments_5: &JsValue,
arguments_6: &JsValue,
arguments_7: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_callback_and_timeout_and_arguments_7( &self, handler: &Function, timeout: i32, arguments_1: &JsValue, arguments_2: &JsValue, arguments_3: &JsValue, arguments_4: &JsValue, arguments_5: &JsValue, arguments_6: &JsValue, arguments_7: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str(&self, handler: &str) -> Result<i32, JsValue>
pub fn set_timeout_with_str(&self, handler: &str) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused(
&self,
handler: &str,
timeout: i32,
unused: &Array,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused( &self, handler: &str, timeout: i32, unused: &Array, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_0(
&self,
handler: &str,
timeout: i32,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_0( &self, handler: &str, timeout: i32, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_1(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_1( &self, handler: &str, timeout: i32, unused_1: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_2(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_2( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_3(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_3( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_4(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_4( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_5(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
unused_5: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_5( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_6(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
unused_5: &JsValue,
unused_6: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_6( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Sourcepub fn set_timeout_with_str_and_timeout_and_unused_7(
&self,
handler: &str,
timeout: i32,
unused_1: &JsValue,
unused_2: &JsValue,
unused_3: &JsValue,
unused_4: &JsValue,
unused_5: &JsValue,
unused_6: &JsValue,
unused_7: &JsValue,
) -> Result<i32, JsValue>
pub fn set_timeout_with_str_and_timeout_and_unused_7( &self, handler: &str, timeout: i32, unused_1: &JsValue, unused_2: &JsValue, unused_3: &JsValue, unused_4: &JsValue, unused_5: &JsValue, unused_6: &JsValue, unused_7: &JsValue, ) -> Result<i32, JsValue>
The setTimeout() method.
This API requires the following crate features to be activated: WorkerGlobalScope
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn remove_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.