#[repr(transparent)]pub struct XmlHttpRequest {
pub obj: JsValue,
}Expand description
The XmlHttpRequest class.
This API requires the following crate features to be activated: XmlHttpRequest
Fields
obj: JsValueImplementations
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn onreadystatechange(&self) -> Option<Function>
pub fn onreadystatechange(&self) -> Option<Function>
Getter for the onreadystatechange field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn set_onreadystatechange(&self, value: Option<&Function>)
pub fn set_onreadystatechange(&self, value: Option<&Function>)
Setter for the onreadystatechange field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn ready_state(&self) -> u16
pub fn ready_state(&self) -> u16
Getter for the readyState field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn set_timeout(&self, value: u32)
pub fn set_timeout(&self, value: u32)
Setter for the timeout field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn with_credentials(&self) -> bool
pub fn with_credentials(&self) -> bool
Getter for the withCredentials field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn set_with_credentials(&self, value: bool)
pub fn set_with_credentials(&self, value: bool)
Setter for the withCredentials field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn response_url(&self) -> String
pub fn response_url(&self) -> String
Getter for the responseURL field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn status_text(&self) -> Result<String, JsValue>
pub fn status_text(&self) -> Result<String, JsValue>
Getter for the statusText field of this object.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn response_type(&self) -> XmlHttpRequestResponseType
pub fn response_type(&self) -> XmlHttpRequestResponseType
Getter for the responseType field of this object.
This API requires the following crate features to be activated: XmlHttpRequest, XmlHttpRequestResponseType
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn set_response_type(&self, value: XmlHttpRequestResponseType)
pub fn set_response_type(&self, value: XmlHttpRequestResponseType)
Setter for the responseType field of this object.
This API requires the following crate features to be activated: XmlHttpRequest, XmlHttpRequestResponseType
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn new() -> Result<XmlHttpRequest, JsValue>
pub fn new() -> Result<XmlHttpRequest, JsValue>
The new XmlHttpRequest(..) constructor, creating a new instance of XmlHttpRequest.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn new_with_ignored(ignored: &str) -> Result<XmlHttpRequest, JsValue>
pub fn new_with_ignored(ignored: &str) -> Result<XmlHttpRequest, JsValue>
The new XmlHttpRequest(..) constructor, creating a new instance of XmlHttpRequest.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn get_all_response_headers(&self) -> Result<String, JsValue>
pub fn get_all_response_headers(&self) -> Result<String, JsValue>
The getAllResponseHeaders() method.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn send_with_opt_js_u8_array(
&self,
body: Option<&Uint8Array>,
) -> Result<(), JsValue>
pub fn send_with_opt_js_u8_array( &self, body: Option<&Uint8Array>, ) -> Result<(), JsValue>
The send() method.
This API requires the following crate features to be activated: XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn send_with_opt_url_search_params(
&self,
body: Option<&UrlSearchParams>,
) -> Result<(), JsValue>
pub fn send_with_opt_url_search_params( &self, body: Option<&UrlSearchParams>, ) -> Result<(), JsValue>
The send() method.
This API requires the following crate features to be activated: UrlSearchParams, XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub fn send_with_opt_readable_stream(
&self,
body: Option<&ReadableStream>,
) -> Result<(), JsValue>
pub fn send_with_opt_readable_stream( &self, body: Option<&ReadableStream>, ) -> Result<(), JsValue>
The send() method.
This API requires the following crate features to be activated: ReadableStream, XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourceimpl XmlHttpRequest
impl XmlHttpRequest
Sourcepub const UNSENT: u16 = 0u16
pub const UNSENT: u16 = 0u16
The XMLHttpRequest.UNSENT const.
This API requires the following crate features to be activated: XmlHttpRequest
Sourcepub const OPENED: u16 = 1u16
pub const OPENED: u16 = 1u16
The XMLHttpRequest.OPENED const.
This API requires the following crate features to be activated: XmlHttpRequest
Sourcepub const HEADERS_RECEIVED: u16 = 2u16
pub const HEADERS_RECEIVED: u16 = 2u16
The XMLHttpRequest.HEADERS_RECEIVED const.
This API requires the following crate features to be activated: XmlHttpRequest
Methods from Deref<Target = XmlHttpRequestEventTarget>
Sourcepub fn onloadstart(&self) -> Option<Function>
pub fn onloadstart(&self) -> Option<Function>
Getter for the onloadstart field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn set_onloadstart(&self, value: Option<&Function>)
pub fn set_onloadstart(&self, value: Option<&Function>)
Setter for the onloadstart field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn onprogress(&self) -> Option<Function>
pub fn onprogress(&self) -> Option<Function>
Getter for the onprogress field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn set_onprogress(&self, value: Option<&Function>)
pub fn set_onprogress(&self, value: Option<&Function>)
Setter for the onprogress field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn onabort(&self) -> Option<Function>
pub fn onabort(&self) -> Option<Function>
Getter for the onabort field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn set_onabort(&self, value: Option<&Function>)
pub fn set_onabort(&self, value: Option<&Function>)
Setter for the onabort field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn onerror(&self) -> Option<Function>
pub fn onerror(&self) -> Option<Function>
Getter for the onerror field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn set_onerror(&self, value: Option<&Function>)
pub fn set_onerror(&self, value: Option<&Function>)
Setter for the onerror field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn onload(&self) -> Option<Function>
pub fn onload(&self) -> Option<Function>
Getter for the onload field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn set_onload(&self, value: Option<&Function>)
pub fn set_onload(&self, value: Option<&Function>)
Setter for the onload field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn ontimeout(&self) -> Option<Function>
pub fn ontimeout(&self) -> Option<Function>
Getter for the ontimeout field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn set_ontimeout(&self, value: Option<&Function>)
pub fn set_ontimeout(&self, value: Option<&Function>)
Setter for the ontimeout field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn onloadend(&self) -> Option<Function>
pub fn onloadend(&self) -> Option<Function>
Getter for the onloadend field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Sourcepub fn set_onloadend(&self, value: Option<&Function>)
pub fn set_onloadend(&self, value: Option<&Function>)
Setter for the onloadend field of this object.
This API requires the following crate features to be activated: XmlHttpRequestEventTarget
Methods from Deref<Target = EventTarget>
Sourcepub fn add_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &Function, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: &AddEventListenerOptions,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_add_event_listener_options_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: &AddEventListenerOptions, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: AddEventListenerOptions, EventListener, EventTarget
Sourcepub fn add_event_listener_with_callback_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &Function,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_callback_and_bool_and_wants_untrusted( &self, type_: &str, listener: &Function, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted(
&self,
type_: &str,
listener: &EventListener,
options: bool,
wants_untrusted: Option<bool>,
) -> Result<(), JsValue>
pub fn add_event_listener_with_event_listener_and_bool_and_wants_untrusted( &self, type_: &str, listener: &EventListener, options: bool, wants_untrusted: Option<bool>, ) -> Result<(), JsValue>
The addEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
pub fn dispatch_event(&self, event: &Event) -> Result<bool, JsValue>
The dispatchEvent() method.
This API requires the following crate features to be activated: Event, EventTarget
Sourcepub fn remove_event_listener_with_callback(
&self,
type_: &str,
listener: &Function,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback( &self, type_: &str, listener: &Function, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener(
&self,
type_: &str,
listener: &EventListener,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener( &self, type_: &str, listener: &EventListener, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_event_listener_options(
&self,
type_: &str,
listener: &Function,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_event_listener_options( &self, type_: &str, listener: &Function, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_event_listener_options(
&self,
type_: &str,
listener: &EventListener,
options: &EventListenerOptions,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_event_listener_options( &self, type_: &str, listener: &EventListener, options: &EventListenerOptions, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventListenerOptions, EventTarget
Sourcepub fn remove_event_listener_with_callback_and_bool(
&self,
type_: &str,
listener: &Function,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_callback_and_bool( &self, type_: &str, listener: &Function, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventTarget
Sourcepub fn remove_event_listener_with_event_listener_and_bool(
&self,
type_: &str,
listener: &EventListener,
options: bool,
) -> Result<(), JsValue>
pub fn remove_event_listener_with_event_listener_and_bool( &self, type_: &str, listener: &EventListener, options: bool, ) -> Result<(), JsValue>
The removeEventListener() method.
This API requires the following crate features to be activated: EventListener, EventTarget
Methods from Deref<Target = Object>
Sourcepub fn constructor(&self) -> Function
pub fn constructor(&self) -> Function
The constructor property returns a reference to the Object constructor
function that created the instance object.
Sourcepub fn has_own_property(&self, property: &JsValue) -> bool
pub fn has_own_property(&self, property: &JsValue) -> bool
The hasOwnProperty() method returns a boolean indicating whether the
object has the specified property as its own property (as opposed to
inheriting it).
Sourcepub fn is_prototype_of(&self, value: &JsValue) -> bool
pub fn is_prototype_of(&self, value: &JsValue) -> bool
The isPrototypeOf() method checks if an object exists in another
object’s prototype chain.
Sourcepub fn property_is_enumerable(&self, property: &JsValue) -> bool
pub fn property_is_enumerable(&self, property: &JsValue) -> bool
The propertyIsEnumerable() method returns a Boolean indicating
whether the specified property is enumerable.
Sourcepub fn to_locale_string(&self) -> JsString
pub fn to_locale_string(&self) -> JsString
The toLocaleString() method returns a string representing the object.
This method is meant to be overridden by derived objects for
locale-specific purposes.
Sourcepub fn to_string(&self) -> JsString
pub fn to_string(&self) -> JsString
The toString() method returns a string representing the object.
Methods from Deref<Target = JsValue>
pub const NULL: JsValue
pub const UNDEFINED: JsValue
pub const TRUE: JsValue
pub const FALSE: JsValue
Sourcepub fn id(&self) -> u64
pub fn id(&self) -> u64
Get the heap ID for this value.
This is used internally for encoding values to send to JS.
Sourcepub fn unchecked_into_f64(&self) -> f64
pub fn unchecked_into_f64(&self) -> f64
Returns the value as f64 without type checking. Used by serde-wasm-bindgen for numeric conversions.
Sourcepub fn has_type<T>(&self) -> boolwhere
T: JsCast,
pub fn has_type<T>(&self) -> boolwhere
T: JsCast,
Check if this value is an instance of a specific JS type.
Sourcepub fn checked_div(&self, rhs: &JsValue) -> JsValue
pub fn checked_div(&self, rhs: &JsValue) -> JsValue
Checked division.
Sourcepub fn unsigned_shr(&self, rhs: &JsValue) -> u32
pub fn unsigned_shr(&self, rhs: &JsValue) -> u32
Unsigned right shift.
Sourcepub fn is_function(&self) -> bool
pub fn is_function(&self) -> bool
Check if this value is a function.
Sourcepub fn is_undefined(&self) -> bool
pub fn is_undefined(&self) -> bool
Check if this value is undefined.
Sourcepub fn js_in(&self, obj: &JsValue) -> bool
pub fn js_in(&self, obj: &JsValue) -> bool
Check if this value has a property with the given name.
Sourcepub fn as_debug_string(&self) -> String
pub fn as_debug_string(&self) -> String
Get a debug string representation of the value.